@@ -29,8 +29,7 @@ static jack_client_t *client;
 static char *source_names[2] = { NULL, NULL };
 static const char **ports;
 
-// TODO: make it configuration in the rc file
-// desired input->size
+// default input size if not defined in the configuration file
 #define INSIZE 1024
 static uint16_t insize = INSIZE;
 // buffer jack samples here before copying to input->data
@@ -64,12 +63,12 @@ process(jack_nframes_t nframes, void *arg)
     for (chn = 0; chn < 2; chn++) {
       in = jack_port_get_buffer(input_ports[chn], nframes);
       if (in != NULL) {
-	for (i = 0; i < nframes; i++, idx++) {
-	  data[chn][idx] = in[i];
-	}
-	if (chn == 0) {
-	  idx = idx2;
-	}
+        for (i = 0; i < nframes; i++, idx++) {
+          data[chn][idx] = in[i];
+        }
+        if (chn == 0) {
+          idx = idx2;
+        }
       }
     }
 
@@ -84,8 +83,8 @@ process(jack_nframes_t nframes, void *arg)
 #endif
       pthread_mutex_lock(&ctx->input->mutex);
       for (i = 0; i < ctx->input->size; i++) {
-	ctx->input->data[A_LEFT][i]  = data[0][i];
-	ctx->input->data[A_RIGHT][i] = data[1][i];
+        ctx->input->data[A_LEFT][i]  = data[0][i];
+        ctx->input->data[A_RIGHT][i] = data[1][i];
       }
       Input_set(ctx->input, A_STEREO);
       pthread_mutex_unlock(&ctx->input->mutex);
@@ -113,31 +112,36 @@ setup_ports()
       fprintf(stderr, "[!] JACK: cannot register input port \"%s\" !\n", name);
       jack_client_close(client);
       exit(1);
+    } else {
+      printf("[i] JACK: registered %s\n", name);
     }
-    else printf("[i] JACK: registered %s\n", name);
   }
 
   ports = jack_get_ports(client, NULL, NULL, JackPortIsPhysical|JackPortIsOutput);
-  if (NULL == ports)
+  if (NULL == ports) {
     xerror("JACK: no physical capture ports\n");
+  }
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   int i;
 
-  if ((client = jack_client_open(PACKAGE, JackNullOption, NULL)) == 0)
+  if ((client = jack_client_open(PACKAGE, JackNullOption, NULL)) == 0) {
     xerror("JACK server not running ?\n");
+  }
 
   jack_set_process_callback(client, process, ctx);
   jack_on_shutdown(client, jack_shutdown, ctx);
 
-  if (NULL == (source_names[0] = getenv("LEBINIOU_JACK_LEFT")))
+  if (NULL == (source_names[0] = getenv("LEBINIOU_JACK_LEFT"))) {
     source_names[0] = "system:capture_1";
-  if (NULL == (source_names[1] = getenv("LEBINIOU_JACK_RIGHT")))
+  }
+  if (NULL == (source_names[1] = getenv("LEBINIOU_JACK_RIGHT"))) {
     source_names[1] = "system:capture_2";
+  }
 
   printf("[i] JACK: left  capture from %s\n", source_names[0]);
   printf("[i] JACK: right capture from %s\n", source_names[1]);
@@ -158,18 +162,22 @@ create(Context_t *ctx)
   data[0] = xcalloc(insize, sizeof(double));
   data[1] = xcalloc(insize, sizeof(double));
 
-  if (jack_activate(client))
+  if (jack_activate(client)) {
     xerror("JACK: cannot activate client\n");
+  }
 
   for (i = 0; i < 2; i++) {
     if (jack_connect(client, ports[i], jack_port_name(input_ports[i]))) {
       fprintf(stderr, "[!] JACK: can not connect input port %s to %s\n", jack_port_name(input_ports[i]), source_names[i]);
       jack_client_close(client);
       exit(1);
+    } else {
+      printf("[i] JACK: connected %s to %s\n", source_names[i], jack_port_name(input_ports[i]));
     }
-    else printf("[i] JACK: connected %s to %s\n", source_names[i], jack_port_name(input_ports[i]));
   }
   jack_free(ports);
+
+  return 1;
 }
 
 
