@@ -69,19 +69,24 @@ set_dsp_params(int fd, int channels, int bits, int *rate)
   int status, val = channels;
 
   status= ioctl(fd, SOUND_PCM_WRITE_CHANNELS, &val);
-  if (status == -1)
+  if (status == -1) {
     perror("SOUND_PCM_WRITE_CHANNELS ioctl failed");
-  if (val != channels) /* not valid, so return */
+  }
+  if (val != channels) { /* not valid, so return */
     return -1;
+  }
   val = bits;
   status= ioctl(fd, SOUND_PCM_WRITE_BITS, &val);
-  if (status == -1)
+  if (status == -1) {
     perror("SOUND_PCM_WRITE_BITS ioctl failed");
-  if (val != bits)
+  }
+  if (val != bits) {
     return -1;
+  }
   status= ioctl(fd, SOUND_PCM_WRITE_RATE, rate);
-  if (status == -1)
+  if (status == -1) {
     perror("SOUND_PCM_WRITE_RATE ioctl failed");
+  }
   return 0;
 }
 
@@ -92,29 +97,38 @@ init()
   int format=AFMT_S16_LE, sample_size=16, stereo=1, frequency=FREQUENCY, status;
 
   status = ioctl(fd, SOUND_PCM_SETFMT, &format);
-  if (status ==  -1)
+  if (status ==  -1) {
     xperror("SOUND_PCM_SETFMT ioctl failed");
-  if (format != AFMT_S16_LE)
+  }
+  if (format != AFMT_S16_LE) {
     xerror("Could not choose S16_LE mode\n");
+  }
 
-  if (ioctl(fd, SNDCTL_DSP_SAMPLESIZE, &sample_size) == -1)
+  if (ioctl(fd, SNDCTL_DSP_SAMPLESIZE, &sample_size) == -1) {
     xperror("ioctl");
-  if (sample_size != 16)
+  }
+  if (sample_size != 16) {
     xerror("Could not choose 16bits sample size\n");
+  }
 
-  if (ioctl(fd, SNDCTL_DSP_STEREO, &stereo) == -1)
+  if (ioctl(fd, SNDCTL_DSP_STEREO, &stereo) == -1) {
     xperror("ioctl");
-  if (stereo != 1)
+  }
+  if (stereo != 1) {
     xerror("Unable to choose stereo\n");
+  }
 
-  if (ioctl(fd, SNDCTL_DSP_SPEED, &frequency) == -1)
+  if (ioctl(fd, SNDCTL_DSP_SPEED, &frequency) == -1) {
     xperror("ioctl");
+  }
   printf("[i] sampling at %dHz\n", frequency);
 
-  if (ioctl(fd, SNDCTL_DSP_GETBLKSIZE, &abuf_size) == -1)
+  if (ioctl(fd, SNDCTL_DSP_GETBLKSIZE, &abuf_size) == -1) {
     xperror("ioctl");
-  if (abuf_size < 1)
+  }
+  if (abuf_size < 1) {
     xerror("fatal: GETBLKSIZE\n");
+  }
   printf("[i] abuf_size= %d\n", abuf_size);
 
   abuf = xcalloc(abuf_size*2, sizeof(short));
@@ -126,7 +140,7 @@ init()
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   int rate;
@@ -142,49 +156,57 @@ create(Context_t *ctx)
 
   /* try to open OSS audio device */
   fd = open(OSS, O_RDONLY);
-  if (fd == -1)
+  if (fd == -1) {
     printf("[dsp] Unable to open OSS device '%s'\n", OSS);
+  }
 
   frag_size = 0x7fff0008; /* try to get a fragment of 256 bytes */
   /* printf("FRAG_SIZE = %d\n", frag_size); */
 
-  if (ioctl(fd, SNDCTL_DSP_SETFRAGMENT, &frag_size) == -1)
+  if (ioctl(fd, SNDCTL_DSP_SETFRAGMENT, &frag_size) == -1) {
     xperror("ioctl");
+  }
 
 #if 1 /* TODO: 0 when ok */
   status= ioctl(fd, SOUND_PCM_READ_RATE, &rate);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SOUND_PCM_READ_RATE ioctl failed");
+  }
   status= ioctl(fd, SOUND_PCM_READ_CHANNELS, &channels);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SOUND_PCM_READ_CHANNELS ioctl failed");
+  }
   status= ioctl(fd, SOUND_PCM_READ_BITS, &bits);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SOUND_PCM_READ_BITS ioctl failed");
+  }
   status= ioctl(fd, SNDCTL_DSP_GETBLKSIZE, &blocksize);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SNFCTL_DSP_GETBLKSIZE ioctl failed");
+  }
 
   printf(
-	 "[i] Information on soundcard:\n"
-	 "[i] Defaults:\n"
-	 "[i]  sampling rate: %d Hz\n"
-	 "[i]  channels: %d\n"
-	 "[i]  sample size: %d bits\n"
-	 "[i]  block size: %d bytes\n",
-	 rate, channels, bits, blocksize
-	 );
+    "[i] Information on soundcard:\n"
+    "[i] Defaults:\n"
+    "[i]  sampling rate: %d Hz\n"
+    "[i]  channels: %d\n"
+    "[i]  sample size: %d bits\n"
+    "[i]  block size: %d bytes\n",
+    rate, channels, bits, blocksize
+  );
 
   /* this requires a more recent version of the sound driver */
 #if SOUND_VERSION >= 301
   printf("[i] Supported Formats:\n");
   deffmt = AFMT_QUERY;
   status= ioctl(fd, SOUND_PCM_SETFMT, &deffmt);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SOUND_PCM_SETFMT ioctl failed");
+  }
   status= ioctl(fd, SOUND_PCM_GETFMTS, &formats);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SOUND_PCM_GETFMTS ioctl failed");
+  }
   if (formats & AFMT_MU_LAW) {
     printf("[i]   mu-law");
     (deffmt == AFMT_MU_LAW) ? printf(" (default)\n") : printf("\n");
@@ -228,45 +250,48 @@ create(Context_t *ctx)
 
   printf("[i] Capabilities:\n");
   status= ioctl(fd, SNDCTL_DSP_GETCAPS, &caps);
-  if (status ==  -1)
+  if (status ==  -1) {
     perror("SNDCTL_DSP_GETCAPS ioctl failed");
+  }
   printf(
-	 "[i]   revision: %d\n"
-	 "[i]   full duplex: %s\n"
-	 "[i]   real-time: %s\n"
-	 "[i]   batch: %s\n"
-	 "[i]   coprocessor: %s\n"
-	 "[i]   trigger: %s\n"
-	 "[i]   mmap: %s\n",
-	 caps & DSP_CAP_REVISION,
-	 yes_no(caps & DSP_CAP_DUPLEX),
-	 yes_no(caps & DSP_CAP_REALTIME),
-	 yes_no(caps & DSP_CAP_BATCH),
-	 yes_no(caps & DSP_CAP_COPROC),
-	 yes_no(caps & DSP_CAP_TRIGGER),
-	 yes_no(caps & DSP_CAP_MMAP));
+    "[i]   revision: %d\n"
+    "[i]   full duplex: %s\n"
+    "[i]   real-time: %s\n"
+    "[i]   batch: %s\n"
+    "[i]   coprocessor: %s\n"
+    "[i]   trigger: %s\n"
+    "[i]   mmap: %s\n",
+    caps & DSP_CAP_REVISION,
+    yes_no(caps & DSP_CAP_DUPLEX),
+    yes_no(caps & DSP_CAP_REALTIME),
+    yes_no(caps & DSP_CAP_BATCH),
+    yes_no(caps & DSP_CAP_COPROC),
+    yes_no(caps & DSP_CAP_TRIGGER),
+    yes_no(caps & DSP_CAP_MMAP));
 
 #endif /* SOUND_VERSION >= 301 */
 
   /* display table heading */
   printf("[i] Modes and Limits:\n"
-	 "[i] Device    Sample    Minimum   Maximum\n"
-	 "[i] Channels  Size      Rate      Rate\n"
-	 "[i] --------  --------  --------  --------\n");
+         "[i] Device    Sample    Minimum   Maximum\n"
+         "[i] Channels  Size      Rate      Rate\n"
+         "[i] --------  --------  --------  --------\n");
 
   /* do mono and stereo */
   for (channels = 1; channels <= 2 ; channels++) {
     /* do 8 and 16 bits */
     for (bits = 8; bits <= 16 ; bits += 8) {
       /* To find the minimum and maximum sampling rates we rely on
-	 the fact that the kernel sound driver will round them to
-	 the closest legal value. */
+      the fact that the kernel sound driver will round them to
+      the closest legal value. */
       min_rate = 1;
-      if (set_dsp_params(fd, channels, bits, &min_rate) == -1)
-	continue;
+      if (set_dsp_params(fd, channels, bits, &min_rate) == -1) {
+        continue;
+      }
       max_rate = 100000;
-      if (set_dsp_params(fd, channels, bits, &max_rate) == -1)
-	continue;
+      if (set_dsp_params(fd, channels, bits, &max_rate) == -1) {
+        continue;
+      }
       /* display the results */
       printf("[i] %8d  %8d  %8d  %8d\n", channels, bits, min_rate, max_rate);
     }
@@ -275,6 +300,8 @@ create(Context_t *ctx)
 
   init();
   ctx->input = Input_new(ABUF_SIZE);
+
+  return 1;
 }
 
 
@@ -296,34 +323,35 @@ jthread(void *args)
       howmuch = abuf_size * 2 * sizeof(short);
       n = read(fd, (void *)abuf, howmuch);
 
-      if (n != howmuch)
-	 xperror("read");
+      if (n != howmuch) {
+        xperror("read");
+      }
 
       if ((ctx->input != NULL) && !ctx->input->mute) {
-	int n2 = 0, idx;
+        int n2 = 0, idx;
 
-	pthread_mutex_lock(&ctx->input->mutex);
-	for (idx = 0; idx < ABUF_SIZE-abuf_size; idx++) {
-	  ctx->input->data[A_LEFT][idx] = ctx->input->data[A_LEFT][idx+abuf_size];
-	  ctx->input->data[A_RIGHT][idx] = ctx->input->data[A_RIGHT][idx+abuf_size];
-	}
+        pthread_mutex_lock(&ctx->input->mutex);
+        for (idx = 0; idx < ABUF_SIZE-abuf_size; idx++) {
+          ctx->input->data[A_LEFT][idx] = ctx->input->data[A_LEFT][idx+abuf_size];
+          ctx->input->data[A_RIGHT][idx] = ctx->input->data[A_RIGHT][idx+abuf_size];
+        }
 
-	for ( ; idx < ABUF_SIZE; idx++) {
-	  ctx->input->data[A_LEFT][idx] =
-	    (float)(((float)(abuf[n2])) / (float)-SHRT_MIN);
-	  n2++;
-	  ctx->input->data[A_RIGHT][idx] =
-	    (float)(((float)(abuf[n2])) / (float)-SHRT_MIN);
-	  n2++;
-	  /*
-	  printf("[+] Read %f %f\n",
-		 ctx->input->data[A_LEFT][idx],
-		 ctx->input->data[A_RIGHT][idx]);
-	  */
-	}
+        for ( ; idx < ABUF_SIZE; idx++) {
+          ctx->input->data[A_LEFT][idx] =
+            (float)(((float)(abuf[n2])) / (float)-SHRT_MIN);
+          n2++;
+          ctx->input->data[A_RIGHT][idx] =
+            (float)(((float)(abuf[n2])) / (float)-SHRT_MIN);
+          n2++;
+          /*
+          printf("[+] Read %f %f\n",
+           ctx->input->data[A_LEFT][idx],
+           ctx->input->data[A_RIGHT][idx]);
+          */
+        }
 
-	Input_set(ctx->input, A_STEREO);
-	pthread_mutex_unlock(&ctx->input->mutex);
+        Input_set(ctx->input, A_STEREO);
+        pthread_mutex_unlock(&ctx->input->mutex);
       }
     }
   }
