@@ -31,7 +31,7 @@ static float *pa_buff = NULL;
 static pa_simple *pa_s;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   int error;
@@ -43,7 +43,7 @@ create(Context_t *ctx)
 
   ss.format = PA_SAMPLE_FLOAT32LE;
   ss.channels = 2;
-  ss.rate = 4410;
+  ss.rate = 44100;
 
   pa_s = pa_simple_new(NULL,               /* PulseAudio server. */
                        "Biniou",           /* Application's name. */
@@ -54,7 +54,7 @@ create(Context_t *ctx)
                        NULL,               /* Channel map */
                        NULL,               /* Buffering attributes. */
                        &error              /* Error code. */
-                       );
+                      );
   if (pa_s == NULL)
     xerror(__FILE__": pa_simple_new() failed: %s\n",
            pa_strerror(error));
@@ -69,6 +69,8 @@ create(Context_t *ctx)
 
   ctx->input = Input_new(insize);
   okdone("pulseaudio initialized");
+
+  return 1;
 }
 
 
@@ -97,8 +99,8 @@ jthread(void *args)
 
       pthread_mutex_lock(&ctx->input->mutex);
       for (m = 0, idx = 0; idx < insize; idx++) {
-	ctx->input->data[A_LEFT][idx] = pa_buff[m++];
-	ctx->input->data[A_RIGHT][idx] = pa_buff[m++];
+        ctx->input->data[A_LEFT][idx] = pa_buff[m++];
+        ctx->input->data[A_RIGHT][idx] = pa_buff[m++];
       }
       Input_set(ctx->input, A_STEREO);
       pthread_mutex_unlock(&ctx->input->mutex);
