@@ -22,15 +22,15 @@
 u_long id = 945287542;
 u_long options = BEQ_THREAD;
 
-#define FACT	0.40
-#define DEVICE	"/dev/urandom"
+#define FACT    0.40
+#define DEVICE  "/dev/urandom"
 
-static short	*urndbuff;
-static int	urndfd;
-static struct timespec req;
+static short  *urndbuff;
+static int     urndfd;
+static struct  timespec req;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   req.tv_sec = 0;
@@ -45,6 +45,8 @@ create(Context_t *ctx)
   uint32_t insize = Context_get_input_size(ctx);
   urndbuff = xcalloc(insize * 2, sizeof(short));
   ctx->input = Input_new(insize);
+
+  return 1;
 }
 
 
@@ -72,8 +74,8 @@ jthread(void *args)
 
       pthread_mutex_lock(&ctx->input->mutex);
       for (m = 0, idx = 0; (m < n) && (idx < (int)ctx->input->size); idx++) {
-	ctx->input->data[A_LEFT][idx] = FACT * (float)((float)urndbuff[m++] / (float)-SHRT_MIN);
-	ctx->input->data[A_RIGHT][idx] = FACT * (float)((float)urndbuff[m++] / (float)-SHRT_MIN);
+        ctx->input->data[A_LEFT][idx] = FACT * (float)((float)urndbuff[m++] / (float)-SHRT_MIN);
+        ctx->input->data[A_RIGHT][idx] = FACT * (float)((float)urndbuff[m++] / (float)-SHRT_MIN);
       }
       Input_set(ctx->input, A_STEREO);
       pthread_mutex_unlock(&ctx->input->mutex);
