@@ -25,7 +25,7 @@ u_long id = 1235598744;
 u_long options = BE_NONE;
 
 static const char *file = NULL;
-static SF_INFO	sfi;
+static SF_INFO     sfi;
 static SNDFILE *sf = NULL;
 
 /* compteur : nombre de frames restant a lire */
@@ -53,7 +53,7 @@ open_file()
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   char *loop_env = NULL;
@@ -67,8 +67,9 @@ create(Context_t *ctx)
   }
 
   loop_env = getenv("LEBINIOU_SNDFILE_LOOP");
-  if (NULL != loop_env)
+  if (NULL != loop_env) {
     loop = 1;
+  }
 
   open_file();
 
@@ -77,6 +78,8 @@ create(Context_t *ctx)
 
   /* printf("[i] Input buffer size = %u\n", bufsize); */
   ctx->input = Input_new(bufsize);
+
+  return 1;
 }
 
 
@@ -111,8 +114,9 @@ run(Context_t *ctx)
       /* plus de frames a lire, mettre les samples pour la fin du buffer a 0 */
       u_short ch;
 
-      for (ch = 0; ch < sfi.channels; ch++)
-	sample[ch] = 0;
+      for (ch = 0; ch < sfi.channels; ch++) {
+        sample[ch] = 0;
+      }
     }
 
     /* copier les samples de la frame lue dans le buffer input */
@@ -128,7 +132,9 @@ run(Context_t *ctx)
   /* printf("[i] frames restant a lire = %llu\n", frames); */
 
   /* buffer pret, demander les FFT/u_data... */
-  Input_set(ctx->input, A_STEREO);
+  if (!ctx->input->mute) {
+    Input_set(ctx->input, A_STEREO);
+  }
   pthread_mutex_unlock(&ctx->input->mutex);
 
   /* si lecture finie: on recommence ou on exit */
@@ -137,8 +143,9 @@ run(Context_t *ctx)
       VERBOSE(printf("[i] sndfile: restarting stream '%s'\n", file));
 
       /* rewind */
-      if (-1 == sf_seek(sf, 0, SEEK_SET))
-	xerror("sf_seek\n");
+      if (-1 == sf_seek(sf, 0, SEEK_SET)) {
+        xerror("sf_seek\n");
+      }
       frames = sfi.frames;
     } else {
       ctx->running = 0;
