@@ -22,9 +22,9 @@
 u_long id = 1253393977;
 u_long options = BEQ_THREAD;
 
-#define INSIZE	256
-#define FACT	0.40
-#define DEVICE	"/dev/urandom"
+#define INSIZE  256
+#define FACT    0.40
+#define DEVICE  "/dev/urandom"
 
 #define SAMPLES_PER_SECOND  4410.0
 #define MIN_FREQUENCY       80.0
@@ -55,8 +55,9 @@ Rndq(void)
   u_long  a, b;
   ssize_t res;
   res = read(urandfd, (void *)&a, sizeof(u_long));
-  if (res == -1)
+  if (res == -1) {
     xperror("read");
+  }
   b = (~0);
   return (((float)a) / ((float)b));
 }
@@ -82,8 +83,9 @@ Randq(void)
   u_long  a;
   ssize_t res;
   res = read(urandfd, (void *)&a, sizeof(u_long));
-  if (res == -1)
+  if (res == -1) {
     xperror("read");
+  }
   return a;
 }
 
@@ -92,8 +94,9 @@ static inline u_long
 Rand(u_long range)
 {
   u_long  a = Randq();
-  if (range != 0)
+  if (range != 0) {
     a %= range;
+  }
 
   return a;
 }
@@ -109,14 +112,15 @@ Rand(u_long range)
   } <-- unused here */
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   int  i;
 
   urandfd = open(DEVICE, O_RDONLY);
-  if (urandfd == -1)
+  if (urandfd == -1) {
     xerror("Unable to open `%s'\n", DEVICE);
+  }
 
   ctx->input = Input_new(INSIZE);
 
@@ -127,6 +131,8 @@ create(Context_t *ctx)
     speed[i] = RangeRnd(MIN_SPEED, MAX_SPEED);
     xtime[i] = Rndq();
   }
+
+  return 1;
 }
 
 
@@ -134,8 +140,9 @@ void
 destroy(Context_t *ctx)
 {
   Input_delete(ctx->input);
-  if (urandfd != -1)
+  if (urandfd != -1) {
     close(urandfd);
+  }
 }
 
 
@@ -153,51 +160,55 @@ jthread(void *args)
       int  i;
 
       for (i = 0; i < CHANNELS; i++) {
-	float  fr, newfr, sc, sp, t, y;
+        float  fr, newfr, sc, sp, t, y;
 
-	/* get twip values */
-	fr = frequency[i];
-	sc = scale[i];
-	sp = speed[i];
-	t = xtime[i];
+        /* get twip values */
+        fr = frequency[i];
+        sc = scale[i];
+        sp = speed[i];
+        t = xtime[i];
 
-	/* compute sample */
-	smp.sample[i] = sinf(t * 2 * M_PI) * FACT;
+        /* compute sample */
+        smp.sample[i] = sinf(t * 2 * M_PI) * FACT;
 
-	/* modify speed */
-	if (Rand(SAMPLES_PER_SECOND / 100) == nearbyintf(MAX_FREQUENCY / 200)) {
-	  y = RangeRnd(-1, 1) / SAMPLES_PER_SECOND;
-	  sp += y;
-	  if ((sp > MAX_SPEED) || (sp < MIN_SPEED))
-	    sp -= (y * 2);
-	}
+        /* modify speed */
+        if (Rand(SAMPLES_PER_SECOND / 100) == nearbyintf(MAX_FREQUENCY / 200)) {
+          y = RangeRnd(-1, 1) / SAMPLES_PER_SECOND;
+          sp += y;
+          if ((sp > MAX_SPEED) || (sp < MIN_SPEED)) {
+            sp -= (y * 2);
+          }
+        }
 
-	/* modify frequency and/or scale */
-	while (1) {
-	  newfr = powf(2, sc * sp / SAMPLES_PER_SECOND / 12) * fr;
-	  if (newfr < MIN_FREQUENCY)
-	    sc = Rndq();
-	  else if (newfr > MAX_FREQUENCY)
-	    sc = -Rndq();
-	  else if (Rand(SAMPLES_PER_SECOND / 10) == nearbyintf(MAX_FREQUENCY / 20))
-	    sc = RangeRnd(-1, 1);
-	  else
-	    break;
-	}
+        /* modify frequency and/or scale */
+        while (1) {
+          newfr = powf(2, sc * sp / SAMPLES_PER_SECOND / 12) * fr;
+          if (newfr < MIN_FREQUENCY) {
+            sc = Rndq();
+          } else if (newfr > MAX_FREQUENCY) {
+            sc = -Rndq();
+          } else if (Rand(SAMPLES_PER_SECOND / 10) == nearbyintf(MAX_FREQUENCY / 20)) {
+            sc = RangeRnd(-1, 1);
+          } else {
+            break;
+          }
+        }
 
-	/* update twip */
-	frequency[i] = newfr;
-	scale[i] = sc;
-	speed[i] = sp;
-	t += (newfr / SAMPLES_PER_SECOND);
-	xtime[i] = (t - floorf(t));
+        /* update twip */
+        frequency[i] = newfr;
+        scale[i] = sc;
+        speed[i] = sp;
+        t += (newfr / SAMPLES_PER_SECOND);
+        xtime[i] = (t - floorf(t));
       }
       ctx->input->data[A_LEFT ][j] = smp.sample[CHANNEL_LEFT ];
       ctx->input->data[A_RIGHT][j] = smp.sample[CHANNEL_RIGHT];
     }
 
     /* buffer written, build FFTs, etc. */
-    Input_set(ctx->input, A_STEREO);
+    if (!ctx->input->mute) {
+      Input_set(ctx->input, A_STEREO);
+    }
     pthread_mutex_unlock(&ctx->input->mutex);
   }
 
