@@ -29,25 +29,22 @@ char dname[] = "GLCube";
 char desc[] = "OpenGL cube";
 
 static u_char faces[6];
-#ifdef WITH_WEBCAM
-extern int webcams;
-#endif
 
-#define NORMAL(X) do {				\
-    glEnable(GL_COLOR_LOGIC_OP);		\
-    glLogicOp(GL_COPY);				\
-    glBegin(GL_QUADS);				\
-    X;						\
-    glDisable(GL_COLOR_LOGIC_OP);		\
-    glEnd();					\
+#define NORMAL(X) do {            \
+    glEnable(GL_COLOR_LOGIC_OP);  \
+    glLogicOp(GL_COPY);           \
+    glBegin(GL_QUADS);            \
+    X;                            \
+    glDisable(GL_COLOR_LOGIC_OP); \
+    glEnd();                      \
   } while(0)
-#define INVERT(X) do {				\
-    glEnable(GL_COLOR_LOGIC_OP);		\
-    glLogicOp(GL_COPY_INVERTED);		\
-    glBegin(GL_QUADS);				\
-    X;						\
-    glDisable(GL_COLOR_LOGIC_OP);		\
-    glEnd();					\
+#define INVERT(X) do {            \
+    glEnable(GL_COLOR_LOGIC_OP);  \
+    glLogicOp(GL_COPY_INVERTED);  \
+    glBegin(GL_QUADS);            \
+    X;                            \
+    glDisable(GL_COLOR_LOGIC_OP); \
+    glEnd();                      \
   } while(0)
 
 
@@ -55,22 +52,23 @@ extern int webcams;
 #define ZERO 0.0
 #define ONE  1.0
 
-static float CUBE[8][3] =
-  {{ ONE,  ONE, -ONE},   // 1
-   { ONE, -ONE, -ONE},   // 2
-   {-ONE, -ONE, -ONE},
-   {-ONE,  ONE, -ONE},   // 4
-   {-ONE,  ONE,  ONE},
-   { ONE,  ONE,  ONE},   // 6
-   { ONE, -ONE,  ONE},
-   {-ONE, -ONE,  ONE}};
+static float CUBE[8][3] = {
+  { ONE,  ONE, -ONE},   // 1
+  { ONE, -ONE, -ONE},   // 2
+  {-ONE, -ONE, -ONE},
+  {-ONE,  ONE, -ONE},   // 4
+  {-ONE,  ONE,  ONE},
+  { ONE,  ONE,  ONE},   // 6
+  { ONE, -ONE,  ONE},
+  {-ONE, -ONE,  ONE}
+};
 
 #define CE(x) glVertex3fv(CUBE[x-1])
 
 #define coucou(X) face(ctx, X)
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   int e, v;
@@ -79,16 +77,13 @@ create(Context_t *ctx)
   /* scale the cube */
   for (e = 0; e < 8; e++)
     for (v = 0; v < 3; v++)
-      if (v != 1)
-	CUBE[e][v] *= ar;
-      else
-	CUBE[e][v] *= 1.15; /* FIXME empirical tuning */
-}
+      if (v != 1) {
+        CUBE[e][v] *= ar;
+      } else {
+        CUBE[e][v] *= 1.15;  /* FIXME empirical tuning */
+      }
 
-
-void
-destroy(Context_t *ctx)
-{
+  return 1;
 }
 
 
@@ -99,26 +94,58 @@ cube()
   glColor3f(1, 1, 1);
   glLineWidth(2);
   glBegin(GL_LINES);
-  CE(1); CE(2); CE(2); CE(3); CE(3); CE(4);
-  CE(4); CE(5); CE(5); CE(8); CE(8); CE(3);
-  CE(1); CE(6); CE(6); CE(7); CE(7); CE(2);
-  CE(6); CE(5); CE(5); CE(8); CE(8); CE(7);
-  CE(6); CE(1); CE(1); CE(4); CE(4); CE(5);
-  CE(7); CE(2); CE(3); CE(8);
+  CE(1);
+  CE(2);
+  CE(2);
+  CE(3);
+  CE(3);
+  CE(4);
+  CE(4);
+  CE(5);
+  CE(5);
+  CE(8);
+  CE(8);
+  CE(3);
+  CE(1);
+  CE(6);
+  CE(6);
+  CE(7);
+  CE(7);
+  CE(2);
+  CE(6);
+  CE(5);
+  CE(5);
+  CE(8);
+  CE(8);
+  CE(7);
+  CE(6);
+  CE(1);
+  CE(1);
+  CE(4);
+  CE(4);
+  CE(5);
+  CE(7);
+  CE(2);
+  CE(3);
+  CE(8);
   glEnd();
 }
 
 
-static inline void t1() {
+static inline void t1()
+{
   glTexCoord2f(ZERO, ZERO);
 }
-static inline void t2() {
+static inline void t2()
+{
   glTexCoord2f(ZERO, ONE);
 }
-static inline void t3() {
+static inline void t3()
+{
   glTexCoord2f(ONE, ONE);
 }
-static inline void t4() {
+static inline void t4()
+{
   glTexCoord2f(ONE, ZERO);
 }
 
@@ -126,9 +153,9 @@ static inline void t4() {
 void
 get_texture(Context_t *ctx, const u_char face, const u_char rgba)
 {
-  if (rgba)
+  if (rgba) {
     Context_make_GL_RGBA_texture(ctx, face);
-  else {
+  } else {
 #ifdef WITH_WEBCAM
     Context_make_GL_gray_texture(ctx, face);
 #else
@@ -145,72 +172,81 @@ face(Context_t *ctx, const char f)
   case 0: // front face
     get_texture(ctx, ACTIVE_BUFFER, 1);
     NORMAL(
-	   t1(); CE(8);
-	   t2(); CE(5);
-	   t3(); CE(6);
-	   t4(); CE(7));
+      t1(); CE(8);
+      t2(); CE(5);
+      t3(); CE(6);
+      t4(); CE(7));
     break;
 
   case 1: // back face
     get_texture(ctx, ACTIVE_BUFFER, 1);
     INVERT(
-	   t4(); CE(2);
-	   t3(); CE(1);
-	   t2(); CE(4);
-	   t1(); CE(3));
+      t4(); CE(2);
+      t3(); CE(1);
+      t2(); CE(4);
+      t1(); CE(3));
     break;
 
   case 2: // left face
 #ifdef WITH_WEBCAM
-    get_texture(ctx, (webcams >= 2) ? 1 : 0, 0);
+    get_texture(ctx, (ctx->webcams >= 2) ? 1 : 0, 0);
 #else
     get_texture(ctx, 0, 0);
 #endif
     NORMAL(
-	   t4(); CE(3);
-	   t3(); CE(4);
-	   t2(); CE(5);
-	   t1(); CE(8));
+      t4(); CE(3);
+      t3(); CE(4);
+      t2(); CE(5);
+      t1(); CE(8));
     break;
 
   case 3: // right face
     get_texture(ctx, 0, 0);
     if (
 #ifdef WITH_WEBCAM
-	webcams > 1
+      ctx->webcams > 1
 #else
-	1
+      1
 #endif
-	) {
+    ) {
       if (1)
-	NORMAL(
-	       t1(); CE(7);
-	       t2(); CE(6);
-	       t3(); CE(1);
-	       t4(); CE(2));
+        NORMAL(
+          t1(); CE(7);
+          t2(); CE(6);
+          t3(); CE(1);
+          t4(); CE(2));
     } else {
       INVERT(
-	     t1(); CE(7);
-	     t2(); CE(6);
-	     t3(); CE(1);
-	     t4(); CE(2));
+        t1(); CE(7);
+        t2(); CE(6);
+        t3(); CE(1);
+        t4(); CE(2));
     }
     break;
 
   case 4: // up face
-    NORMAL({}); break;
-    t1(); CE(5);
-    t2(); CE(4);
-    t3(); CE(1);
-    t4(); CE(6);
+    NORMAL({});
+    break;
+    t1();
+    CE(5);
+    t2();
+    CE(4);
+    t3();
+    CE(1);
+    t4();
+    CE(6);
     break;
 
 #if 0
   case 5: // bottom face
-    t1(); CE(3);
-    t2(); CE(8);
-    t3(); CE(7);
-    t4(); CE(2);
+    t1();
+    CE(3);
+    t2();
+    CE(8);
+    t3();
+    CE(7);
+    t4();
+    CE(2);
     break;
 #endif
   }
@@ -222,8 +258,9 @@ textures(Context_t *ctx)
 {
   char ibou; /* :) */
 
-  for (ibou = 0; ibou < 6; ibou++)
-    coucou(ibou); /* :) again */
+  for (ibou = 0; ibou < 6; ibou++) {
+    coucou(ibou);  /* :) again */
+  }
 }
 
 
