@@ -41,8 +41,9 @@ run(Context_t *ctx)
     /* u_short value = ((*w++ & 15) + (*c & 15) + (*e++ & 15)) / 3 + 1; */
     u_short value = (*w++ + *c++ + *e++) / 3 + 1;
 
-    if (value >= 256)
+    if (value >= 256) {
       value = 0;
+    }
 
     /* value = (*c & 0x1111000) | value; */
 
