@@ -26,38 +26,23 @@ char desc[] = "Pulsing box";
 
 #define BEAT_BAND 2
 
-
-void
-create(Context_t *ctx)
-{
-  if (NULL == ctx->input)
-    options |= BEQ_DISABLED;
-}
+// FIXME check the log calculations part in input.c
 
 
 void
 run(Context_t *ctx)
 {
-  if (NULL == ctx->input)
-    return;
-
   double max = ctx->input->spectrum_log[A_MONO][BEAT_BAND];
   u_short x1;
 
   if (max > 1.0) {
-#ifdef DEBUG
-    printf("[!] %s: max too HIGH: %f\n", __FILE__, max);
-#endif
     max = 1.0;
   } else if (max < 0.0) {
-#ifdef DEBUG
-    printf("[!] %s: max too LOW: %f\n", __FILE__, max);
-#endif
     max = 0.0;
   }
   x1 = max * MAXX;
 
   draw_filled_box_nc(passive_buffer(ctx),
-		     0, HHEIGHT + (HHEIGHT / 8),
-		     x1, HHEIGHT - (HHEIGHT / 8), 255);
+         0, HHEIGHT + (HHEIGHT / 8),
+         x1, HHEIGHT - (HHEIGHT / 8), 255);
 }
