@@ -18,6 +18,7 @@
  */
 
 #include "context.h"
+#include "image_filter.h"
 
 
 u_long id = 944355800;
@@ -28,30 +29,8 @@ char desc[] = "Blur filter";
 void
 run(Context_t *ctx)
 {
-  const Pixel_t *n, *s, *w, *c, *e;
-  Pixel_t *d;
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
-  u_long i;
 
-  Buffer8_init_mask_3x3(active_buffer(ctx));
-
-  n = src->buffer + 1;
-  s = src->buffer + 2 * WIDTH + 1;
-  w = src->buffer + WIDTH;
-  c = src->buffer + (WIDTH + 1);
-  e = src->buffer + (WIDTH + 2);
-
-  d = dst->buffer + (WIDTH + 1);
-  for (i = BUFFSIZE - WIDTH - (WIDTH + 1); i--; ) {
-    short somme =
-      *n++
-      + (*w++ << 1) + (*c++ << 1) + (*e++ << 1)
-      + *s++;
-    somme >>= 3;
-    somme &= 255;
-    *d++ = (Pixel_t)(somme);
-  }
-
-  Buffer8_expand_border(dst);
+  image_filter_average(dst, src, FT_BLUR2_3x3, BM_TOROIDAL, 0, NULL);
 }
