@@ -42,25 +42,35 @@ run(Context_t *ctx)
       Pixel_t m, n, s, e, w;
       short t;
 
-      m = get_pixel_nc(src, i    , j    );
-      n = get_pixel_nc(src, i    , j - 1);
-      if (n != m) flat = 0;
-      s = get_pixel_nc(src, i    , j + 1);
-      if (s != m) flat = 0;
+      m = get_pixel_nc(src, i, j    );
+      n = get_pixel_nc(src, i, j - 1);
+      if (n != m) {
+        flat = 0;
+      }
+      s = get_pixel_nc(src, i, j + 1);
+      if (s != m) {
+        flat = 0;
+      }
       e = get_pixel_nc(src, i + 1, j    );
-      if (e != m) flat = 0;
+      if (e != m) {
+        flat = 0;
+      }
       w = get_pixel_nc(src, i - 1, j    );
-      if (w != m) flat = 0;
+      if (w != m) {
+        flat = 0;
+      }
 
       t = (n + s + ((e + w + m) << 1)) >> 3;
 
-      if (t < 0)
-	t = drand48() * 256;
+      if (t < 0) {
+        t = drand48() * 256;
+      }
 
-      if (flat)
-	t = bcolor;
-      else
-	bcolor++;
+      if (flat) {
+        t = bcolor;
+      } else {
+        bcolor++;
+      }
 
       set_pixel_nc(dst, i, j, (Pixel_t)(t));
     }
