@@ -18,6 +18,7 @@
  */
 
 #include "context.h"
+#include "image_filter.h"
 
 
 u_long id = 944355802;
@@ -28,21 +29,8 @@ char desc[] = "Blur filter";
 void
 run(Context_t *ctx)
 {
-  Pixel_t *d;
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
-  const Pixel_t *m = src->buffer;
-  const Pixel_t *n = src->buffer + WIDTH;
-  const Pixel_t *o = src->buffer + (2 * WIDTH);
-  long i;
 
-  Buffer8_init_mask_3x3(active_buffer(ctx));
-
-  d = dst->buffer + (WIDTH + 1);
-  for (i = BUFFSIZE - WIDTH - (WIDTH + 1) - 1; i--; m++, n++, o++)
-    *d++ = (*m + (*(m + 1) << 1) + (*m + 2)
-	    + (*n << 1) + (*(n + 1) << 4) + (*(n + 2) << 1)
-	    + *o + (*(o + 1) << 1) + *(o + 2)) >> 5;
-
-  Buffer8_expand_border(dst);
+  image_filter_average(dst, src, FT_BLUR4_3x3, BM_TOROIDAL, 0, NULL);
 }
