@@ -18,6 +18,7 @@
  */
 
 #include "context.h"
+#include "image_filter.h"
 
 
 u_long id = 1103058150;
@@ -29,29 +30,8 @@ char desc[] = "Vertical blur";
 void
 run(Context_t *ctx)
 {
-  u_short i, j;
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
 
-  Buffer8_init_mask_3x3(active_buffer(ctx));
-
-  for (j = 1; j < MAXY - 1; j++)
-    for (i = 1; i < MAXX - 1; i++) {
-      u_short somme;
-      /*
-       * 0 2 0
-       * 1 4 1   => 10
-       * 0 2 0
-       */
-      somme =  get_pixel_nc(src, i - 1, j    );
-      somme += get_pixel_nc(src, i    , j - 1) * 2;
-      somme += get_pixel_nc(src, i    , j    ) * 4;
-      somme += get_pixel_nc(src, i    , j + 1) * 2;
-      somme += get_pixel_nc(src, i + 1, j    );
-      somme /= 10;
-
-      set_pixel_nc(dst, i, j, (Pixel_t)(somme));
-    }
-
-  Buffer8_expand_border(dst);
+  image_filter_average(dst, src, FT_VBLUR_3x3, BM_TOROIDAL, 0, NULL);
 }
