@@ -54,11 +54,13 @@ static Alarm_t *cirrus_alarm = NULL;
 static Shuffler_t *shuffler = NULL;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   cirrus_alarm = Alarm_new(3, 10);
   shuffler = Shuffler_new(NCOLORS);
+
+  return 1;
 }
 
 
