@@ -21,7 +21,7 @@
 
 
 u_long id = 1091656394;
-u_long options = BE_CLEAN|BEQ_FIRST|BEQ_NORANDOM;
+u_long options = BE_CLEAN|BEQ_FIRST;
 u_long mode = NORMAL;
 char desc[] = "Clears the screen";
 
