@@ -56,10 +56,6 @@ run(Context_t *ctx)
   Buffer8_t *dst = passive_buffer(ctx);
   u_short i;
 
-  assert(ctx->input != NULL);
-  if (ctx->input == NULL)
-    return;
-
   Buffer8_clear(dst);
 
   pthread_mutex_lock(&ctx->input->mutex);
@@ -80,7 +76,7 @@ run(Context_t *ctx)
 
     /* if a critter is out of screen, reset it */
     if ((tmp.x < MINX) || (tmp.y < MINY)
-	|| (tmp.x > MAXX) || (tmp.y > MAXY)) {
+         || (tmp.x > MAXX) || (tmp.y > MAXY)) {
       randomize(&critters[i]);
     } else {
       /* update position */
@@ -88,9 +84,8 @@ run(Context_t *ctx)
       critters[i].pos.y = tmp.y;
     }
 
+    pthread_mutex_unlock(&ctx->input->mutex);
   }
-
-  pthread_mutex_unlock(&ctx->input->mutex);
 }
 
 
@@ -99,8 +94,9 @@ randomize_all()
 {
   int i;
 
-  for (i = 0; i < nb_critters; i++)
+  for (i = 0; i < nb_critters; i++) {
     randomize(&critters[i]);
+  }
 }
 
 
@@ -111,27 +107,26 @@ on_switch_on(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL) {
-    options |= BEQ_DISABLED;
-    return;
-  }
-
   nb_critters = ctx->input->size;
 
   critters = xcalloc(nb_critters, sizeof(struct Critter));
-  if (critters == NULL)
+  if (critters == NULL) {
     xerror("pas de critter, trop dure la vie\n");
+  }
 
   randomize_all();
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (critters != NULL)
+  if (critters != NULL) {
     xfree(critters);
+  }
 }
