@@ -66,50 +66,38 @@ get_color(const Input_t *input, const int i, const int j)
   dist = sqrtf(dx + dy + dz + dt);
   dist /= DMAX;
 
-  /* 	return (last_color = (255 - (u_char)(255 * dist))); */
+  /* return (last_color = (255 - (u_char)(255 * dist))); */
   return (255 - (Pixel_t)(255 * dist));
 }
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
   int ii, jj;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  assert(ctx->input != NULL);
-  if (ctx->input == NULL)
-    return;
-
   Buffer8_clear(dst);
 
   pthread_mutex_lock(&ctx->input->mutex);
 
   for (jj = 0; jj < MINSCREEN; jj++) {
     int j = (int)((float)jj
-		  / (float)MINSCREEN
-		  * (float)(ctx->input->size-3.0));
+      / (float)MINSCREEN
+      * (float)(ctx->input->size-3.0));
     int last_i = -1;
     Pixel_t last_c = 0;
 
     for (ii = 0; ii < MINSCREEN; ii++) {
       Pixel_t c = last_c;
       int i = (int)((float)ii
-		    / (float)MINSCREEN
-		    * (float)(ctx->input->size-3.0));
+        / (float)MINSCREEN
+        * (float)(ctx->input->size-3.0));
 
       if (i != last_i) {
-	c = get_color(ctx->input, i, j);
-	last_i = i;
-	last_c = c;
+        c = get_color(ctx->input, i, j);
+        last_i = i;
+        last_c = c;
       }
 
       /* not-optimized plot */
