@@ -40,8 +40,9 @@ const float p = 45.0 / 180.0 * M_PI;
 
 
 static Map_t
-cth_bighalfwheel(u_short i, u_short j)
+cth_bighalfwheel(const short in_x, const short in_y)
 {
+  const u_short i = in_x, j = in_y;
   int dx, dy;
   Map_t m;
 
@@ -55,23 +56,27 @@ cth_bighalfwheel(u_short i, u_short j)
     dist = sqrt((i-cx)*(i-cx) + (j-cy)*(j-cy));
 
     if (i==cx) {
-      if (j>cx)
-	ang = q;
-      else
-	ang = -q;
-    } else
+      if (j>cx) {
+        ang = q;
+      } else {
+        ang = -q;
+      }
+    } else {
       ang = atanf((float)(j-cy)/(i-cx));
+    }
 
-    if (i<cx)
+    if (i<cx) {
       ang += M_PI;
+    }
     if (dist < HEIGHT) {
       dx = ceil(-sinf(ang-p)*dist/10.0);
       dy = ceil(cosf(ang-p)*dist/10.0);
     } else {
-      if (i<cx)
-	dx = 3;
-      else
-	dx = -3;
+      if (i<cx) {
+        dx = 3;
+      } else {
+        dx = -3;
+      }
       dy = 0;
     }
 
@@ -104,10 +109,12 @@ on_switch_on()
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_bighalfwheel = Translation_new(&cth_bighalfwheel, &init_params);
+
+  return 1;
 }
 
 
