@@ -33,7 +33,7 @@ static int xCenter, yCenter;
 
 
 static Map_t
-hurricane(const u_short x, const u_short y)
+hurricane(const short x, const short y)
 {
   int  dx, dy, map_x, map_y;
   int  speedFactor;
@@ -43,8 +43,9 @@ hurricane(const u_short x, const u_short y)
   if (Randomness) {
     speedFactor = b_rand_int_range(0, (Randomness + 1)) - Randomness / 3;
     sp = speed * (100L + speedFactor) / 100L;
-  } else
+  } else {
     sp = speed;
+  }
 
   dx = x - xCenter;
   dy = y - yCenter;
@@ -52,26 +53,21 @@ hurricane(const u_short x, const u_short y)
   if (slowX || slowY) {
     long dSquared = (long)dx*dx + (long)dy*dy + 1;
 
-    if (slowY)
+    if (slowY) {
       dx = (int)(dx * 2500L / dSquared);
-    if (slowX)
+    }
+    if (slowX) {
       dy = (int)(dy * 2500L / dSquared);
+    }
   }
 
-  if (reverse)
+  if (reverse) {
     sp = -sp;
+  }
 
   map_x = (int)(x + (dy * sp) / 700);
   map_y = (int)(y - (dx * sp) / 700);
 
-  while (map_x < 0)
-    map_x += WIDTH;
-  while (map_y < 0)
-    map_y += HEIGHT;
-
-  map_x %= WIDTH;
-  map_y %= HEIGHT;
-
   m.map_x = map_x;
   m.map_y = map_y;
 
@@ -99,10 +95,12 @@ on_switch_on(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_hurricane = Translation_new(&hurricane, &init_params);
+
+  return 1;
 }
 
 
