@@ -31,16 +31,18 @@ static int Speed, Random;
 
 
 static Map_t
-smoke(const u_short x, const u_short y)
+smoke(const short in_x, const short in_y)
 {
+  const u_short x = in_x, y = in_y;
   int map_x, map_y;
   Map_t m;
 
   map_x = x - (5 + b_rand_int_range(0, 12 * Random / 100)) * Speed / 100;
   map_y = y - (5 + b_rand_int_range(0, 12 * Random / 100)) * Speed / 100;
 
-  if (map_y > MAXY || map_y < MINY || map_x > MAXX || map_x < MINX)
+  if (map_y > MAXY || map_y < MINY || map_x > MAXX || map_x < MINX) {
     map_x = map_y = 0;
+  }
 
   m.map_x = map_x;
   m.map_y = map_y;
@@ -50,22 +52,26 @@ smoke(const u_short x, const u_short y)
 
 
 static void
-init_params() {
+init_params()
+{
   Speed = b_rand_int_range(30, 300);
   Random = b_rand_int_range(12, 100);
 }
 
 
 void
-on_switch_on(Context_t *ctx) {
+on_switch_on(Context_t *ctx)
+{
   Translation_batch_init(t_smoke);
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_smoke = Translation_new(&smoke, &init_params);
+
+  return 1;
 }
 
 
