@@ -37,8 +37,9 @@ static int speed = DEFAULT_SPEED;
 
 
 static Map_t
-cth_space(u_short x, u_short y)
+cth_space(const short in_x, const short in_y)
 {
+  const u_short x = in_x, y = in_y;
   int dx, dy, map_x, map_y;
   Map_t m;
 
@@ -48,8 +49,7 @@ cth_space(u_short x, u_short y)
   map_x = (int)((float)(x) - (float)(dx * -speed) / 700.0);
   map_y = (int)((float)(y) - (float)(dy * -speed) / 700.0);
 
-  if ((map_y > MAXY) || (map_y < MINY)
-      || (map_x > MAXX) || (map_x < MINX)) {
+  if ((map_y > MAXY) || (map_y < MINY) || (map_x > MAXX) || (map_x < MINX)) {
     map_x = 0;
     map_y = 0;
   }
@@ -76,10 +76,12 @@ on_switch_on(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_space = Translation_new(&cth_space, &init_params);
+
+  return 1;
 }
 
 
