@@ -38,8 +38,9 @@ const float p = 45.0 / 180.0 * M_PI;
 
 
 static Map_t
-cth_spiral(const u_short i, const u_short j)
+cth_spiral(const short in_x, const short in_y)
 {
+  const u_short i = in_x, j = in_y;
   int dx,dy;
   Map_t m;
 
@@ -53,15 +54,18 @@ cth_spiral(const u_short i, const u_short j)
     dist = sqrt((i-cx)*(i-cx) + (j-cy)*(j-cy));
 
     if (i==cx) {
-      if (j>cx)
-	ang = q;
-      else
-	ang = -q;
-    } else
+      if (j>cx) {
+        ang = q;
+      } else {
+        ang = -q;
+      }
+    } else {
       ang = atan((float)(j-cy)/(i-cx));
+    }
 
-    if (i<cx)
+    if (i<cx) {
       ang += M_PI;
+    }
 
     dx = ceil(-sin(ang-p)*dist/10.0);
     dy = ceil(cos(ang-p)*dist/10.0);
@@ -94,10 +98,12 @@ on_switch_on(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_spiral = Translation_new(&cth_spiral, &init_params);
+
+  return 1;
 }
 
 
