@@ -34,10 +34,11 @@ inc_theta()
 {
   roll_theta += roll_freq;
 
-  if (roll_theta > (2 * M_PI))
+  if (roll_theta > (2 * M_PI)) {
     roll_theta -= 2 * M_PI;
-  else if (roll_theta < (-2 * M_PI))
+  } else if (roll_theta < (-2 * M_PI)) {
     roll_theta += 2 * M_PI;
+  }
 }
 
 
@@ -45,10 +46,11 @@ void
 on_switch_on(Context_t *ctx)
 {
   roll_freq = Input_random_float_range(ctx->input, 0.01, 0.06);
-  if (b_rand_boolean())
+  if (b_rand_boolean()) {
     roll_freq = -roll_freq;
+  }
 #ifdef DEBUG
-    VERBOSE(printf("[i] %s: roll_freq= %f\r\n", __FILE__, roll_freq));
+  VERBOSE(printf("[i] %s: roll_freq= %f\r\n", __FILE__, roll_freq));
 #endif
 }
 
@@ -71,13 +73,16 @@ run(Context_t *ctx)
 
     b %= (2 * HEIGHT);
 
-    if (b < 0)
+    if (b < 0) {
       b += (2 * HEIGHT);
-    if (b >= (short)HEIGHT)
+    }
+    if (b >= (short)HEIGHT) {
       b = 2 * HEIGHT - b - 1;
+    }
 
-    for (i = 0; i < WIDTH; i++)
+    for (i = 0; i < WIDTH; i++) {
       set_pixel_nc(dst, i, j, (get_pixel_nc(src, i, b)));
+    }
   }
 
   inc_theta();
