@@ -88,8 +88,9 @@ Delay2_init_spline(Spline_t *s)
   for (p = ps->particles; p != NULL; p = g_slist_next(p), i++) {
     Particle_t *part = (Particle_t *)p->data;
 
-    if (i > ps->nb_particles)
+    if (i > ps->nb_particles) {
       xerror("FUCK DAMN SHIT i= %li max= %li\n", i, s->nb_cpoints);
+    }
     s->cpoints[i] = part->pos;
   }
 }
@@ -105,57 +106,53 @@ Delay2_draw_spline(Context_t *ctx, Spline_t *s)
 
 #if CONNECT
   /* with LINES */
-  for (i = 0; i < s->nb_spoints-1; i++)
-    draw_line_3d(params3d, dst, &s->spoints[i], &s->spoints[i+1], Input_random_u_char(input));
+  for (i = 0; i < s->nb_spoints-1; i++) {
+    draw_line_3d(params3d, dst, &s->spoints[i], &s->spoints[i+1], Input_random_color(input));
+  }
 #else
   /* with DOTS */
-  for (i = 0; i < s->nb_spoints; i++)
-    set_pixel_3d(params3d, dst, &s->spoints[i], Input_random_u_char(input));
+  for (i = 0; i < s->nb_spoints; i++) {
+    set_pixel_3d(params3d, dst, &s->spoints[i], Input_random_color(input));
+  }
 #endif
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else
-    ps = Particle_System_new(MAX_PARTICLES);
+  ps = Particle_System_new(MAX_PARTICLES);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (ps != NULL)
+  if (ps != NULL) {
     Particle_System_delete(ps);
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (ctx->input != NULL) {
+  if (Plugin_is_enabled(options)) {
     Buffer8_t *dst = passive_buffer(ctx);
 
     Buffer8_clear(dst);
-
     Particle_System_go(ps);
-
     Delay2_generate(ctx->input);
 
     if (ps->nb_particles) {
       Spline_t *spline = NULL;
 
       spline = Spline_new(SPAN_SIZE, ps->nb_particles);
-
       Delay2_init_spline(spline);
-
       Spline_compute(spline);
-
       Delay2_draw_spline(ctx, spline);
-
       Spline_delete(spline);
     }
   }
