@@ -52,8 +52,7 @@ Delay3_particles(Context_t *ctx)
 
     source.pos.x = source.pos.z = 0;
     source.pos.y = Input_random_float_range(input, -1.1, -0.9);
-    /* XXX Input_random_Pixel */
-    col = Input_random_u_char(input);
+    col = Input_random_color(input);
 
     /* TODO si c'est ok *= 0.25 lors de la generation des points de controle
      * de la spline */
@@ -91,37 +90,36 @@ Delay3_init(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL) {
-    options |= BEQ_DISABLED;
-    return;
-  }
-
   ps = Particle_System_new(PS_NOLIMIT);
 
   s = Spline_new(SPAN_SIZE, ctx->input->size - 2);
 #ifdef DEBUG
   Spline_info(s);
 #endif
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (ps != NULL)
+  if (ps != NULL) {
     Particle_System_delete(ps);
-  if (s != NULL)
+  }
+  if (s != NULL) {
     Spline_delete(s);
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (s != NULL) {
+  if (Plugin_is_enabled(options)) {
     Delay3_init(ctx);
     Spline_compute(s);
     Delay3_particles(ctx);
