@@ -40,6 +40,7 @@ run(Context_t *ctx)
 
   Pixel_t *d;
 
-  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH); )
+  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH); ) {
     (*d++) = ((*c++ << 2) - (*n++ + *s++ + *w++ + *e++));
+  }
 }
