@@ -36,6 +36,7 @@ run(Context_t *ctx)
 
   Pixel_t *d;
 
-  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH - 1); )
+  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH - 1); ) {
     *d++ = ((*nw++ - *se++) / 2) + 128;
+  }
 }
