@@ -38,17 +38,20 @@ randomize(Buffer8_t *buff)
 {
   Pixel_t *p = buff->buffer;
 
-  for ( ; p < buff->buffer + BUFFSIZE*sizeof(Pixel_t); p++)
+  for ( ; p < buff->buffer + BUFFSIZE*sizeof(Pixel_t); p++) {
     *p = b_rand_boolean() ? 0 : 255;
+  }
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   game = Buffer8_new();
   game2 = Buffer8_new();
   randomize(game);
+
+  return 1;
 }
 
 
@@ -104,19 +107,19 @@ run(Context_t *ctx)
 
       switch (old) {
       case 0:
-	/* dead cell, becomes alive ? */
-	new = firing(i, j) ? 255 : 0;
-	break;
+        /* dead cell, becomes alive ? */
+        new = firing(i, j) ? 255 : 0;
+        break;
 
       case 255:
-	/* firing cell, keeps firing ? */
-	new = firing(i, j) ? 255 : 254;
-	break;
+        /* firing cell, keeps firing ? */
+        new = firing(i, j) ? 255 : 254;
+        break;
 
       default:
-	/* cell decays */
-	new = old - 2;
-	break;
+        /* cell decays */
+        new = old - 2;
+        break;
       }
 
       set_pixel_nc(game2, i, j, new);
