@@ -132,16 +132,16 @@ typedef struct {
 #define BMIN(a,b)((a)<(b)?(a):(b))
 
 #define BCOUNT 256
-#define NCOL	255
+#define NCOL   255
 
 #define MAXRAND 2147483648.0
 /* Macros */
 #define IX(C)   ((C) * sp->beecount + sp->cnsegs[(C)])
-#define B(t,b)	(*(sp->p + (t) + (b) * sp->taillen))
-#define X(t,b)	B((t),(b)).x
-#define Y(t,b)	B((t),(b)).y
-#define Z(t,b)	B((t),(b)).z
-#define balance_rand(v)	((lrand48()/MAXRAND*(v))-((v)/2))	/* random around 0 */
+#define B(t,b)  (*(sp->p + (t) + (b) * sp->taillen))
+#define X(t,b)  B((t),(b)).x
+#define Y(t,b)  B((t),(b)).y
+#define Z(t,b)  B((t),(b)).z
+#define balance_rand(v)  ((lrand48()/MAXRAND*(v))-((v)/2))  /* random around 0 */
 #define SCALE_X(A) (WIDTH/2+WIDTH/sp->size*(A))
 #define SCALE_Y(A) (HEIGHT/2+HEIGHT/sp->size*(A))
 #define LOST_IN_SPACE (sp->size * 10)
@@ -156,11 +156,11 @@ typedef struct {
   double      size;
   int         taillen;
 
-  int         beecount;	/* number of bees */
-  Line_t   *csegs;	    /* bee lines */
+  int         beecount;  /* number of bees */
+  Line_t     *csegs;     /* bee lines */
   int        *cnsegs;
   double      step;
-  dvector     centre;		/* centre */
+  dvector     centre;    /* centre */
   struct {
     double  depth;
     double  height;
@@ -239,7 +239,7 @@ Duffing(Par par, double x, double y, double z)
 }
 
 #define deallocate(p,t) {free(p); p=(t*)NULL; }
-#define allocate(p,t,s) if ((p=malloc(sizeof(t)*s))==NULL)	\
+#define allocate(p,t,s) if ((p=malloc(sizeof(t)*s))==NULL) \
     {free_flow(sp);return;}
 
 
@@ -286,15 +286,16 @@ on_switch_on(Context_t *ctx)
     /* Change by sqr so its seems more variable */
     sp->taillen = NRAND((int) sqrt((double) (-sp->taillen - MINTRAIL + 1)));
     sp->taillen = sp->taillen * sp->taillen + MINTRAIL;
-  } else if (sp->taillen < MINTRAIL)
+  } else if (sp->taillen < MINTRAIL) {
     sp->taillen = MINTRAIL;
+  }
 
   switch (rand) {
   case 0:
     sp->view.depth = 10;
     sp->view.height = 0.2;
     beemult = 3;
-    /* fallthrough */
+  /* fallthrough */
   case 1:
     sp->ODE = Lorenz;
     sp->step = 0.02;
@@ -313,7 +314,7 @@ on_switch_on(Context_t *ctx)
     sp->view.depth = 10;
     sp->view.height = 0.1;
     beemult = 4;
-    /* fallthrough */
+  /* fallthrough */
   case 3:
     sp->ODE = Rossler;
     sp->step = 0.05;
@@ -332,7 +333,7 @@ on_switch_on(Context_t *ctx)
     sp->view.depth = 10;
     sp->view.height = 0.1;
     beemult = 3;
-    /* fallthrough */
+  /* fallthrough */
   case 5:
     sp->ODE = RosslerCone;
     sp->step = 0.05;
@@ -387,9 +388,11 @@ on_switch_on(Context_t *ctx)
     break;
   }
 
-  if (sp) free_flow(sp); /* beecount changes with beemult */
+  if (sp) {
+    free_flow(sp);  /* beecount changes with beemult */
+  }
   sp->beecount = (int) (beemult * BCOUNT);
-  if (sp->beecount < 0) {	/* random variations */
+  if (sp->beecount < 0) {                    /* random variations */
     sp->beecount = NRAND(-sp->beecount) + 1; /* Minimum 1 */
   }
 
@@ -412,11 +415,13 @@ on_switch_on(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   changeme = b_timer_new();
   on_switch_on(ctx);
+
+  return 1;
 }
 
 
@@ -436,10 +441,11 @@ run(Context_t *ctx)
   Buffer8_clear(dst);
 
   sp = &flow;
-  if (sp->csegs == NULL)
+  if (sp->csegs == NULL) {
     return;
+  }
 
-  if(!sp->view.depth){ /* simple 3D tumble */
+  if(!sp->view.depth) { /* simple 3D tumble */
     double      sint, cost, sinp, cosp;
     sp->tumble.theta += sp->tumble.dtheta;
     sp->tumble.phi += sp->tumble.dphi;
@@ -447,35 +453,49 @@ run(Context_t *ctx)
     cost = cos(sp->tumble.theta);
     sinp = sin(sp->tumble.phi);
     cosp = cos(sp->tumble.phi);
-    M[0][0]= cost; M[0][1]=-sint*cosp; M[0][2]= sint*sinp;
-    M[1][0]= sint; M[1][1]= cost*cosp; M[1][2]=-cost*sinp;
-    M[2][0]= 0;    M[2][1]= 0;         M[2][2]= 1;
+    M[0][0]= cost;
+    M[0][1]=-sint*cosp;
+    M[0][2]= sint*sinp;
+    M[1][0]= sint;
+    M[1][1]= cost*cosp;
+    M[1][2]=-cost*sinp;
+    M[2][0]= 0;
+    M[2][1]= 0;
+    M[2][2]= 1;
   } else { /* initialize matrix */
-    M[0][0]= 0; M[0][1]= 0; M[0][2]= 0;
-    M[1][0]= 0; M[1][1]= 0; M[1][2]= 0;
-    M[2][0]= 0; M[2][1]= 0; M[2][2]= 0;
+    M[0][0]= 0;
+    M[0][1]= 0;
+    M[0][2]= 0;
+    M[1][0]= 0;
+    M[1][1]= 0;
+    M[1][2]= 0;
+    M[2][0]= 0;
+    M[2][1]= 0;
+    M[2][2]= 0;
 
   }
 
-  for (col = 0; col < NCOL; col++)
+  for (col = 0; col < NCOL; col++) {
     sp->cnsegs[col] = 0;
+  }
 
   /* <=- Bees -=> */
   for (b = 0; b < sp->beecount; b++) {
     if(fabs(X(0, b)) > LOST_IN_SPACE ||
-       fabs(Y(0, b)) > LOST_IN_SPACE ||
-       /* if z is always invisible it's probably time */
-       fabs(Z(0, b)) > ((sp->tumble.dphi!=0 ||
-			 sp->tumble.phi!=0)?LOST_IN_SPACE:LOST_IN_TIME)){
-      if(sp->view.depth && b==0){ /* lost camera - reset */
-	create(ctx);
-	return;
+        fabs(Y(0, b)) > LOST_IN_SPACE ||
+        /* if z is always invisible it's probably time */
+        fabs(Z(0, b)) > ((sp->tumble.dphi!=0 ||
+                          sp->tumble.phi!=0)?LOST_IN_SPACE:LOST_IN_TIME)) {
+      if(sp->view.depth && b==0) { /* lost camera - reset */
+        (void)create(ctx);
+        return;
       }
       continue;
     }
     /* Age the tail. */
-    for(i = sp->taillen - 1; i > 0; i--)
+    for(i = sp->taillen - 1; i > 0; i--) {
       B(i, b) = B(i-1, b);
+    }
 
     /* 2nd order Kunge Kutta */
     {
@@ -500,54 +520,59 @@ run(Context_t *ctx)
     /* Fill the segment lists. */
 
     if(sp->view.depth) { /* perspective view has special points */
-      if(b==0){ /* point of view */
-	sp->centre.x=X(0, b);
-	sp->centre.y=Y(0, b);
-	sp->centre.z=Z(0, b);
-      }else if(b==1){ /* neighbour: used to compute local axes */
-	double x[3], p[3], x2=0, xp=0;
-	int j;
+      if(b==0) { /* point of view */
+        sp->centre.x=X(0, b);
+        sp->centre.y=Y(0, b);
+        sp->centre.z=Z(0, b);
+      } else if(b==1) { /* neighbour: used to compute local axes */
+        double x[3], p[3], x2=0, xp=0;
+        int j;
 
-	/* forward */
-	x[0] = X(0, 0) - X(1, 0);
-	x[1] = Y(0, 0) - Y(1, 0);
-	x[2] = Z(0, 0) - Z(1, 0);
+        /* forward */
+        x[0] = X(0, 0) - X(1, 0);
+        x[1] = Y(0, 0) - Y(1, 0);
+        x[2] = Z(0, 0) - Z(1, 0);
 
-	/* neighbour */
-	p[0] = X(0, 1) - X(1, 0);
-	p[1] = Y(0, 1) - Y(1, 0);
-	p[2] = Z(0, 1) - Z(1, 0);
+        /* neighbour */
+        p[0] = X(0, 1) - X(1, 0);
+        p[1] = Y(0, 1) - Y(1, 0);
+        p[2] = Z(0, 1) - Z(1, 0);
 
-	for(i=0; i<3; i++){
-	  x2+= x[i]*x[i];    /* X . X */
-	  xp+= x[i]*p[i];    /* X . P */
-	  M[0][i] = x[i];    /* X */
-	}
+        for(i=0; i<3; i++) {
+          x2+= x[i]*x[i];    /* X . X */
+          xp+= x[i]*p[i];    /* X . P */
+          M[0][i] = x[i];    /* X */
+        }
 
-	for(i=0; i<3; i++)               /* (X x P) x X */
-	  M[1][i] = x2*p[i] - xp*x[i]; /* == (X . X) P - (X . P) X */
+        for(i=0; i<3; i++) {             /* (X x P) x X */
+          M[1][i] = x2*p[i] - xp*x[i];  /* == (X . X) P - (X . P) X */
+        }
 
-	M[2][0] =  x[1]*p[2] - x[2]*p[1]; /* X x P */
-	M[2][1] = -x[0]*p[2] + x[2]*p[0];
-	M[2][2] =  x[0]*p[1] - x[1]*p[0];
+        M[2][0] =  x[1]*p[2] - x[2]*p[1]; /* X x P */
+        M[2][1] = -x[0]*p[2] + x[2]*p[0];
+        M[2][2] =  x[0]*p[1] - x[1]*p[0];
 
-	/* normalise axes */
-	for(j=0; j<3; j++){
-	  double A=0;
-	  for(i=0; i<3; i++) A+=M[j][i]*M[j][i]; /* sum squares */
-	  A=sqrt(A);
-	  for(i=0; i<3; i++) M[j][i]/=A;
-	}
+        /* normalise axes */
+        for(j=0; j<3; j++) {
+          double A=0;
+          for(i=0; i<3; i++) {
+            A+=M[j][i]*M[j][i];  /* sum squares */
+          }
+          A=sqrt(A);
+          for(i=0; i<3; i++) {
+            M[j][i]/=A;
+          }
+        }
 
-	X(0, 1)=X(0, 0)+M[1][0]; /* adjust neighbour */
-	Y(0, 1)=Y(0, 0)+M[1][1];
-	Z(0, 1)=Z(0, 0)+M[1][2];
+        X(0, 1)=X(0, 0)+M[1][0]; /* adjust neighbour */
+        Y(0, 1)=Y(0, 0)+M[1][1];
+        Z(0, 1)=Z(0, 0)+M[1][2];
       }
     }
 
     begin = 0; /* begin new trail */
     end = BMIN(sp->taillen, sp->count);
-    for(i=0; i < end; i++){
+    for(i=0; i < end; i++) {
       double x=X(i,b)-sp->centre.x;
       double y=Y(i,b)-sp->centre.y;
       double z=Z(i,b)-sp->centre.z;
@@ -555,32 +580,32 @@ run(Context_t *ctx)
       double YM=M[1][0]*x + M[1][1]*y + M[1][2]*z;
       double ZM=M[2][0]*x + M[2][1]*y + M[2][2]*z+sp->view.height;
       double absx, absy;
-      if(sp->view.depth){
-	if(XM <= 0){
-	  /* off screen - new trail */
-	  begin = i + 1;
-	  continue;
-	}
-	absx=SCALE_X(sp->view.depth*YM/XM);
-	absy=SCALE_Y(sp->view.depth*ZM/XM);
-      }else{
-	absx=SCALE_X(XM);
-	absy=SCALE_Y(YM);
+      if(sp->view.depth) {
+        if(XM <= 0) {
+          /* off screen - new trail */
+          begin = i + 1;
+          continue;
+        }
+        absx=SCALE_X(sp->view.depth*YM/XM);
+        absy=SCALE_Y(sp->view.depth*ZM/XM);
+      } else {
+        absx=SCALE_X(XM);
+        absy=SCALE_Y(YM);
       }
       if(absx <= 0 || absx >= WIDTH ||
-	 absy <= 0 || absy >= HEIGHT) {
-	/* off screen - new trail */
-	begin = i + 1;
-	continue;
+          absy <= 0 || absy >= HEIGHT) {
+        /* off screen - new trail */
+        begin = i + 1;
+        continue;
       }
       if(i > begin) {  /* complete previous segment */
-	sp->csegs[IX(col)].x2 = (short) absx;
-	sp->csegs[IX(col)].y2 = (short) absy;
-	sp->cnsegs[col]++;
+        sp->csegs[IX(col)].x2 = (short) absx;
+        sp->csegs[IX(col)].y2 = (short) absy;
+        sp->cnsegs[col]++;
       }
-      if(i < end -1){  /* start new segment */
-	sp->csegs[IX(col)].x1 = (short) absx;
-	sp->csegs[IX(col)].y1 = (short) absy;
+      if(i < end -1) { /* start new segment */
+        sp->csegs[IX(col)].x1 = (short) absx;
+        sp->csegs[IX(col)].y1 = (short) absy;
       }
     }
   }
@@ -588,15 +613,15 @@ run(Context_t *ctx)
   for (col = 0; col < NCOL; col++) {
     if (sp->cnsegs[col] > 0)
       for (b = 0; b < sp->cnsegs[col]; b++) {
-	/*Line *l = &sp->csegs[b] + col * sp->beecount;*/
-	Line_t *l = &sp->csegs[sp->beecount * col + b];
-	/*if ((l->x1 > 0) && (l->x1 < WIDTH))*/
-	/*
-	 * if ((l->x1 < MINX) || (l->x1 > MAXX) || (l->y1 < MINY) || (l->y1 > MAXY)
-	 || (l->x2 < MINX) || (l->x2 > MAXX) || (l->y2 < MINY) || (l->y2 > MAXY))
-	 continue;
-	*/
-	draw(dst, l, (Pixel_t)col);
+        /*Line *l = &sp->csegs[b] + col * sp->beecount;*/
+        Line_t *l = &sp->csegs[sp->beecount * col + b];
+        /*if ((l->x1 > 0) && (l->x1 < WIDTH))*/
+        /*
+         * if ((l->x1 < MINX) || (l->x1 > MAXX) || (l->y1 < MINY) || (l->y1 > MAXY)
+         || (l->x2 < MINX) || (l->x2 > MAXX) || (l->y2 < MINY) || (l->y2 > MAXY))
+         continue;
+        */
+        draw(dst, l, (Pixel_t)col);
       }
     /*draw_line_3d (Buffer8_t *, const Point3d *, const Point3d *, const guchar);*/
   }
@@ -604,8 +629,9 @@ run(Context_t *ctx)
 
   if(++sp->count > 512)*/
   ++sp->count;
-  if (b_timer_elapsed(changeme) > 30)
+  if (b_timer_elapsed(changeme) > 30) {
     on_switch_on(ctx);
+  }
 }
 
 
