@@ -29,8 +29,6 @@
  *
  */
 
-/* end blabla intro */
-
 /* You first need to include this file */
 #include "context.h"
 
@@ -41,35 +39,44 @@
  * command in the shell */
 u_long id = 944338581;
 
-u_long options = BE_GFX \
-  | BEQ_UNIQUE		\
-  | BEQ_NORANDOM;
+/* options */
+u_long options = BE_GFX|BEQ_UNIQUE;
 
+/* default layer mode */
 u_long mode = OVERLAY;
 
+/* display name in the OSD */
 char dname[] = "The foo plugin";
 
+/* description for the OSD when plugin is selected */
 char desc[] = "Basic/demo plugin";
 
 
 static u_short x, y;
 
 
-void
+// you don't have to define this function if unneeded
+int8_t
 create(Context_t *ctx)
 {
+  // here goes the code when the plugin is loaded
   x = CENTERX;
   y = CENTERY;
+
+  // return 1 on success, 0 if the plugin failed to initialize
+  return 1;
 }
 
 
+// you don't have to define this function if unneeded
 void
 destroy(Context_t *ctx)
 {
-
+  // here goes the code when the plugin is unloaded
 }
 
 
+// the main plugin function
 void
 run(Context_t *ctx)
 {
@@ -77,46 +84,49 @@ run(Context_t *ctx)
   u_short steps, s;
   Buffer8_t *dst;
 
-  if (ctx->input == NULL)
-    return;
-
   steps = (u_short)(drand48() * 100);
   dst = passive_buffer(ctx);
 
   Buffer8_clear(dst);
 
+  // make sure to lock/unlock the input mutex if the plugin uses audio buffers
   pthread_mutex_lock(&ctx->input->mutex);
 
-  if (drand48() < .5)
+  if (drand48() < .5) {
     for (s = 0; s < steps; s++) {
       Pixel_t c = ctx->input->data_u[A_MONO][idx] * 255;
 
       set_pixel_nc(dst, x++, y, c);
 
       if (x == WIDTH) {
-	x = 0;
-	if (++y == HEIGHT)
-	  y = 0;
+        x = 0;
+        if (++y == HEIGHT) {
+          y = 0;
+        }
       }
 
-      if (++idx == ctx->input->size)
-	idx = 0;
+      if (++idx == ctx->input->size) {
+        idx = 0;
+      }
     }
-  else
+  } else {
     for (s = 0; s < steps; s++) {
       Pixel_t c = ctx->input->data_u[A_MONO][idx] * 255;
 
       set_pixel_nc(dst, x, y++, c);
 
       if (y == HEIGHT) {
-	y = 0;
-	if (++x == WIDTH)
-	  x = 0;
+        y = 0;
+        if (++x == WIDTH) {
+          x = 0;
+        }
       }
 
-      if (++idx == ctx->input->size)
-	idx = 0;
+      if (++idx == ctx->input->size) {
+        idx = 0;
+      }
     }
+  }
 
   pthread_mutex_unlock(&ctx->input->mutex);
 }
