@@ -28,11 +28,11 @@ char desc[] = "Galaxy effect";
 /* Compatibility with the xlockmore RNG API
    (note that the xlockmore hacks never expect negative numbers.)
 */
-#define LRAND()			((long) (random() & 0x7fffffff))
-#define NRAND(n)		((int) (LRAND() % (n)))
-#define MAXRAND			(2147483648.0) /* unsigned 1<<31 as a float */
-#define SRAND(n)		/* already seeded by screenhack.c */
-#define NUMCOLORS               256
+#define LRAND()   ((long) (random() & 0x7fffffff))
+#define NRAND(n)  ((int) (LRAND() % (n)))
+#define MAXRAND   (2147483648.0) /* unsigned 1<<31 as a float */
+#define SRAND(n)  /* already seeded by screenhack.c */
+#define NUMCOLORS 256
 
 /* Originally done by Uli Siegmund <uli@wombat.okapi.sub.org> on Amiga
  *   for EGS in Cluster
@@ -73,21 +73,18 @@ static u_char tracks;
 
 #define DEF_TRACKS "True"
 
-static XrmOptionDescRec opts[] =
-  {
-    {"-tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "on"},
-    {"+tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "off"}
-  };
+static XrmOptionDescRec opts[] = {
+  {"-tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "on"},
+  {"+tracks", ".galaxy.tracks", XrmoptionNoArg, (caddr_t) "off"}
+};
 
-static argtype vars[] =
-  {
-    {(caddr_t *) & tracks, "tracks", "Tracks", DEF_TRACKS, t_Bool}
-  };
+static argtype vars[] = {
+  {(caddr_t *) & tracks, "tracks", "Tracks", DEF_TRACKS, t_Bool}
+};
 
-static OptionStruct desc[] =
-  {
-    {"-/+tracks", "turn on/off star tracks"}
-  };
+static OptionStruct desc[] = {
+  {"-/+tracks", "turn on/off star tracks"}
+};
 
 ModeSpecOpt galaxy_opts = { 2, opts, 1, vars, desc };
 #endif
@@ -121,8 +118,7 @@ ModeSpecOpt galaxy_opts = { 2, opts, 1, vars, desc };
 
 #define COLORBASE  16
 /* Colors for stars start here */
-#define COLORSTEP  (NUMCOLORS/COLORBASE) /* NUMCOLORS / COLORBASE colors
-					    per galaxy */
+#define COLORSTEP  (NUMCOLORS/COLORBASE) /* NUMCOLORS / COLORBASE colors per galaxy */
 
 
 typedef struct {
@@ -151,10 +147,8 @@ typedef struct {
   int         f_hititerations; /* # iterations before restart */
   int         step; /* */
 #if 0
-  double      rot_y; /* rotation of eye around center of universe, around
-			y-axis*/
-  double      rot_x; /* rotation of eye around center of universe, around
-			x-axis */
+  double      rot_y; /* rotation of eye around center of universe, around y-axis */
+  double      rot_x; /* rotation of eye around center of universe, around x-axis */
 #endif
 } unistruct;
 
@@ -172,9 +166,9 @@ free_galaxies(unistruct * gp)
 
       free(gt->stars);
       /*   if (gt->oldpoints != NULL)
-	   (void) free((void *) gt->oldpoints);*/
+      (void) free((void *) gt->oldpoints);*/
       /*   if (gt->newpoints != NULL)
-	   (void) free((void *) gt->newpoints);*/
+      (void) free((void *) gt->newpoints);*/
     }
     (void) free((void *) gp->galaxies);
     gp->galaxies = NULL;
@@ -199,21 +193,25 @@ startover()
   /* if (MI_BATCHCOUNT(mi) < -MINGALAXIES)*/
   free_galaxies(gp);
   /* gp->ngalaxies = MI_BATCHCOUNT(mi);*/
-  if (gp->ngalaxies < -MINGALAXIES)
+  if (gp->ngalaxies < -MINGALAXIES) {
     gp->ngalaxies = NRAND(-gp->ngalaxies - MINGALAXIES + 1) + MINGALAXIES;
+  }
 
-  else if (gp->ngalaxies < MINGALAXIES)
+  else if (gp->ngalaxies < MINGALAXIES) {
     gp->ngalaxies = MINGALAXIES;
-  if (gp->galaxies == NULL)
+  }
+  if (gp->galaxies == NULL) {
     gp->galaxies = xcalloc(gp->ngalaxies, sizeof(Galaxy));
+  }
 
   for (i = 0; i < gp->ngalaxies; ++i) {
     Galaxy     *gt = &gp->galaxies[i];
     double      sinw1, sinw2, cosw1, cosw2;
 
     gt->galcol = NRAND(COLORBASE - 2);
-    if (gt->galcol > 1)
-      gt->galcol += 2; /* Mult 8; 16..31 no green stars */
+    if (gt->galcol > 1) {
+      gt->galcol += 2;  /* Mult 8; 16..31 no green stars */
+    }
     /* Galaxies still may have some green stars but are not all green. */
 
     free(gt->stars);
@@ -262,22 +260,23 @@ startover()
       cosw = cos(w);
       d = FLOATRAND * gp->size;
       h = FLOATRAND * exp(-2.0 * (d / gp->size)) / 5.0 * gp->size;
-      if (FLOATRAND < 0.5)
-	h = -h;
+      if (FLOATRAND < 0.5) {
+        h = -h;
+      }
       st->pos[0] = gp->mat[0][0] * d * cosw + gp->mat[1][0] * d * sinw +
-	gp->mat[2][0] * h + gt->pos[0];
+                   gp->mat[2][0] * h + gt->pos[0];
       st->pos[1] = gp->mat[0][1] * d * cosw + gp->mat[1][1] * d * sinw +
-	gp->mat[2][1] * h + gt->pos[1];
+                   gp->mat[2][1] * h + gt->pos[1];
       st->pos[2] = gp->mat[0][2] * d * cosw + gp->mat[1][2] * d * sinw +
-	gp->mat[2][2] * h + gt->pos[2];
+                   gp->mat[2][2] * h + gt->pos[2];
 
       v = sqrt(gt->mass * QCONS / sqrt(d * d + h * h));
       st->vel[0] = -gp->mat[0][0] * v * sinw + gp->mat[1][0] * v * cosw +
-	gt->vel[0];
+                   gt->vel[0];
       st->vel[1] = -gp->mat[0][1] * v * sinw + gp->mat[1][1] * v * cosw +
-	gt->vel[1];
+                   gt->vel[1];
       st->vel[2] = -gp->mat[0][2] * v * sinw + gp->mat[1][2] * v * cosw +
-	gt->vel[2];
+                   gt->vel[2];
 
       st->vel[0] *= DELTAT;
       st->vel[1] *= DELTAT;
@@ -287,7 +286,7 @@ startover()
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   unistruct  *gp;
@@ -305,6 +304,8 @@ create(Context_t *ctx)
   gp->midx =  HWIDTH;
   gp->midy =  HHEIGHT;
   startover(/*mi*/);
+
+  return 1;
 }
 
 
@@ -343,19 +344,20 @@ run(Context_t *ctx)
       double      v2 = st->vel[2];
 
       for (k = 0; k < gp->ngalaxies; ++k) {
-	Galaxy     *gtk = &gp->galaxies[k];
-	double      d0 = gtk->pos[0] - st->pos[0];
-	double      d1 = gtk->pos[1] - st->pos[1];
-	double      d2 = gtk->pos[2] - st->pos[2];
+        Galaxy     *gtk = &gp->galaxies[k];
+        double      d0 = gtk->pos[0] - st->pos[0];
+        double      d1 = gtk->pos[1] - st->pos[1];
+        double      d2 = gtk->pos[2] - st->pos[2];
 
-	d = d0 * d0 + d1 * d1 + d2 * d2;
-	if (d > EPSILON)
-	  d = gt->mass / (d * sqrt(d)) * DELTAT * DELTAT * QCONS;
-	else
-	  d = gt->mass * eps;
-	v0 += d0 * d;
-	v1 += d1 * d;
-	v2 += d2 * d;
+        d = d0 * d0 + d1 * d1 + d2 * d2;
+        if (d > EPSILON) {
+          d = gt->mass / (d * sqrt(d)) * DELTAT * DELTAT * QCONS;
+        } else {
+          d = gt->mass * eps;
+        }
+        v0 += d0 * d;
+        v1 += d1 * d;
+        v2 += d2 * d;
       }
 
       st->vel[0] = v0;
@@ -367,12 +369,12 @@ run(Context_t *ctx)
       st->pos[2] += v2;
 
       /*
-	newp->x = (short) (((cox * st->pos[0]) - (six * st->pos[2])) *
-	gp->scale) + gp->midx;
-	newp->y = (short) (((cor * st->pos[1]) - (sir * ((six * st->pos[0]) +
-	(cox * st->pos[2])))) * gp->scale) + gp->midy;
-	xclip (&newp->x);
-	yclip (&newp->y);
+      newp->x = (short) (((cox * st->pos[0]) - (six * st->pos[2])) *
+      gp->scale) + gp->midx;
+      newp->y = (short) (((cor * st->pos[1]) - (sir * ((six * st->pos[0]) +
+      (cox * st->pos[2])))) * gp->scale) + gp->midy;
+      xclip (&newp->x);
+      yclip (&newp->y);
       */
     }
 
@@ -383,10 +385,11 @@ run(Context_t *ctx)
       double      d2 = gtk->pos[2] - gt->pos[2];
 
       d = d0 * d0 + d1 * d1 + d2 * d2;
-      if (d > EPSILON)
-	d = gt->mass * gt->mass / (d * sqrt(d)) * DELTAT * QCONS;
-      else
-	d = gt->mass * gt->mass / (EPSILON * sqrt_EPSILON) * DELTAT * QCONS;
+      if (d > EPSILON) {
+        d = gt->mass * gt->mass / (d * sqrt(d)) * DELTAT * QCONS;
+      } else {
+        d = gt->mass * gt->mass / (EPSILON * sqrt_EPSILON) * DELTAT * QCONS;
+      }
 
       d0 *= d;
       d1 *= d;
@@ -424,8 +427,9 @@ run(Context_t *ctx)
   }
 
   gp->step++;
-  if (gp->step > gp->f_hititerations * 4)
+  if (gp->step > gp->f_hititerations * 4) {
     startover();
+  }
 }
 
 
