@@ -32,14 +32,6 @@ char desc[] = "Pulse pictures";
 static const Image8_t *pic = NULL;
 
 
-void
-create(Context_t *ctx)
-{
-  if ((images == NULL) || !images->size)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 on_switch_on(Context_t *ctx)
 {
@@ -55,26 +47,25 @@ run(Context_t *ctx)
   float volume;
   u_long p, k;
 
-  if ((ctx->input == NULL) || (options & BEQ_DISABLED))
-    return;
-
   img = pic->buff;
   volume = Input_get_volume(ctx->input);
   //volume = expf(volume)/expf(1.0);
   // printf("Vol= %f\n", volume);
   p = (u_long)(volume * BUFFSIZE  * 1);
 
-    if (p > 100000)
-	pic = Images_random(images);
+  if (p > 100000) {
+    pic = Images_random(images);
+  }
 
 #if 1
   for (k = 0; k < BUFFSIZE; k++) {
     uint32_t rnd = b_rand_int_range(0, BUFFSIZE);
     //    printf("%i ", rnd);
-    if (rnd <= p)
-      dst->buffer[k] = img->buffer[k]; /* TODO from image */
-    else
-      dst->buffer[k] = 0; //src->buffer[k];
+    if (rnd <= p) {
+      dst->buffer[k] = img->buffer[k];  /* TODO from image */
+    } else {
+      dst->buffer[k] = 0;  //src->buffer[k];
+    }
   }
 #else
   for (k = 0; k < BUFFSIZE; k++) {
