@@ -38,7 +38,7 @@ typedef struct {
 
 typedef struct {
   u_char nb_fct;
-  void   (*new)(struct Context_s *);	        /* constructor */
+  void   (*new)(struct Context_s *); /* constructor */
   t_complex (*fct)(t_complex, guint32, gint32, gint32);
   vector_field_t *vector_field;
 } VectorField_t;
@@ -52,7 +52,7 @@ struct args_s {
 
 static void
 compute_generate_sector(guint32 g, guint32 f, guint32 p1, guint32 p2,
-			guint32 debut, guint32 step, VectorField_t *vf)
+                        guint32 debut, guint32 step, VectorField_t *vf)
 {
   vector_field_t *vector_field = vf->vector_field;
   const guint32 width = (guint32)vector_field->width;
@@ -63,8 +63,9 @@ compute_generate_sector(guint32 g, guint32 f, guint32 p1, guint32 p2,
   guint32 fin = debut + step;
   guint32 cx, cy;
 
-  if (fin > height)
+  if (fin > height) {
     fin = height;
+  }
 
   for (cy = debut; cy < fin; cy++)
     for (cx = 0; cx < width; cx++) {
@@ -73,7 +74,7 @@ compute_generate_sector(guint32 g, guint32 f, guint32 p1, guint32 p2,
       guint32 rw, lw, add;
       guint32 w1, w2, w3, w4;
       guint32 x, y;
-	    
+
       a.x = (gfloat)cx;
       a.y = (gfloat)cy;
       a = vf->fct(a, f, p1, p2);
@@ -88,9 +89,8 @@ compute_generate_sector(guint32 g, guint32 f, guint32 p1, guint32 p2,
       w4 = (guint32)(fpy * rw);
       w2 = rw - w4;
       w3 = (guint32)(fpy * lw);
-      w1 = lw - w3; 
-      vector[b_add + add].weight = \
-	(w1 << 24) | (w2 << 16) | (w3 << 8) | w4;
+      w1 = lw - w3;
+      vector[b_add + add].weight = (w1 << 24) | (w2 << 16) | (w3 << 8) | w4;
     }
 }
 
@@ -101,8 +101,9 @@ compute_generate_vector_field_loop(void *ptr)
   struct args_s *args = (struct args_s *)ptr;
   guint32 i;
 
-  for (i = 0; i < args->height; i += 10)
+  for (i = 0; i < args->height; i += 10) {
     compute_generate_sector(args->f, args->f, 2, 2, i, 10, args->vf);
+  }
 
   xfree(args);
   pthread_exit(NULL);
@@ -147,7 +148,7 @@ vector_field_t *
 VectorField_vector_field_new(const u_char nb_fct)
 {
   vector_field_t *field;
-  
+
   field = g_new0(vector_field_t, 1);
   field->vector = g_new0(t_interpol, BUFFSIZE * nb_fct);
   field->width = WIDTH;
@@ -184,7 +185,7 @@ VectorField_delete(VectorField_t *vf)
 
 
 void
-VectorField_compute_surface(Context_t *ctx, t_interpol *vector, gint32 width, gint32 height) 
+VectorField_compute_surface(Context_t *ctx, t_interpol *vector, gint32 width, gint32 height)
 {
   gint32 i,j;
   gint32 add_dest = 0;
@@ -194,20 +195,21 @@ VectorField_compute_surface(Context_t *ctx, t_interpol *vector, gint32 width, gi
   guint32 color;
   Pixel_t *surface1 = active_buffer(ctx)->buffer;
   Pixel_t *surface2 = passive_buffer(ctx)->buffer;
-  
+
   for (j = 0; j < height; j++)
     for (i = 0; i < width; i++) {
       interpol = &vector[add_dest];
       add_src = (interpol->coord & 0xFFFF) * width + (interpol->coord >> 16);
       ptr_pix = &((Pixel_t *)surface1)[add_src];
       color = ((guint32)(*(ptr_pix)) * (interpol->weight >> 24)
-	       + (guint32)(*(ptr_pix+1)) * ((interpol->weight & 0xFFFFFF) >> 16)
-	       + (guint32)(*(ptr_pix+width)) * ((interpol->weight & 0xFFFF) >> 8)
-	       + (guint32)(*(ptr_pix+width+1)) * (interpol->weight & 0xFF)) >> 8;
-      if (color > 255)
-	surface2[add_dest] = (Pixel_t)255;
-      else
-	surface2[add_dest] = (Pixel_t)color;
+               + (guint32)(*(ptr_pix+1)) * ((interpol->weight & 0xFFFFFF) >> 16)
+               + (guint32)(*(ptr_pix+width)) * ((interpol->weight & 0xFFFF) >> 8)
+               + (guint32)(*(ptr_pix+width+1)) * (interpol->weight & 0xFF)) >> 8;
+      if (color > 255) {
+        surface2[add_dest] = (Pixel_t)255;
+      } else {
+        surface2[add_dest] = (Pixel_t)color;
+      }
       add_dest++;
     }
 }
@@ -218,7 +220,7 @@ VectorField_run(VectorField_t *vf, Context_t *ctx, u_long vector_index)
 {
   vector_index *= BUFFSIZE;
   VectorField_compute_surface(ctx, &(vf->vector_field->vector[vector_index]),
-			      vf->vector_field->width, vf->vector_field->height);
+                              vf->vector_field->width, vf->vector_field->height);
 }
 
 #endif /* __INFINITY_H */
