@@ -20,34 +20,38 @@
 #ifndef __SHAKER_H
 #define __SHAKER_H
 
-#define SOUND_DISTURB_K 32
+#define SOUND_DISTURB_K 127
 
 static inline void
 check_width(short *value)
 {
-  if (*value < 0)
+  if (*value < 0) {
     *value += WIDTH;
-  else if (*value >= (short)WIDTH)
+  } else if (*value >= (short)WIDTH) {
     *value -= WIDTH;
+  }
 }
 
 static inline void
 check_height(short *value)
 {
-  if (*value < 0)
+  if (*value < 0) {
     *value += HEIGHT;
-  else if (*value >= (short)HEIGHT)
+  } else if (*value >= (short)HEIGHT) {
     *value -= HEIGHT;
+  }
 }
 
 static inline void
 displace(const Buffer8_t *src, Buffer8_t *dst,
-	 short i, short j, short dx, short dy)
+         short i, short j, short dx, short dy)
 {
-  if ((i < SOUND_DISTURB_K) || (i > MAXX - SOUND_DISTURB_K))
+  if ((i < SOUND_DISTURB_K) || (i > MAXX - SOUND_DISTURB_K)) {
     check_width(&dx);
-  if ((j < SOUND_DISTURB_K) || (j > MAXY - SOUND_DISTURB_K))
+  }
+  if ((j < SOUND_DISTURB_K) || (j > MAXY - SOUND_DISTURB_K)) {
     check_height(&dy);
+  }
   set_pixel_nc(dst, i, j, get_pixel_nc(src, dx, dy));
 }
 
