@@ -135,14 +135,9 @@ fct(t_complex a, guint32 n, gint32 p1, gint32 p2)   /* p1 et p2:0-4 */
   b.x += HWIDTH;
   b.y += HHEIGHT;
 
-  if (b.x < 0.0 )
-    b.x = 0.0;
-  if (b.y < 0.0)
-    b.y = 0.0;
-  if (b.x > (gfloat)MAXX)
-    b.x = (gfloat)MAXX;
-  if (b.y > (gfloat)MAXY)
-    b.y = (gfloat)MAXY;
+  /* because infinity access pixels at (b.x + 1, b.y + 1) */
+  b.x = MIN( MAX(b.x, 0), MAXX-1);
+  b.y = MIN( MAX(b.y, 0), MAXY-1);
 
   return b;
 }
@@ -155,12 +150,14 @@ static Shuffler_t *shuffler = NULL;
 static VectorField_t *vf = NULL;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   vf = VectorField_new(NB_FCT, &fct);
   timer = b_timer_new();
   shuffler = Shuffler_new(NB_FCT);
+
+  return 1;
 }
 
 
@@ -188,6 +185,7 @@ run(Context_t *ctx)
   VectorField_run(vf, ctx, num_effect);
 
   /* TODO remove hardcoded 5 seconds delay */
-  if (b_timer_elapsed(timer) > 5)
+  if (b_timer_elapsed(timer) > 5) {
     on_switch_on(ctx);
+  }
 }
