@@ -31,14 +31,6 @@ char desc[] = "Random image squares";
 #define SQUARES_PER_TURN  10
 
 
-void
-create(Context_t *ctx)
-{
-  if ((images == NULL) || !images->size)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
@@ -56,8 +48,7 @@ run(Context_t *ctx)
 
     for (j = 0; j < SQUARE_SIZE; j++)
       for (i = 0; i < SQUARE_SIZE; i++)
-	set_pixel_nc(dst,
-		     sx+i, sy+j,
-		     get_pixel_nc(ctx->imgf->cur->buff, sx+i, sy+j));
+        set_pixel_nc(dst, sx+i, sy+j,
+                     get_pixel_nc(ctx->imgf->cur->buff, sx+i, sy+j));
   }
 }
