@@ -33,16 +33,18 @@ run(Context_t *ctx)
 
   int x, y;
 
-  for (x = 0; x < WIDTH; x++)
+  for (x = 0; x < WIDTH; x++) {
     set_pixel_nc(dst, x, 0, get_pixel_nc(src, x, 0));
+  }
 
   for (y = 1; y < HEIGHT; y++) {
     for (x = 0; x < WIDTH; x++) {
       Pixel_t c = get_pixel_nc(src, x, y);
       int y2 = y - (c >> 5);
 
-      if (y2 < 0)
-	y2 = 0;
+      if (y2 < 0) {
+        y2 = 0;
+      }
 
       set_pixel_nc(dst, x, y, c/2);
       set_pixel_nc(dst, x, y2, c);
