@@ -57,8 +57,9 @@ ok(Context_t *ctx)
   max_size = ((WIDTH % p) || (HEIGHT % p)) ? p * 2 : p;
   max_size = MIN(max_size, MAX_SIZE);
 
-  if ((p == WIDTH) || (p == HEIGHT) || (p == 1))
+  if ((p == WIDTH) || (p == HEIGHT) || (p == 1)) {
     return 0;
+  }
 
 #ifdef DEBUG
   VERBOSE(printf("[i] mosaic: max_size= %d\n", max_size));
@@ -68,14 +69,15 @@ ok(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ok(ctx))
+  if (ok(ctx)) {
     on_switch_on(ctx);
-  else {
+    return 1;
+  } else {
     VERBOSE(printf("[!] mosaic: non-standard screen size, disabling plugin.\n"));
-    options |= BEQ_DISABLED;
+    return 0;
   }
 }
 
@@ -100,33 +102,33 @@ mosaic(Context_t *ctx)
 static void
 expand()
 {
-  if (size > max_size)
+  if (size > max_size) {
     mode = SHRINK;
-  else
+  } else {
     size += 2;
+  }
 }
 
 
 static void
 shrink()
 {
-  if (size == 2)
+  if (size == 2) {
     mode = EXPAND;
-  else
+  } else {
     size -= 2;
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (max_size == -1)
-    return;
-
   mosaic(ctx);
 
-  if (mode == EXPAND)
+  if (mode == EXPAND) {
     expand();
-  else if (mode == SHRINK)
+  } else if (mode == SHRINK) {
     shrink();
+  }
 }
