@@ -37,14 +37,14 @@ init(const u_short startx, const u_short starty,
      short distx, short disty, u_char delta, const int reversed)
 {
   u_short donex, doney;
-  u_short x = startx, y = starty;
+  short x = startx, y = starty;
 
   while ((distx >= 0) || (disty >= 0)) {
     /* horizontal line: S----->E */
     for (donex = 0; donex < distx; donex++) {
       /*      if (xinc == 1) {
-	u_short dx;
-	for (dx = 0; dx < SWIDTH; dx++)
+      u_short dx;
+      for (dx = 0; dx < SWIDTH; dx++)
       */
       DST(x,y) = SRC(x,y);
       x += xinc;
@@ -66,13 +66,15 @@ init(const u_short startx, const u_short starty,
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   map = xcalloc(BUFFSIZE, sizeof(u_long));
 
   init(0, 0, +1, +1, MAXSCREEN-2, MINSCREEN-2, 2, 0);
   init(MAXX, MAXY, -1, -1, MAXSCREEN-2, MINSCREEN-2, 2, 1);
+
+  return 1;
 }
 
 
@@ -90,6 +92,7 @@ run(Context_t *ctx)
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
 
-  for (k = 0; k < BUFFSIZE; k++)
+  for (k = 0; k < BUFFSIZE; k++) {
     dst->buffer[k] = src->buffer[map[k]];
+  }
 }
