@@ -26,23 +26,12 @@ u_long mode = OVERLAY;
 char desc[] = "3D Archimedean spiral";
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
   static float t  = 0;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (ctx->input == NULL)
-    return;
-
   Buffer8_clear(dst);
 
   float random = Input_get_volume(ctx->input);
@@ -54,6 +43,6 @@ run(Context_t *ctx)
     P.pos.y = random * expf(0.15 * t) * sinf(2 * t);
     P.pos.z = -1 + random * expf(0.15 * t);
 
-    set_pixel_3d(&ctx->params3d, dst, &P, Input_random_u_char(ctx->input));
+    set_pixel_3d(&ctx->params3d, dst, &P, Input_random_color(ctx->input));
   }
 }
