@@ -26,35 +26,24 @@ u_long mode = OVERLAY;
 char desc[] = "Pulsing spiral";
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
   static Pixel_t c = 0;
   int i, j;
-  float x, y, /*z,*/ theta, phi, r, d , x1 , x2 , x3 = 5;
+  float x, y, /*z,*/ theta, phi, r, d, x1, x2, x3 = 5;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (ctx->input == NULL)
-    return;
-
   Buffer8_clear(dst);
 
   x1 = Input_get_volume(ctx->input) * WIDTH; /* Nb de pts par droite */
   x2 = 0.3 + ctx->input->data[A_MONO][((int)x1 % ctx->input->size)];
 
   for (i = 0; i < WIDTH; i++) {
-    theta = i / 20.0;         /* Rotation angle */
+    theta = i / 20.0;   /* Rotation angle */
 
-    r = expf(theta*x2);        /* Distance from axis  */
-    d = 0.33 * r;		  /* Radius relative to r (involute/evolute) */
+    r = expf(theta*x2); /* Distance from axis  */
+    d = 0.33 * r;       /* Radius relative to r (involute/evolute) */
     /* For ornament, add a periodic function to d */
     for (j = 0; j < 30; j++) {
       phi = 2.0 * M_PI *j / x3;
