@@ -39,14 +39,17 @@ run(Context_t *ctx)
   dst = passive_buffer(ctx);
 
   for (j = MAXY; j >= MINY; j--) {
-    for (d = delta; d < MAXX; d++)
+    for (d = delta; d < MAXX; d++) {
       set_pixel_nc(dst, d + 1, j, get_pixel_nc(src, d - delta + 1, j));
+    }
 
-    for (e = 0; e < delta; e++)
+    for (e = 0; e < delta; e++) {
       set_pixel_nc(dst, e + 1, j, get_pixel_nc(src, MAXX - delta + e + 1, j));
+    }
 
-    if (!(y % a))
+    if (!(y % a)) {
       delta++;
+    }
 
     y++;
   }
