@@ -39,14 +39,6 @@ on_switch_off(Context_t *ctx)
 #define L 6 //8
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
@@ -64,30 +56,29 @@ run(Context_t *ctx)
      a mon avis ca pecho pas les bonnes datas dans le spectrum
   */
 
-  assert(ctx->input != NULL);
-  if (ctx->input == NULL)
-    return;
-
   for (i = 1; i <= L; i++)
     //somme += ctx->input->spectrum_log_norme[A_MONO][i];
-    somme += ctx->input->spectrum[A_MONO][i];
+    {
+      somme += ctx->input->spectrum[A_MONO][i];
+    }
   somme /= L;
 
   /* FIXME */
   /*
-     if (somme < log_min_norme_2)
-     somme = log_min_norme_2;
-     else
-     if (somme > log_max_norme_2)
-     somme = log_max_norme_2;
+    if (somme < log_min_norme_2)
+    somme = log_min_norme_2;
+    else
+    if (somme > log_max_norme_2)
+    somme = log_max_norme_2;
   */
   /* tentative de fix */
   /* log_max_norme_2 c'etait un mauvais nom, log_max_norme plutot ? */
   // printf("somme1= %f ", somme);
 
 #ifdef XDEBUG
-  if ((somme < 0) || (somme > ctx->input->max_spectrum[A_MONO]))
+  if ((somme < 0) || (somme > ctx->input->max_spectrum[A_MONO])) {
     printf("[!] pulse: strange somme= %f\n", somme);
+  }
 #endif
 
   /*
@@ -112,11 +103,11 @@ run(Context_t *ctx)
 
     for ( ; ((i < 256) && (val > 0)); (i++, l -= K)) {
       ctx->cf->cur->colors[i].col.r =
-	PMIN((u_short)(ctx->cf->dst->colors[i].col.r + l), (u_short)(255));
+        PMIN((u_short)(ctx->cf->dst->colors[i].col.r + l), (u_short)(255));
       ctx->cf->cur->colors[i].col.g =
-	PMIN((u_short)(ctx->cf->dst->colors[i].col.g + l), (u_short)(255));
+        PMIN((u_short)(ctx->cf->dst->colors[i].col.g + l), (u_short)(255));
       ctx->cf->cur->colors[i].col.b =
-	PMIN((u_short)(ctx->cf->dst->colors[i].col.b + l), (u_short)(255));
+        PMIN((u_short)(ctx->cf->dst->colors[i].col.b + l), (u_short)(255));
     }
 
     for ( ; i < 256; i++) {
