@@ -1,5 +1,6 @@
 /*
  *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 2019 Laurent Marsac
  *
  *  This file is part of lebiniou.
  *
@@ -19,22 +20,45 @@
 
 #include "context.h"
 
-
 u_long id = 957202985;
-u_long options = BE_WARP|BE_LENS;
+u_long options = BE_WARP | BE_LENS;
 char desc[] = "Ripple effect";
 
-/*
- * FIXME precompute the tables at startup
- * or when parameters will change --oliv3
- */
+#define RIPPLE_SIZE_MAX 50
+
+static float *ripple = NULL;
+
+
+int8_t
+create(Context_t *ctx)
+{
+  ripple = xcalloc(RIPPLE_SIZE_MAX * HEIGHT * WIDTH, sizeof(float));
+
+  const float s = sqrtf((WIDTH * WIDTH) + (HEIGHT * HEIGHT));
+
+  for (int n = 0; n < RIPPLE_SIZE_MAX; n++)
+    for (int j = -HHEIGHT; j < HHEIGHT; j++)
+      for (int i = -HWIDTH; i < HWIDTH; i++) {
+        float dist = sqrtf((i * i) + (j * j));
+        float sd = sinf(dist * M_PI * n / s);
+        ripple[n * HEIGHT * WIDTH + (j + HHEIGHT) * WIDTH + (i + HWIDTH)] = sd;
+      }
+
+  return 1;
+}
+
+
+void
+destroy(Context_t *ctx)
+{
+  xfree(ripple);
+}
 
 
 void
 run(Context_t *ctx)
 {
   short j, i;
-  const float s = sqrtf((WIDTH * WIDTH) + (HEIGHT * HEIGHT));
   const float zoom_fact = 0.9;
   const float ripple_fact = 0.1;
   static u_short ripple_size = 8;
@@ -47,19 +71,17 @@ run(Context_t *ctx)
   Buffer8_clear_border(src);
 
   for (j = -HHEIGHT; j < HHEIGHT; j++) {
-    for (i = -HWIDTH; i < HWIDTH; i++)  {
-      float dist = sqrtf((i*i) + (j*j)), sd;
-      int si=0, sj=0;
+    for (i = -HWIDTH; i < HWIDTH; i++) {
 
-      dist *= M_PI * ripple_size / s;
-      sd = sinf(dist);
+      int si = 0, sj = 0;
 
+      float sd = ripple[ripple_size * HEIGHT * WIDTH + (j + HHEIGHT) * WIDTH + (i + HWIDTH)];
       si = (int)(di * (zoom_fact + (ripple_fact * sd)));
       sj = (int)(dj * (zoom_fact + (ripple_fact * sd)));
 
       if ((si < MINX) || (si > MAXX) || (sj < MINY) || (sj > MAXY)) {
-	si = HWIDTH;
-	sj = HHEIGHT;
+        si = HWIDTH;
+        sj = HHEIGHT;
       }
 
       set_pixel_nc(dst, di, dj, get_pixel_nc(src, si, sj));
@@ -70,10 +92,12 @@ run(Context_t *ctx)
   }
 
   if (dir == 1) {
-    if (++ripple_size == 49)
+    if (++ripple_size == 49) {
       dir = -1;
+    }
   } else { /* -1 */
-    if (--ripple_size == 1)
+    if (--ripple_size == 1) {
       dir = 1;
+    }
   }
 }
