@@ -50,30 +50,30 @@ init()
   t.v_i.x = (2.0 / (float)(P->size - 1) * (float)RADIUS) * cos (alpha);
   t.v_i.y = (2.0 / (float)(P->size - 1) * (float)RADIUS) * sin (alpha);
 
-  for (i = 0; i < P->size; i++)
+  for (i = 0; i < P->size; i++) {
     P->trans[i] = t;
+  }
 
   Porteuse_init_alpha (P);
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    P = Porteuse_new(ctx->input->size, A_MONO);
-    init ();
-  }
+  P = Porteuse_new(ctx->input->size, A_MONO);
+  init ();
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (P != NULL)
+  if (P != NULL) {
     Porteuse_delete (P);
+  }
 }
 
 
@@ -87,16 +87,14 @@ on_switch_on(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  if (P == NULL)
-    return;
-
   Buffer8_clear(passive_buffer(ctx));
   Porteuse_draw(P, ctx, connect);
 
   /* FIXME hardcoded */
   alpha += 0.005;
 
-  if (alpha > 2*M_PI)
+  if (alpha > 2*M_PI) {
     alpha -= 2*M_PI;
+  }
   init();
 }
