@@ -53,8 +53,9 @@ change_params()
     sin1_freq += sin1_freq_inc;
     if (sin1_freq > sin1_target_freq) {
       float new_freq = rnd_freq();
-      while (new_freq >= sin1_freq)
-	new_freq = rnd_freq();
+      while (new_freq >= sin1_freq) {
+        new_freq = rnd_freq();
+      }
       sin1_freq_inc = -(drand48() / 10 + .01);
       sin1_target_freq = new_freq;
     }
@@ -62,8 +63,9 @@ change_params()
     sin1_freq += sin1_freq_inc;
     if (sin1_freq < sin1_target_freq) {
       float new_freq = rnd_freq();
-      while (new_freq <= sin1_freq)
-	new_freq = rnd_freq();
+      while (new_freq <= sin1_freq) {
+        new_freq = rnd_freq();
+      }
       sin1_freq_inc = drand48() / 10 + .01;
       sin1_target_freq = new_freq;
     }
@@ -101,26 +103,25 @@ init(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    P = Porteuse_new(ctx->input->size, A_MONO);
-    sin1_freq = sin1_freq_min;
-    sin1_target_freq = rnd_freq();
-    sin1_freq_inc = drand48() / 10 + .01;
-    init(ctx);
-  }
+  P = Porteuse_new(ctx->input->size, A_MONO);
+  sin1_freq = sin1_freq_min;
+  sin1_target_freq = rnd_freq();
+  sin1_freq_inc = drand48() / 10 + .01;
+  init(ctx);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (P != NULL)
+  if (P != NULL) {
     Porteuse_delete(P);
+  }
 }
 
 
@@ -134,9 +135,6 @@ on_switch_on(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  if (P == NULL)
-    return;
-
   Buffer8_clear(passive_buffer(ctx));
   Porteuse_draw(P, ctx, connect);
   change_params();
