@@ -53,8 +53,9 @@ change_params()
     sin2_freq += sin2_freq_inc;
     if (sin2_freq > sin2_target_freq) {
       float new_freq = rnd_freq();
-      while (new_freq >= sin2_freq)
-	new_freq = rnd_freq();
+      while (new_freq >= sin2_freq) {
+        new_freq = rnd_freq();
+      }
       sin2_freq_inc = -(drand48() / 10 + .01);
       sin2_target_freq = new_freq;
     }
@@ -62,8 +63,9 @@ change_params()
     sin2_freq += sin2_freq_inc;
     if (sin2_freq < sin2_target_freq) {
       float new_freq = rnd_freq();
-      while (new_freq <= sin2_freq)
-	new_freq = rnd_freq();
+      while (new_freq <= sin2_freq) {
+        new_freq = rnd_freq();
+      }
       sin2_freq_inc = drand48() / 10 + .01;
       sin2_target_freq = new_freq;
     }
@@ -87,7 +89,7 @@ init(Context_t *ctx)
 
   for (i = 0; i < P->size; i++) {
     float y = (t.v_j_factor
-	       * sin (sin2_freq * (float)i /(float)(ctx->input->size - 1) + sin2_phi));
+               * sin (sin2_freq * (float)i /(float)(ctx->input->size - 1) + sin2_phi));
 
     t.v_before.x = 0;
     t.v_before.y = y;
@@ -103,38 +105,33 @@ init(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    P = Porteuse_new(ctx->input->size, A_MONO);
-    sin2_freq = sin2_freq_min;
-    sin2_target_freq = rnd_freq();
-    sin2_freq_inc = drand48() / 10 + .01;
-    init(ctx);
-  }
+  P = Porteuse_new(ctx->input->size, A_MONO);
+  sin2_freq = sin2_freq_min;
+  sin2_target_freq = rnd_freq();
+  sin2_freq_inc = drand48() / 10 + .01;
+  init(ctx);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (P != NULL)
+  if (P != NULL) {
     Porteuse_delete(P);
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (P == NULL)
-    return;
-
   Buffer8_clear(passive_buffer(ctx));
   Porteuse_draw(P, ctx, connect);
-
   change_params();
   init(ctx);
 }
