@@ -62,49 +62,40 @@ fct(t_complex a, guint32 n, gint32 p1, gint32 p2)
   b.x += HWIDTH;
   b.y += HHEIGHT;
 
-  if (b.x < 0.0 )
-    b.x = 0.0;
-  else if (b.x > (float)MAXX)
-    b.x = (float)MAXX;
-  if (b.y < 0.0)
-    b.y = 0.0;
-  else if (b.y > (float)MAXY)
-    b.y = (float)MAXY;
+  /* because infinity access pixels at (b.x + 1, b.y + 1) */
+  b.x = MIN( MAX(b.x, 0), MAXX-1);
+  b.y = MIN( MAX(b.y, 0), MAXY-1);
 
   return b;
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else
-    vf = VectorField_new(NB_FCT, &fct);
+  vf = VectorField_new(NB_FCT, &fct);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (vf != NULL)
+  if (vf != NULL) {
     VectorField_delete(vf);
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  u_char volume = 0;
+  u_char volume = volume = (u_char)(Input_get_volume(ctx->input) * 10);
 
-  if (ctx->input == NULL)
-    return;
-
-  volume = (u_char)(Input_get_volume(ctx->input) * 10);
-
-  if (volume >= NB_FCT)
+  if (volume >= NB_FCT) {
     volume = NB_FCT-1;
+  }
 
   VectorField_run(vf, ctx, volume);
 }
