@@ -18,6 +18,7 @@
  */
 
 #include "context.h"
+#include "../include/spectrum.h"
 
 
 u_long id = 1051738767;
@@ -29,44 +30,22 @@ char desc[] = "Display the spectrum";
 static u_short *v_start = NULL, *v_end = NULL;
 
 
-inline static u_short float_to_ushort(float x, u_short minval, u_short maxval)
-{
-  u_short n;
-  x = floor(x); /* rounded to lower int */
-  if (x < minval)
-    n = minval;
-  else if (x > maxval)
-    n = maxval;
-  else
-    n = (ushort)x;
-  return n;
-}
-
-
-inline static u_short float_to_nearest_ushort(float x, u_short minval, u_short maxval)
-{
-  return float_to_ushort(x + 0.5 /* will be rounded to nearest int */, minval, maxval);
-}
-
-
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    u_short k;
-    float da_log;
+  u_short k;
+  float da_log;
 
-    v_start = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
-    v_end   = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
+  v_start = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
+  v_end   = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
 
-    da_log = logf(ctx->input->spectrum_size - 1) / logf(10.0);
-    for (k = 1; k < ctx->input->spectrum_size; k++) {
-      v_start[k] = float_to_nearest_ushort( logf((float) k) / logf(10.0) / da_log * MAXX, 0, MAXX);
-      v_end[k]   = float_to_nearest_ushort(log1p((float) k) / logf(10.0) / da_log * MAXX, 0, MAXX); /* log1p(x)=logf(x+1) */
-    }
+  da_log = logf(ctx->input->spectrum_size - 1) / logf(10.0);
+  for (k = 1; k < ctx->input->spectrum_size; k++) {
+    v_start[k] = float_to_nearest_ushort( logf((float) k) / logf(10.0) / da_log * MAXX, 0, MAXX);
+    v_end[k]   = float_to_nearest_ushort(log1p((float) k) / logf(10.0) / da_log * MAXX, 0, MAXX); /* log1p(x)=logf(x+1) */
   }
+
+  return 1;
 }
 
 
@@ -84,10 +63,6 @@ run(Context_t *ctx)
   Buffer8_t *dst;
   u_short i;
 
-  /* should not happen, safety check */
-  if (NULL == ctx->input)
-    return;
-
   dst = passive_buffer(ctx);
   Buffer8_clear(dst);
 
@@ -103,4 +78,3 @@ run(Context_t *ctx)
   }
   pthread_mutex_unlock(&ctx->input->mutex);
 }
-
