@@ -42,32 +42,31 @@ on_switch_on(Context_t *ctx)
 {
   u_long i;
 
-  splashing = 1;
-  for (i = 0; i < WIDTH; i++)
+  for (i = 0; i < WIDTH; i++) {
     splash_map[i] = 0;
-  for ( ; i < BUFFSIZE-WIDTH; i++)
+  }
+  for ( ; i < BUFFSIZE-WIDTH; i++) {
     splash_map[i] = (u_long)(WIDTH + drand48 () * (BUFFSIZE-WIDTH));
-  for ( ; i < BUFFSIZE; i++)
+  }
+  for ( ; i < BUFFSIZE; i++) {
     splash_map[i] = 0;
+  }
 
   b_timer_start(step_splash_timer);
   b_timer_start(splash_timer);
-
   splashing = 1;
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (images == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    splash_map = xcalloc(BUFFSIZE, sizeof(u_long));
-    dst_splash_map = xcalloc(BUFFSIZE, sizeof(u_long));
-    step_splash_timer = b_timer_new();
-    splash_timer = b_timer_new();
-  }
+  splash_map = xcalloc(BUFFSIZE, sizeof(u_long));
+  dst_splash_map = xcalloc(BUFFSIZE, sizeof(u_long));
+  step_splash_timer = b_timer_new();
+  splash_timer = b_timer_new();
+
+  return 1;
 }
 
 
@@ -105,16 +104,18 @@ splash_blur()
     dst_splash_map[i] = (u_long)sum;
   }
 
-  for (i = WIDTH; i < BUFFSIZE-WIDTH; i++)
+  for (i = WIDTH; i < BUFFSIZE-WIDTH; i++) {
     splash_map[i] = dst_splash_map[i];
+  }
 }
 
 
 static void
 splash_check_splash()
 {
-  if (b_timer_elapsed(splash_timer) > MAX_SPLASH)
+  if (b_timer_elapsed(splash_timer) > MAX_SPLASH) {
     splashing = 0;
+  }
 }
 
 
@@ -127,16 +128,13 @@ splash(Context_t *ctx)
   /* FIXME Optimize */
   for (i = 0; i < BUFFSIZE; i++)
     dst->buffer[i] = (u_long)((src->buffer[splash_map[i]]
-			       + ctx->imgf->cur->buff->buffer[splash_map[i]]) / 2);
+                               + ctx->imgf->cur->buff->buffer[splash_map[i]]) / 2);
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (NULL == images)
-    return;
-
   if (splashing == 1) {
     if (b_timer_elapsed(step_splash_timer) > SPLASH_TIMESLICE) {
       splash_blur();
@@ -144,6 +142,7 @@ run(Context_t *ctx)
       b_timer_start(step_splash_timer);
     }
     splash(ctx);
-  } else
+  } else {
     Buffer8_copy(active_buffer(ctx), passive_buffer(ctx));
+  }
 }
