@@ -27,7 +27,7 @@ char desc[] = "Tunnel effect";
 static u_long *tunnel;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   u_short di, dj, start;
@@ -40,7 +40,7 @@ create(Context_t *ctx)
     length = HEIGHT - 2 * start;
     for (dj = start; dj < (HEIGHT - start); dj++) {
       tunnel[dj * WIDTH + di] = tunnel[(HEIGHT - 1 - dj) * WIDTH + (WIDTH - 1 - di)] =
-      (u_long)((u_short)((float)(dj - start) / length * (float)HEIGHT) * WIDTH + (2 * di));
+                                  (u_long)((u_short)((float)(dj - start) / length * (float)HEIGHT) * WIDTH + (2 * di));
     }
   }
 
@@ -49,9 +49,11 @@ create(Context_t *ctx)
     length = WIDTH - 2 * start;
     for (di = start; di < (WIDTH - start); di++) {
       tunnel[dj * WIDTH + (WIDTH - 1 - di)] = tunnel[(HEIGHT - 1 - dj) * WIDTH + di] =
-        (u_long)((u_short)((float)(di - start) / length * (float)HEIGHT) * WIDTH + ((float)(dj * 2) / HEIGHT) * WIDTH);
+          (u_long)((u_short)((float)(di - start) / length * (float)HEIGHT) * WIDTH + ((float)(dj * 2) / HEIGHT) * WIDTH);
     }
   }
+
+  return 1;
 }
 
 
@@ -71,6 +73,7 @@ run(Context_t *ctx)
 
   Buffer8_init_mask_3x3(active_buffer(ctx));
 
-  for (k = 0; k < BUFFSIZE; k++)
+  for (k = 0; k < BUFFSIZE; k++) {
     dst->buffer[k] = src->buffer[tunnel[k]];
+  }
 }
