@@ -28,18 +28,15 @@ u_long mode = OVERLAY;
 static int line = 0;
 static int prevline = 0;
 static Pixel_t *linebuf = NULL;
-extern int webcams;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (!webcams)
-    options |= BEQ_DISABLED;
-  else {
-    line = MAXY;
-    linebuf = xcalloc(WIDTH, sizeof(Pixel_t));
-  }
+  line = MAXY;
+  linebuf = xcalloc(WIDTH, sizeof(Pixel_t));
+
+  return 1;
 }
 
 
@@ -71,20 +68,19 @@ run(Context_t *ctx)
   Pixel_t *src = NULL;
   Pixel_t *dst = passive_buffer(ctx)->buffer;
 
-  if (!webcams)
-    return;
-
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   src = ctx->cam_save[ctx->cam][0]->buffer;
   blitline_buf(src, dst);
   pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
-  if (line)
+  if (line) {
     line--;
-  else
+  } else {
     line = MAXY;
+  }
 
   dst += WIDTH * line;
-  for (i = 0; i < WIDTH; i++)
+  for (i = 0; i < WIDTH; i++) {
     dst[i] = 127;
+  }
 }
