@@ -21,19 +21,10 @@
 
 
 u_long id = 1329763807;
-u_long options = BE_GFX|BEQ_IMAGE|BEQ_MUTE_CAM|BEQ_NORANDOM;
+u_long options = BE_GFX|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "DiffTV";
 u_long mode = OVERLAY;
 
-extern int webcams;
-
-void
-create(Context_t *ctx)
-{
-  if (!webcams)
-    options |= BEQ_DISABLED;
-}
-
 
 void
 on_switch_on(Context_t *ctx)
@@ -47,15 +38,13 @@ run(Context_t *ctx)
 {
   Pixel_t *src1, *start, *src2, *dst;
 
-  if (!webcams)
-    return;
-
   dst = start = passive_buffer(ctx)->buffer;
 
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   src1 = ctx->cam_save[ctx->cam][0]->buffer;
   src2 = ctx->cam_ref[ctx->cam]->buffer;
-  for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++)
+  for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
     *dst = abs(*src1 - *src2);
+  }
   pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
