@@ -40,25 +40,20 @@ u_long mode = OVERLAY;
 #define PLANES 8
 
 static Buffer8_t *nervous = NULL;
-extern int webcams;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (!webcams)
-    options |= BEQ_DISABLED;
-  else
-    if (PLANES > CAM_SAVE) {
-      printf("[!] NervousTV: not enough frames (%d, want %d)\n", CAM_SAVE, PLANES);
-      options |= BEQ_DISABLED;
-    } else {
-      uint32_t i;
+  uint32_t i;
 
-      nervous = Buffer8_new();
-      for (i = 0; i < BUFFSIZE; i++)
-	nervous->buffer[i] = b_rand_int_range(0, PLANES-1);
-    }
+  assert(PLANES <= CAM_SAVE);
+  nervous = Buffer8_new();
+  for (i = 0; i < BUFFSIZE; i++) {
+    nervous->buffer[i] = b_rand_int_range(0, PLANES-1);
+  }
+
+  return 1;
 }
 
 
@@ -77,14 +72,12 @@ run(Context_t *ctx)
   Buffer8_t *src = NULL;
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (!webcams)
-    return;
-
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   src = ctx->cam_save[ctx->cam][nervous->buffer[r]];
   Buffer8_copy(src, dst);
   pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
-  if (++r == BUFFSIZE)
+  if (++r == BUFFSIZE) {
     r = 0;
+  }
 }
