@@ -36,16 +36,14 @@ u_long mode = OVERLAY;
 #define MAGIC_THRESHOLD 40
 
 static Buffer8_t *diff = NULL;
-extern int webcams;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (!webcams)
-    options |= BEQ_DISABLED;
-  else
-    diff = Buffer8_new();
+  diff = Buffer8_new();
+
+  return 1;
 }
 
 
@@ -72,9 +70,6 @@ run(Context_t *ctx)
   Pixel_t *dst;
   uint16_t x, y;
 
-  if (!webcams)
-    return;
-
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   src1 = ctx->cam_save[ctx->cam][0];
   src2 = ctx->cam_ref[ctx->cam];
@@ -89,10 +84,11 @@ run(Context_t *ctx)
 
   for (y = 1; y < MAXY; y++) {
     for (x = 0; x < WIDTH; x++) {
-      if (*d)
-	*dst = src[4] & 0xfc;
-      else
-	*dst = *src;
+      if (*d) {
+        *dst = src[4] & 0xfc;
+      } else {
+        *dst = *src;
+      }
 
       d++;
       src++;
