@@ -28,41 +28,37 @@
 #include "context.h"
 
 
-uint32_t id = 1324068377;
-uint32_t options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
+u_long id = 1324068377;
+u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "QuarkTV plugin from the EffecTV project";
 u_long mode = OVERLAY;
 
 #define MIN_FRAMES 11
 
 static Buffer8_t *qtv = NULL;
-extern int webcams;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (!webcams)
-    options |= BEQ_DISABLED;
-  else
-    if (MIN_FRAMES > CAM_SAVE) {
-      printf("[!] QuarkTV: not enough frames (%d, want %d)\n", CAM_SAVE, MIN_FRAMES);
-      options |= BEQ_DISABLED;
-    } else {
-      uint32_t i;
+  uint32_t i;
 
-      qtv = Buffer8_new();
-      for (i = 0; i < BUFFSIZE; i++)
-	qtv->buffer[i] = b_rand_int_range(0, MIN_FRAMES-1);
-    }
+  assert(MIN_FRAMES <= CAM_SAVE);
+  qtv = Buffer8_new();
+  for (i = 0; i < BUFFSIZE; i++) {
+    qtv->buffer[i] = b_rand_int_range(0, MIN_FRAMES-1);
+  }
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (NULL != qtv)
+  if (NULL != qtv) {
     Buffer8_delete(qtv);
+  }
 }
 
 
@@ -72,18 +68,13 @@ run(Context_t *ctx)
   uint64_t i;
   Pixel_t *dst;
 
-  if (!webcams)
-    return;
-
   dst = passive_buffer(ctx)->buffer;
 
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
-
   for (i = 0; i < BUFFSIZE; i++, dst++) {
     const Pixel_t rnd = qtv->buffer[i];
     *dst = ctx->cam_save[ctx->cam][rnd]->buffer[i];
   }
-
   pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
 
@@ -92,22 +83,23 @@ run(Context_t *ctx)
 #if 0
 static int draw(RGB32 *src, RGB32 *dest)
 {
-	int i;
-	int cf;
+  int i;
+  int cf;
 
-	memcpy(planetable[plane], src, video_area * PIXEL_SIZE);
+  memcpy(planetable[plane], src, video_area * PIXEL_SIZE);
 
-	for(i=0; i<video_area; i++) {
-		cf = (inline_fastrand()>>24)&(PLANES-1);
-		dest[i] = (planetable[cf])[i];
-		/* The reason why I use high order 8 bits is written in utils.c
-		(or, 'man rand') */
-	}
+  for(i=0; i<video_area; i++) {
+    cf = (inline_fastrand()>>24)&(PLANES-1);
+    dest[i] = (planetable[cf])[i];
+    /* The reason why I use high order 8 bits is written in utils.c
+    (or, 'man rand') */
+  }
 
-	plane--;
-	if(plane<0)
-		plane = PLANES - 1;
+  plane--;
+  if(plane<0) {
+    plane = PLANES - 1;
+  }
 
-	return 0;
+  return 0;
 }
 #endif
