@@ -28,8 +28,8 @@
 #include "context.h"
 
 
-uint32_t id = 1325100452;
-uint32_t options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
+u_long id = 1325100452;
+u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "StreakTV plugin from the EffecTV project";
 u_long mode = OVERLAY;
 
@@ -41,26 +41,20 @@ u_long mode = OVERLAY;
 static Buffer8_t *planes[PLANES];
 static Pixel_t *planetable[PLANES];
 static int plane = 0;
-extern int webcams;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (!webcams)
-    options |= BEQ_DISABLED;
-  else
-    if (PLANES > CAM_SAVE) {
-      printf("[!] StreakTV: not enough frames (%d, want %d)\n", CAM_SAVE, PLANES);
-      options |= BEQ_DISABLED;
-    } else {
-      int i;
+  int i;
 
-      for (i = 0; i < PLANES; i++) {
-	planes[i] = Buffer8_new();
-	planetable[i] = planes[i]->buffer;
-      }
-    }
+  assert(PLANES <= CAM_SAVE);
+  for (i = 0; i < PLANES; i++) {
+    planes[i] = Buffer8_new();
+    planetable[i] = planes[i]->buffer;
+  }
+
+  return 1;
 }
 
 
@@ -69,8 +63,9 @@ destroy(Context_t *ctx)
 {
   int i;
 
-  for (i = 0; i < PLANES; i++)
+  for (i = 0; i < PLANES; i++) {
     Buffer8_delete(planes[i]);
+  }
 }
 
 
@@ -81,14 +76,12 @@ run(Context_t *ctx)
   uint8_t cf;
   Pixel_t *dst;
 
-  if (!webcams)
-    return;
-
   dst = passive_buffer(ctx)->buffer;
 
   pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
-  for (i = 0; i < BUFFSIZE; i++)
+  for (i = 0; i < BUFFSIZE; i++) {
     planetable[plane][i] = (ctx->cam_save[ctx->cam][0]->buffer[i] & STRIDE_MASK) >> STRIDE_SHIFT;
+  }
   pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 
   cf = plane & (STRIDE-1);
