@@ -19,20 +19,10 @@
 
 #include "context.h"
 
-uint32_t id = 1172430309;
-uint32_t options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
+u_long id = 1172430309;
+u_long options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "Webcam plugin";
-uint8_t mode = OVERLAY;
-
-extern int webcams;
-
-
-void
-create(Context_t *ctx)
-{
-  if (!webcams)
-    options |= BEQ_DISABLED;
-}
+u_long mode = OVERLAY;
 
 
 void
