@@ -33,11 +33,13 @@ char desc[] = "Cellular automaton";
 static Buffer8_t *game[2] = { NULL, NULL };
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   game[0] = Buffer8_new();
   game[1] = Buffer8_new();
+
+  return 1;
 }
 
 
@@ -119,7 +121,6 @@ run(Context_t *ctx)
     sw++;
   }
 
-  /*  Buffer8_mix_interlaced2(active_buffer(ctx->biniou8), out);*/
   /*  Buffer8_clear_border(active_buffer(ctx->biniou8));*/
   /*  Buffer8_copy(active_buffer(ctx->biniou8), passive_buffer(ctx->biniou8));*/
 
