@@ -52,19 +52,13 @@ run(Context_t *ctx)
   Buffer8_t *dst = passive_buffer(ctx);
   u_short k;
 
-  if (ctx->input == NULL)
-    return;
-
   memmove((void *)src->buffer, (const void *)(src->buffer+sizeof(Pixel_t)), BUFFSIZE-1);
 
   pthread_mutex_lock(&ctx->input->mutex);
-
-  for (k = 1; k < ctx->input->spectrum_size; k++)
-  {
+  for (k = 1; k < ctx->input->spectrum_size; k++) {
     Pixel_t color1 = (Pixel_t)(255.0 * ctx->input->spectrum_log[A_MONO][k]);
     v_line_nc(src, MAXX, v_start[k], v_end[k] - 1, color1);
   }
-
   pthread_mutex_unlock(&ctx->input->mutex);
 
   v_line_nc(src, MINX, MINY, MAXY, 0);
@@ -76,28 +70,24 @@ run(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input != NULL) {
-    v_start = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
-    v_end = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
+  v_start = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
+  v_end = xcalloc(ctx->input->spectrum_size, sizeof(u_short));
 
-    my_scr = Buffer8_new();
+  my_scr = Buffer8_new();
 
-    init_v(ctx);
-  } else
-    options |= BEQ_DISABLED;
+  init_v(ctx);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (ctx->input != NULL) {
-    Buffer8_delete(my_scr);
-
-    xfree(v_start);
-    xfree(v_end);
-  }
+  Buffer8_delete(my_scr);
+  xfree(v_start);
+  xfree(v_end);
 }
