@@ -43,11 +43,13 @@ initSinTable()
 
   tsinptr = tptr = Warp.sintable;
 
-  for (i = 0; i < 1024; i++)
+  for (i = 0; i < 1024; i++) {
     *tptr++ = (int)(sin(i * M_PI / 512.0) * 32767.0);
+  }
 
-  for (i = 0; i < 256; i++)
+  for (i = 0; i < 256; i++) {
     *tptr++ = *tsinptr++;
+  }
 }
 
 
@@ -80,8 +82,9 @@ initDistTable()
   m = sqrt ((float)(halfw*halfw + halfh*halfh));
 
   for (y = -halfh; y < halfh; y++)
-    for (x= -halfw; x < halfw; x++)
+    for (x= -halfw; x < halfw; x++) {
       *distptr++ = ((int) ( (sqrt ((float)(x*x+y*y)) * 511.9999) / m)) << 1;
+    }
 }
 
 
@@ -135,30 +138,45 @@ doWarp8bpp(int xw, int yw, int cw)
       dx = ctable [i+1] + x;
       dy = ctable [i] + y;
 
-      if (dx < MINX)    goto clipxmin;
-      if (dx > MAXX)    goto clipxmax;
-    xclipok:
-      if (dy < MINY)    goto clipymin;
-      if (dy > MAXY)    goto clipymax;
-    yclipok:*destptr++ = * (offstable[dy] + dx);
+      if (dx < MINX) {
+        goto clipxmin;
+      }
+      if (dx > MAXX) {
+        goto clipxmax;
+      }
+xclipok:
+      if (dy < MINY) {
+        goto clipymin;
+      }
+      if (dy > MAXY) {
+        goto clipymax;
+      }
+yclipok:
+      *destptr++ = * (offstable[dy] + dx);
     }
   return;
 
- clipxmin:
-  dx = 0; goto xclipok;
- clipxmax:
-  dx = MAXX; goto xclipok;
- clipymin:
-  dy = 0; goto yclipok;
- clipymax:
-  dy = MAXY; goto yclipok;
+clipxmin:
+  dx = 0;
+  goto xclipok;
+clipxmax:
+  dx = MAXX;
+  goto xclipok;
+clipymin:
+  dy = 0;
+  goto yclipok;
+clipymax:
+  dy = MAXY;
+  goto yclipok;
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   initWarp(ctx);
+
+  return 1;
 }
 
 
