@@ -42,14 +42,14 @@ gum(Context_t *ctx, u_short x, u_short max_y)
   dy = (float)HHEIGHT / (float)(HEIGHT - max_y);
   for (cy = y = MAXY; y >= max_y; y--) {
     set_pixel_nc(dst, x, y,
-		 get_pixel_nc(src, x, (u_short)cy));
+                 get_pixel_nc(src, x, (u_short)cy));
     cy -= dy;
   }
 
   dy = (float)(HEIGHT - max_y) / (float)HHEIGHT;
   for ( ; y >= 0; y--) {
     set_pixel_nc(dst, x, y,
-		 get_pixel_nc(src, x, (u_short)cy));
+                 get_pixel_nc(src, x, (u_short)cy));
     cy -= dy;
   }
 }
@@ -63,26 +63,15 @@ do_gum(Context_t *ctx, u_short x, float val)
 }
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
   u_short x;
 
-  if (ctx->input == NULL)
-    return;
-
   pthread_mutex_lock(&ctx->input->mutex);
   for (x = 0; x < WIDTH; x++) {
     u_short idx = (u_short)((float)x / (float)WIDTH * (float)ctx->input->size);
-    float value = ctx->input->data[A_MONO][idx];
+    float value = Input_clamp(ctx->input->data[A_MONO][idx]);
 
     do_gum(ctx, x, value);
   }
