@@ -40,16 +40,14 @@ typedef struct {
 static xscanline_conf xscanline_cf;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (images == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    xscanline_cf.size = MINPCT;
-    xscanline_cf.dir = 1;
-    xscanline_cf.ping_pong = 0;
-  }
+  xscanline_cf.size = MINPCT;
+  xscanline_cf.dir = 1;
+  xscanline_cf.ping_pong = 0;
+
+  return 1;
 }
 
 
@@ -75,24 +73,26 @@ x_scanline(Context_t *ctx, float amount)
   dst = passive_buffer(ctx);
 
   for (s = 0; s < size; s++) {
-    for (j = 0; j <= MAXY; j++)
+    for (j = 0; j <= MAXY; j++) {
       set_pixel_nc(dst, x_line, j, get_pixel_nc(src, x_line, j));
+    }
 
     x_line += xscanline_cf.dir;
     if (x_line > MAXX) {
       if (xscanline_cf.ping_pong) {
-	x_line = MAXX;
-	xscanline_cf.dir = -xscanline_cf.dir;
-      } else
-	x_line = 0;
-    } else
-      if (x_line < 0) {
-	if (xscanline_cf.ping_pong) {
-	  x_line = 0;
-	  xscanline_cf.dir = -xscanline_cf.dir;
-	} else
-	  x_line = MAXX;
+        x_line = MAXX;
+        xscanline_cf.dir = -xscanline_cf.dir;
+      } else {
+        x_line = 0;
       }
+    } else if (x_line < 0) {
+      if (xscanline_cf.ping_pong) {
+        x_line = 0;
+        xscanline_cf.dir = -xscanline_cf.dir;
+      } else {
+        x_line = MAXX;
+      }
+    }
   }
 }
 
@@ -100,6 +100,5 @@ x_scanline(Context_t *ctx, float amount)
 void
 run(Context_t *ctx)
 {
-  if (images != NULL)
-    x_scanline(ctx, xscanline_cf.size);
+  x_scanline(ctx, xscanline_cf.size);
 }
