@@ -26,44 +26,30 @@ char dname[] = "X Shaker";
 char desc[] = "Shaker effect";
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
-  u_short i, j;
-
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
-
-  if (ctx->input == NULL)
-    return;
+  uint16_t i;
 
   Buffer8_init_mask_3x3(active_buffer(ctx));
 
   pthread_mutex_lock(&ctx->input->mutex);
-
   for (i = 0; i < WIDTH; i++) {
     u_short idx = 0;
+    uint16_t j;
 
     for (j = 0; j < HEIGHT; j++) {
-      char dx, dy;
+      char dx = Input_clamp(ctx->input->data[A_LEFT][idx])  * SOUND_DISTURB_K;
+      char dy = Input_clamp(ctx->input->data[A_RIGHT][idx]) * SOUND_DISTURB_K;
 
-      dx = (char)(ctx->input->data[A_MONO][idx] * SOUND_DISTURB_K);
-      dy = (char)(ctx->input->data[A_MONO][idx] * SOUND_DISTURB_K);
+      if (++idx == ctx->input->size) {
+        idx = 0;
+      }
 
-      if (++idx == ctx->input->size)
-	idx = 0;
-
-      displace(src, dst, i, j, i+dx, j+dy);
+      displace(src, dst, i, j, i + dx, j + dy);
     }
   }
-
   pthread_mutex_unlock(&ctx->input->mutex);
 }
