@@ -26,32 +26,23 @@ char dname[] = "X Wave";
 char desc[] = "Swap columns";
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
-  u_short a, b, i, j;
+  int16_t a, b;
+  uint16_t i, j;
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (ctx->input == NULL)
-    return;
-
   Buffer8_init_mask_3x3(active_buffer(ctx));
 
   pthread_mutex_lock(&ctx->input->mutex);
   a = Input_random_short_range(ctx->input, 0, MAXX);
   for (i = 0; i < (ctx->input->size - 1); i++) {
     b = Input_random_short_range(ctx->input, 0, MAXX);
-    for (j = 0; j < HEIGHT; j++)
+    for (j = 0; j < HEIGHT; j++) {
       set_pixel_nc(dst, a, j, get_pixel_nc(src, b, j));
+    }
     a = b;
   }
   pthread_mutex_unlock(&ctx->input->mutex);
