@@ -42,14 +42,14 @@ gum(Context_t *ctx, u_short y, u_short max_x)
   dx = (float)HWIDTH / (float)(WIDTH - max_x);
   for (cx = x = MAXX; x >= max_x; x--) {
     set_pixel_nc(dst, x, y,
-		 get_pixel_nc(src, (u_short)cx, y));
+                 get_pixel_nc(src, (u_short)cx, y));
     cx -= dx;
   }
 
   dx = (float)(WIDTH - max_x) / (float)HWIDTH;
   for ( ; x >= 0; x--) {
     set_pixel_nc(dst, x, y,
-		 get_pixel_nc(src, (u_short)cx, y));
+                 get_pixel_nc(src, (u_short)cx, y));
     cx -= dx;
   }
 }
@@ -63,26 +63,15 @@ do_gum(Context_t *ctx, u_short y, float val)
 }
 
 
-void
-create(Context_t *ctx)
-{
-  if (ctx->input == NULL)
-    options |= BEQ_DISABLED;
-}
-
-
 void
 run(Context_t *ctx)
 {
   u_short y;
 
-  if (ctx->input == NULL)
-    return;
-
   pthread_mutex_lock(&ctx->input->mutex);
   for (y = 0; y < HEIGHT; y++) {
     u_short idx = (u_short)((float)y / (float)HEIGHT * (float)ctx->input->size);
-    float value = ctx->input->data[A_MONO][idx];
+    float value = Input_clamp(ctx->input->data[A_MONO][idx]);
 
     do_gum(ctx, y, value);
   }
