@@ -33,7 +33,8 @@ run(Context_t *ctx)
   Buffer8_t *wrk = active_buffer(ctx);
 
   for (j = 0; j < HEIGHT; j++)
-    for (i = 0; i < HWIDTH; i++)
+    for (i = 0; i < HWIDTH; i++) {
       set_pixel_nc(wrk, i, j, get_pixel_nc(wrk, MAXX - i, j));
+    }
   Buffer8_copy(active_buffer(ctx), passive_buffer(ctx));
 }
