@@ -44,37 +44,36 @@ init()
   t.v_j_factor = HMAXX * 0.85;
   t.v_i.y = 1.0 / (float)(P->size - 1) * (float)MAXY;
 
-  for (i = 0; i < P->size; i++)
+  for (i = 0; i < P->size; i++) {
     P->trans[i] = t;
+  }
 
   Porteuse_init_alpha(P);
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input != NULL) {
-    P = Porteuse_new(ctx->input->size, A_MONO);
-    init();
-  } else
-    options |= BEQ_DISABLED;
+  P = Porteuse_new(ctx->input->size, A_MONO);
+  init();
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (P != NULL)
+  if (P != NULL) {
     Porteuse_delete(P);
+  }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (P != NULL) {
-    Buffer8_clear(passive_buffer(ctx));
-    Porteuse_draw(P, ctx, connect);
-  }
+  Buffer8_clear(passive_buffer(ctx));
+  Porteuse_draw(P, ctx, connect);
 }
