@@ -46,23 +46,23 @@ init()
   t.v_j_factor = HMAXX * 0.85;
   t.v_i.y = 1.0 / (float)(PL->size - 1) * (float)MAXY;
 
-  for (i = 0; i < PL->size; i++)
+  for (i = 0; i < PL->size; i++) {
     PL->trans[i] = PR->trans[i] = t;
+  }
 
   Porteuse_init_alpha(PL);
   Porteuse_init_alpha(PR);
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (ctx->input != NULL) {
-    PL = Porteuse_new(ctx->input->size, A_LEFT);
-    PR = Porteuse_new(ctx->input->size, A_RIGHT);
-    init();
-  } else
-    options |= BEQ_DISABLED;
+  PL = Porteuse_new(ctx->input->size, A_LEFT);
+  PR = Porteuse_new(ctx->input->size, A_RIGHT);
+  init();
+
+  return 1;
 }
 
 
@@ -86,10 +86,7 @@ on_switch_on(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  assert(ctx->input != NULL);
-  if (ctx->input != NULL) {
-    Buffer8_clear(passive_buffer(ctx));
-    Porteuse_draw(PL, ctx, connect);
-    Porteuse_draw(PR, ctx, connect);
-  }
+  Buffer8_clear(passive_buffer(ctx));
+  Porteuse_draw(PL, ctx, connect);
+  Porteuse_draw(PR, ctx, connect);
 }
