@@ -40,16 +40,14 @@ typedef struct {
 static yscanline_conf yscanline_cf;
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  if (images == NULL)
-    options |= BEQ_DISABLED;
-  else {
-    yscanline_cf.size = MINPCT;
-    yscanline_cf.dir = 1;
-    yscanline_cf.ping_pong = 0;
-  }
+  yscanline_cf.size = MINPCT;
+  yscanline_cf.dir = 1;
+  yscanline_cf.ping_pong = 0;
+
+  return 1;
 }
 
 
@@ -75,24 +73,26 @@ y_scanline(Context_t *ctx, float amount)
   dst = passive_buffer(ctx);
 
   for (s = 0; s < size; s++) {
-    for (i = 0; i <= MAXX; i++)
+    for (i = 0; i <= MAXX; i++) {
       set_pixel_nc(dst, i, y_line, get_pixel_nc(src, i, y_line));
+    }
 
     y_line += yscanline_cf.dir;
     if (y_line > MAXY) {
       if (yscanline_cf.ping_pong) {
-	y_line = MAXY;
-	yscanline_cf.dir = -yscanline_cf.dir;
-      } else
-	y_line = 0;
-    } else
-      if (y_line < 0) {
-	if (yscanline_cf.ping_pong) {
-	  y_line = 0;
-	  yscanline_cf.dir = -yscanline_cf.dir;
-	} else
-	  y_line = MAXY;
+        y_line = MAXY;
+        yscanline_cf.dir = -yscanline_cf.dir;
+      } else {
+        y_line = 0;
       }
+    } else if (y_line < 0) {
+      if (yscanline_cf.ping_pong) {
+        y_line = 0;
+        yscanline_cf.dir = -yscanline_cf.dir;
+      } else {
+        y_line = MAXY;
+      }
+    }
   }
 }
 
@@ -100,7 +100,5 @@ y_scanline(Context_t *ctx, float amount)
 void
 run(Context_t *ctx)
 {
-  if (images != NULL)
-    y_scanline(ctx, yscanline_cf.size);
+  y_scanline(ctx, yscanline_cf.size);
 }
-
