@@ -29,9 +29,6 @@
 #include "utils.h"
 
 
-extern int webcams;
-
-
 u_long id = 1405944413;
 u_long options = BE_LENS;
 u_long mode = OVERLAY;
@@ -165,51 +162,45 @@ forward(void)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
-  Pixel_t *p;
-  size_t bytes;
-  short i;
-  enum eSource es;
-
   /* compute monitor size */
-  mView.size.x = SCALE(WIDTH , MONITOR_SIZE_PERCENT);
-  if (mView.size.x < 1) {
-    options |= BEQ_DISABLED;
-    printf("\r[-] WARNING: zmonitor width is less than 1 pixel: plugin disabled\n");
-    return;
-  }
-
+  mView.size.x = SCALE(WIDTH, MONITOR_SIZE_PERCENT);
+  assert(mView.size.x >= 1);
   mView.size.y = SCALE(HEIGHT, MONITOR_SIZE_PERCENT);
-  if (mView.size.y < 1) {
-    options |= BEQ_DISABLED;
-    printf("\r[-] WARNING: zmonitor height is less than 1 pixel: plugin disabled\n");
-    return;
-  }
+  assert(mView.size.y >= 1);
+
+  enum eSource es;
+  short i;
 
   /* check sources */
-  for (es = sFIRST; es <= sLAST; es++)
+  for (es = sFIRST; es <= sLAST; es++) {
     sources[es] = bENABLED;
+  }
 
-  if (webcams < 1)
+  if (ctx->webcams < 1) {
     sources[sCAMERA] = bDISABLED;
+  }
   /* we have now, at least, 2 sources enabled: sCAPTURE & sCLEAR */
 
   /* init recording flag */
   rRecording = b_rand_boolean();
 
   /* allocate webcam copy buffer, if needed */
-  if (sources[sCAMERA] != bDISABLED)
+  if (sources[sCAMERA] != bDISABLED) {
     webcam = Buffer8_new();
+  }
 
   /* allocate monitor buffers */
-  bytes = (size_t) mView.size.x * mView.size.y * sizeof(Pixel_t);
+  size_t bytes = (size_t) mView.size.x * mView.size.y * sizeof(Pixel_t);
   for (i = 0; i < rBUFFERS; i++) {
-    p = (Pixel_t *) xmalloc(bytes);
+    Pixel_t *p = xmalloc(bytes);
     randomize_buffer(p);
     rBuffer[i] = p;
   }
+
+  return 1;
 }
 
 
@@ -218,11 +209,13 @@ destroy(Context_t *ctx)
 {
   short i;
 
-  if (webcam)
+  if (webcam) {
     Buffer8_delete(webcam);
+  }
 
-  for (i = 0; i < rBUFFERS; i++)
+  for (i = 0; i < rBUFFERS; i++) {
     xfree(rBuffer[i]);
+  }
 }
 
 
@@ -311,21 +304,24 @@ run(Context_t *ctx)
 #endif /* !FASTDRAW */
       }
       /* outside view ? */
-      else if (r > 1)
+      else if (r > 1) {
         col = PIXEL_TRANSPARENT;
+      }
       /* inside view ? */
       else {
         col = src[(mView.size.y - (y + 1)) * mView.size.x + x];
 #ifdef DRAWHALFCOLOR
-        if ((y % HALFCOLOR_PERIOD) == 1)
-          col >>= 1; /* halfbright color, 1 line each HALFCOLOR_PERIOD */
+        if ((y % HALFCOLOR_PERIOD) == 1) {
+          col >>= 1;  /* halfbright color, 1 line each HALFCOLOR_PERIOD */
+        }
 #endif /* DRAWHALFCOLOR */
-        if (col < 1)
-          col = 1; /* be sure monitor has no PIXEL_TRANSPARENT color */
+        if (col < 1) {
+          col = 1;  /* be sure monitor has no PIXEL_TRANSPARENT color */
+        }
       }
 
       set_pixel_nc(dst,
-        mView.position.x + x, MAXY - (mView.position.y + y), col);
+                   mView.position.x + x, MAXY - (mView.position.y + y), col);
     }
   }
 
@@ -335,8 +331,9 @@ run(Context_t *ctx)
   cy = SCALE(mView.size.y, MONITOR_SOURCE_LEFTTOP_PERCENT);
   y1 = mView.position.y + cy;
   cy = SCALE(mView.size.y, MONITOR_SOURCE_SIZE_PERCENT);
-  if (cy < 1)
-    cy = 1; /* at least, use a 1x1 pixels area for channel colored-boxes */
+  if (cy < 1) {
+    cy = 1;  /* at least, use a 1x1 pixels area for channel colored-boxes */
+  }
   y2 = y1 + cy - 1;
 
   for (i = sFIRST; i <= sLAST; i++) {
@@ -344,40 +341,42 @@ run(Context_t *ctx)
     cx += SCALE(mView.size.x, (i - sFIRST) * MONITOR_SOURCE_SIZE_PERCENT);
     x1 = mView.position.x + cx;
     cx = SCALE(mView.size.y, MONITOR_SOURCE_SIZE_PERCENT);
-    if (cx < 1)
-      cx = 1; /* at least, use a 1x1 pixels area for channel colored-boxes */
+    if (cx < 1) {
+      cx = 1;  /* at least, use a 1x1 pixels area for channel colored-boxes */
+    }
     x2 = x1 + cx - 1;
     col = PIXEL_MAXVAL;
     if (rSource == (enum eSource) i) {
       if (rRecording == bON) {
-        if ((cx <= 1) && (cy <= 1))
+        if ((cx <= 1) && (cy <= 1)) {
           set_pixel_nc(dst, x1, MAXY - y1, col);
-        else if (cx <= 1)
+        } else if (cx <= 1) {
           v_line_nc(dst, x1, MAXY - y1, MAXY - y2, col);
-        else if (cy <= 1)
+        } else if (cy <= 1) {
           h_line_nc(dst, MAXY - y1, x1, x2, col);
-        else
+        } else {
           draw_filled_box_nc(dst, x1, MAXY - y1, x2, MAXY - y2, col);
-      }
-      else
-      {
+        }
+      } else {
         /* bg */
-        if ((cx <= 1) && (cy <= 1))
+        if ((cx <= 1) && (cy <= 1)) {
           set_pixel_nc(dst, x1, MAXY - y1, col >> 2);
-        else if (cx <= 1)
+        } else if (cx <= 1) {
           v_line_nc(dst, x1, MAXY - y1, MAXY - y2, col >> 2);
-        else if (cy <= 1)
+        } else if (cy <= 1) {
           h_line_nc(dst, MAXY - y1, x1, x2, col >> 2);
-        else
+        } else {
           draw_filled_box_nc(dst, x1, MAXY - y1, x2, MAXY - y2, col >> 2);
+        }
 
         /* fg */
-        if ((cx >= 3) && (cy >= 3))
+        if ((cx >= 3) && (cy >= 3)) {
           draw_box_nc(dst, x1, MAXY - y1, x2, MAXY - y2, col);
+        }
       }
-    }
-    else
+    } else {
       draw_filled_box_nc(dst, x1, MAXY - y1, x2, MAXY - y2, col >> 2);
+    }
   }
 #endif /* !FASTDRAW */
 
@@ -385,14 +384,17 @@ run(Context_t *ctx)
   forward();
 
   /* change params */
-  if (b_rand_int_range(0, ctx->max_fps * 2 + 1) == 1)
+  if (b_rand_int_range(0, ctx->max_fps * 2 + 1) == 1) {
     random_recording();
+  }
 
-  if (b_rand_int_range(0, ctx->max_fps * 5 + 1) == 1)
+  if (b_rand_int_range(0, ctx->max_fps * 5 + 1) == 1) {
     random_source();
+  }
 
-  if (b_rand_int_range(0, ctx->max_fps * 10 + 1) == 1)
+  if (b_rand_int_range(0, ctx->max_fps * 10 + 1) == 1) {
     random_position();
+  }
 }
 
 
@@ -425,8 +427,7 @@ random_recording(void)
         randomize_sometimes(rBuffer[rPosition], ((len - i) * 256) / len);
         forward();
       }
-    }
-    else {
+    } else {
       /* start recording: fill a few buffers with noise, more and more */
       for (i = 0; i < len; ) {
         randomize_sometimes(rBuffer[rPosition], (++i * 256) / len);
@@ -460,15 +461,17 @@ random_position(void)
 {
   mPosition = b_rand_int_range(pFIRST, pLAST + 1);
 
-  if (is_left_aligned(mPosition)) /* we are left aligned */
+  if (is_left_aligned(mPosition)) { /* we are left aligned */
     mView.position.x = SCALE(WIDTH, MONITOR_LEFTTOP_PERCENT);
-  else /* we are right aligned */
+  } else { /* we are right aligned */
     mView.position.x = SCALE(WIDTH, MONITOR_RIGHTBOTTOM_PERCENT) - mView.size.x;
+  }
 
-  if (is_top_aligned(mPosition)) /* we are top aligned */
+  if (is_top_aligned(mPosition)) { /* we are top aligned */
     mView.position.y = SCALE(HEIGHT, MONITOR_LEFTTOP_PERCENT);
-  else /* we are bottom aligned */
+  } else { /* we are bottom aligned */
     mView.position.y = SCALE(HEIGHT, MONITOR_RIGHTBOTTOM_PERCENT) - mView.size.y;
+  }
 }
 
 
@@ -478,8 +481,9 @@ randomize_buffer(Pixel_t *ptr)
   short x, y;
 
   for (y = 0; y < mView.size.y; y++) {
-    for (x = 0; x < mView.size.x; x++)
+    for (x = 0; x < mView.size.x; x++) {
       *ptr++ = b_rand_int_range(PIXEL_MINVAL, PIXEL_MAXVAL + 1);
+    }
   }
 }
 
@@ -513,15 +517,16 @@ zscale(Pixel_t *dst, const Pixel_t *src)
   int ret;
 
   sws_context = sws_getContext(
-    WIDTH, HEIGHT, AV_PIX_FMT_GRAY8, /* source */
-    mView.size.x, mView.size.y, AV_PIX_FMT_GRAY8, /* destination */
+                  WIDTH, HEIGHT, AV_PIX_FMT_GRAY8, /* source */
+                  mView.size.x, mView.size.y, AV_PIX_FMT_GRAY8, /* destination */
 #ifdef __NetBSD__
-    SWS_BILINEAR, NULL, NULL, NULL);
+                  SWS_BILINEAR, NULL, NULL, NULL);
 #else
-    SWS_FAST_BILINEAR, NULL, NULL, NULL);
+                  SWS_FAST_BILINEAR, NULL, NULL, NULL);
 #endif
-  if (NULL == sws_context)
+  if (NULL == sws_context) {
     xerror("sws_getContext\n");
+  }
 
   srcStride[0] = WIDTH;
   dstStride[0] = mView.size.x;
@@ -529,8 +534,9 @@ zscale(Pixel_t *dst, const Pixel_t *src)
   dstSlice[0] = (uint8_t *)dst;
 
   ret = sws_scale(sws_context, srcSlice, srcStride, 0, HEIGHT, dstSlice, dstStride);
-  if (ret < 0)
+  if (ret < 0) {
     xerror("sws_scale\n");
+  }
 
   sws_freeContext(sws_context);
 }
