@@ -41,7 +41,7 @@ static Point2d_t  centers[NUMCENTERS];
 
 
 static void init_params(void);
-static Map_t cth_spiral(const u_short, const u_short);
+static Map_t cth_spiral(const short, const short);
 
 static inline float
 hypof(const float x, const float y)
@@ -50,18 +50,21 @@ hypof(const float x, const float y)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   t_spiral = Translation_new(&cth_spiral, &init_params);
+
+  return 1;
 }
 
 
 void
 destroy(Context_t *ctx)
 {
-  if (NULL != t_spiral)
+  if (NULL != t_spiral) {
     Translation_delete(t_spiral);
+  }
 }
 
 
@@ -92,7 +95,7 @@ init_params(void)
 
 
 static Map_t
-cth_spiral(const u_short xx, const u_short yy)
+cth_spiral(const short xx, const short yy)
 {
   Map_t m;
   float ang, cx, cy, dist, dx, dy, radius, x, y;
@@ -109,12 +112,10 @@ cth_spiral(const u_short xx, const u_short yy)
     if ((y == MINY) || (y == MAXY)) {
       dx = ((cx - x) * 3) / 4;
       dy = cy - y;
-    }
-    else if ((x == MINX) || (x == MAXX)) {
+    } else if ((x == MINX) || (x == MAXX)) {
       dx = cx - x;
       dy = ((cy - y) * 3) / 4;
-    }
-    else {
+    } else {
       dx = x - cx;
       dy = y - cy;
       dist = hypof(dx, dy);
@@ -123,17 +124,17 @@ cth_spiral(const u_short xx, const u_short yy)
         dist /= 10;
         dx = -sinf(ang) * dist;
         dy =  cosf(ang) * dist;
-      }
-      else
+      } else {
         dx = dy = 0;
+      }
     }
 
     x += dx;
     y += dy;
   }
 
-  m.map_x = abs((int) rintf(x)) % WIDTH;
-  m.map_y = abs((int) rintf(y)) % HEIGHT;
+  m.map_x = x;
+  m.map_y = y;
 
   return m;
 }
