@@ -32,36 +32,40 @@ char desc[] = "RTMP streamer";
 static FILE *rtmp = NULL;
 
 
-static void
+static int8_t
 open_rtmp()
 {
   char cmd[MAXLEN+1];
   char *args = NULL, *url = NULL;
 
   memset(&cmd, '\0', MAXLEN+1);
-  if (NULL == (args = getenv("LEBINIOU_RTMP_FFMPEG_ARGS")))
+  if (NULL == (args = getenv("LEBINIOU_RTMP_FFMPEG_ARGS"))) {
     args = RTMP_FFMPEG_ARGS;
-  if (NULL == (url = getenv("LEBINIOU_RTMP_URL")))
+  }
+  if (NULL == (url = getenv("LEBINIOU_RTMP_URL"))) {
     url = RTMP_URL;
+  }
 
   g_snprintf(cmd, MAXLEN, "%s %s %s", FFMPEG, args, url);
-  if (NULL == (rtmp = popen(cmd, "w")))
+  if (NULL == (rtmp = popen(cmd, "w"))) {
     xperror("popen");
-  else {
+  } else {
     VERBOSE(printf("[i] %s: opened stream to %s\n", __FILE__, url));
     VERBOSE(printf("[i] %s: ffmpeg args: '%s'\n", __FILE__, args));
   }
+
+  return 1;
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   if (check_command(FFMPEG_CHECK) == -1) {
     printf("[!] %s: ffmpeg binary not found, plugin disabled\n", __FILE__);
-    options |= BEQ_DISABLED;
-  } else {  
-    open_rtmp();
+    return 0;
+  } else {
+    return open_rtmp();
   }
 }
 
@@ -70,40 +74,39 @@ void
 destroy(Context_t *ctx)
 {
   if (NULL != rtmp)
-    if (-1 == pclose(rtmp))
+    if (-1 == pclose(rtmp)) {
       xperror("pclose");
+    }
 }
 
 
 void
 run(Context_t *ctx)
 {
-  if (NULL != rtmp) {
-    u_char *data;
-    char buff[MAXLEN+1];
-    size_t res;
+  u_char *data;
+  char buff[MAXLEN+1];
+  size_t res;
 
-    /* get picture */
-    data = export_BGR_active_buffer(ctx, 1);
+  /* get picture */
+  data = export_BGR_active_buffer(ctx, 1);
 
-    memset(&buff, '\0', MAXLEN+1);
-    g_snprintf(buff, MAXLEN, "P6  %d %d 255\n", WIDTH, HEIGHT);
+  memset(&buff, '\0', MAXLEN+1);
+  g_snprintf(buff, MAXLEN, "P6  %d %d 255\n", WIDTH, HEIGHT);
 
-    /* PPM header */
-    res = fwrite((const void *)&buff, sizeof(char), strlen(buff), rtmp);
-    if (res != strlen(buff)) {
-      fprintf(stderr, "[!] %s:write_header: short write (%d of %d)\n", __FILE__, (int)res, (int)strlen(buff));
-      exit(1);
-    }
-
-    /* PPM data */
-    res = fwrite((const void *)data, sizeof(Pixel_t), RGB_BUFFSIZE, rtmp);
-    xfree(data);
-    if (res != RGB_BUFFSIZE) {
-      fprintf(stderr, "[!] %s:write_image: short write (%d of %li)\n", __FILE__, (int)res, RGB_BUFFSIZE);
-      exit(1);
-    }
-
-    fflush(rtmp);
+  /* PPM header */
+  res = fwrite((const void *)&buff, sizeof(char), strlen(buff), rtmp);
+  if (res != strlen(buff)) {
+    fprintf(stderr, "[!] %s:write_header: short write (%d of %d)\n", __FILE__, (int)res, (int)strlen(buff));
+    exit(1);
   }
+
+  /* PPM data */
+  res = fwrite((const void *)data, sizeof(Pixel_t), RGB_BUFFSIZE, rtmp);
+  xfree(data);
+  if (res != RGB_BUFFSIZE) {
+    fprintf(stderr, "[!] %s:write_image: short write (%d of %li)\n", __FILE__, (int)res, RGB_BUFFSIZE);
+    exit(1);
+  }
+
+  fflush(rtmp);
 }
