@@ -21,6 +21,7 @@
 #include "biniou.h"
 #include "osd.h"
 #include "src/defaults.h"
+#include "events.h"
 
 u_long id = 1541681431;
 u_long options = BE_NONE;
@@ -41,10 +42,14 @@ create_window(const Uint32 flags)
   char *window_title;
 
   window_title = g_strdup_printf("Le Biniou (%dx%d)", WIDTH, HEIGHT);
-  window = SDL_CreateWindow(window_title, current.w - WIDTH, 0, WIDTH, HEIGHT, flags);
+
+  int x0 = WIDTH_ORIGIN == INT32_MIN ? current.w - WIDTH : WIDTH_ORIGIN;
+  int y0 = HEIGHT_ORIGIN == INT32_MIN ? 0 : HEIGHT_ORIGIN;
+  window = SDL_CreateWindow(window_title, x0, y0, WIDTH, HEIGHT, flags);
   g_free(window_title);
-  if (NULL == window)
+  if (NULL == window) {
     xerror("Couldn't set %dx%d video mode: %s\n", WIDTH, HEIGHT, SDL_GetError());
+  }
 
   icon_file = g_strdup_printf("%s/lebiniou.bmp", DEFAULT_DATADIR);
   icon = SDL_LoadBMP(icon_file);
@@ -68,8 +73,8 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
   const int depth = 32, pitch = 4 * WIDTH;
   const Uint32 pixel_format = SDL_PIXELFORMAT_RGBA32;
 
-  SDL_Surface* surf = SDL_CreateRGBSurfaceWithFormatFrom((void *)src, WIDTH, HEIGHT,
-							 depth, pitch, pixel_format);
+  SDL_Surface *surf = SDL_CreateRGBSurfaceWithFormatFrom((void *)src, WIDTH, HEIGHT,
+                                                         depth, pitch, pixel_format);
   assert(surf != NULL);
   if (SDL_BlitScaled(surf, NULL, SDL_GetWindowSurface(window), NULL) < 0) {
     xerror("SDL_BlitScaled failed\n");
@@ -91,12 +96,10 @@ SDL_get_event(Context_t *ctx)
 
     switch (evt.type) {
     case SDL_KEYDOWN:
-      if (NULL != ctx->events_cb) {
-	key.val = evt.key.keysym.sym;
-	key.mod = evt.key.keysym.mod;
+      key.val = evt.key.keysym.sym;
+      key.mod = evt.key.keysym.mod;
 
-	ctx->events_cb(ctx, &key);
-      }
+      on_key(ctx, &key);
       break;
 
     case SDL_QUIT:
@@ -106,46 +109,46 @@ SDL_get_event(Context_t *ctx)
     case SDL_MOUSEMOTION:
       switch (evt.motion.state) {
       case SDL_BUTTON_LEFT:
-	ctx->params3d.xe = evt.motion.x;
-	ctx->params3d.ye = evt.motion.y;
-	Params3d_rotate(&ctx->params3d);
-	break;
+        ctx->params3d.xe = evt.motion.x;
+        ctx->params3d.ye = evt.motion.y;
+        Params3d_rotate(&ctx->params3d);
+        break;
 
       case SDL_BUTTON_RIGHT + SDL_BUTTON_LEFT: /* <- WTF ? */
-	// printf("right button motion @ %d %d\n",  evt.motion.x, evt.motion.y);
-	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
-	break;
+        // printf("right button motion @ %d %d\n",  evt.motion.x, evt.motion.y);
+        set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
+        break;
 
       default:
-	break;
+        break;
       }
       break;
 
     case SDL_MOUSEWHEEL:
       if (evt.wheel.y > 0) { // scroll up
-	ctx->params3d.scale_factor /= 0.9;
+        ctx->params3d.scale_factor /= SCALE_FACTOR_MULT;
       } else if (evt.wheel.y < 0) { // scroll down
-	if (ctx->params3d.scale_factor > 11)
-	  ctx->params3d.scale_factor *= 0.9;
+        if (ctx->params3d.scale_factor > SCALE_FACTOR_MIN)
+          ctx->params3d.scale_factor *= SCALE_FACTOR_MULT;
       }
-      printf("[i] scale: %d\n", ctx->params3d.scale_factor);
+      printf("[i] 3D scale factor: %.2f\n", ctx->params3d.scale_factor);
       break;
 
     case SDL_MOUSEBUTTONDOWN:
       /* printf("type= %d, button= %d\n", evt.button.type, evt.button.button); */
       switch (evt.button.button) {
       case SDL_BUTTON_LEFT:
-	ctx->params3d.xs = evt.motion.x;
-	ctx->params3d.ys = evt.motion.y;
-	break;
+        ctx->params3d.xs = evt.motion.x;
+        ctx->params3d.ys = evt.motion.y;
+        break;
 
       case SDL_BUTTON_RIGHT:
-	// printf("button down @ %d %d\n",  evt.motion.x, evt.motion.y);
-	set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
-	break;
+        // printf("button down @ %d %d\n",  evt.motion.x, evt.motion.y);
+        set_pixel_nc(active_buffer(ctx), evt.motion.x, MAXY-evt.motion.y, 255);
+        break;
 
       default:
-	break;
+        break;
       }
       break;
 
@@ -174,7 +177,7 @@ run(Context_t *ctx)
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   Uint32 flags = 0;
@@ -185,8 +188,9 @@ create(Context_t *ctx)
   subsystems = SDL_WasInit(SDL_INIT_VIDEO);
   if (subsystems == 0) {
     ret = SDL_Init(SDL_INIT_VIDEO);
-    if (ret == -1)
+    if (ret == -1) {
       xerror("Couldn't initialize SDL: %s\n", SDL_GetError());
+    }
   }
 
   /* We assume running on the first screen/display */
@@ -201,6 +205,10 @@ create(Context_t *ctx)
 
   osd_init();
 
+  if (ctx->window_decorations == 0) {
+    flags |= SDL_WINDOW_BORDERLESS;
+  }
+
 #ifndef FIXED
   flags |= SDL_WINDOW_RESIZABLE;
 #endif
@@ -209,6 +217,42 @@ create(Context_t *ctx)
 #ifdef NO_MOUSE_CURSOR
   SDL_ShowCursor(SDL_DISABLE);
 #endif
+
+  /* Fill windows on boot */
+  /* Initialize main window with target picture */
+  /* No colormaps are loaded yet, so we convert to grayscale */
+  const int depth = 24, pitch = 3 * WIDTH;
+  const Uint32 pixel_format = SDL_PIXELFORMAT_RGB24;
+  Pixel_t *target = xmalloc(3 * BUFFSIZE * sizeof(Pixel_t));
+  Buffer8_t *pic = Buffer8_new();
+  Buffer8_copy(ctx->target_pic->buff, pic);
+  Buffer8_flip_v(pic);
+  const Pixel_t *src = pic->buffer;
+  Pixel_t *dst = target;
+  uint32_t i = 0;
+
+  for (i = 0; i < BUFFSIZE; i++, src++, dst += 3) {
+    dst[0] = dst[1] = dst[2] = *src;
+  }
+  SDL_Surface *surf = SDL_CreateRGBSurfaceWithFormatFrom((void *)target, WIDTH, HEIGHT,
+                                                         depth, pitch, pixel_format);
+  Buffer8_delete(pic);
+  xfree(target);
+  assert(surf != NULL);
+  if (SDL_BlitScaled(surf, NULL, SDL_GetWindowSurface(window), NULL) < 0) {
+    xerror("SDL_BlitScaled failed\n");
+  }
+  SDL_FreeSurface(surf);
+  if (SDL_UpdateWindowSurface(window) < 0) {
+    xerror("SDL_UpdateWindowSurface failed: %s\n", SDL_GetError());
+  }
+
+  /* OSD */
+  if (has_osd) {
+    osd(ctx);
+  }
+
+  return 1;
 }
 
 
