@@ -26,7 +26,7 @@
 #include "src/defaults.h"
 
 #define PB_WIDTH 3 /* progress bar width (%) */
-#define SHOW 15    /* number of plugins to display before/after the current plugin */
+#define SHOW 18    /* number of plugins to display before/after the current plugin */
 
 extern char has_osd;
 extern u_short fontlineskip;
@@ -37,27 +37,34 @@ SDL_Window *osd_window = NULL;
 #define ARROW       "->"
 #define OSD_BUFFLEN 512
 
-#define OSD_WIDTH  440
-#define OSD_HEIGHT 700
+#define OSD_WIDTH  600
+#define OSD_HEIGHT 900
 
 
-void osd_init() {
+void osd_init()
+{
   char *icon_file;
   SDL_Surface *icon = NULL;
   Uint32 colorkey;
-  int flags = 0; // SDL_WINDOW_RESIZABLE;
+  int flags = SDL_WINDOW_RESIZABLE;
 
   ttf_init();
 
-  if (!has_osd)
+  if (!has_osd) {
     return;
+  }
 
-  osd_window = SDL_CreateWindow("Le Biniou OSD", 0, 0, OSD_WIDTH, OSD_HEIGHT, flags);
-  if (NULL == osd_window)
+  osd_window = SDL_CreateWindow("Le Biniou", 0, 0, OSD_WIDTH, OSD_HEIGHT, flags);
+  if (NULL == osd_window) {
     xerror("Couldn't set %dx%d video mode: %s\n", OSD_WIDTH, OSD_HEIGHT, SDL_GetError());
+  }
 
   icon_file = g_strdup_printf("%s/lebiniou.bmp", DEFAULT_DATADIR);
+#ifdef DEBUG
+  printf("[i] Loading icon from %s\n", icon_file);
+#endif
   icon = SDL_LoadBMP(icon_file);
+  assert(icon != NULL);
   g_free(icon_file);
   colorkey = SDL_MapRGB(icon->format, 0, 0, 0);
   SDL_SetColorKey(icon, SDL_TRUE, colorkey);
@@ -66,7 +73,8 @@ void osd_init() {
 }
 
 
-void osd_quit() {
+void osd_quit()
+{
   if (has_osd) {
     SDL_DestroyWindow(osd_window);
     ttf_quit();
@@ -75,7 +83,8 @@ void osd_quit() {
 
 
 static void
-osd_info(const Context_t *ctx) {
+osd_info(const Context_t *ctx)
+{
   char buff[OSD_BUFFLEN+1];
   int dst_y = 0;
 
@@ -94,7 +103,7 @@ osd_info(const Context_t *ctx) {
   now_str = ctime((time_t *)&now.tv_sec);
   now_str[strlen(now_str)-1] = '\0';
 
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "%s", now_str);
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "%s", now_str);
 
   /* Uptime */
   elapsed = b_timer_elapsed(ctx->timer);
@@ -106,77 +115,91 @@ osd_info(const Context_t *ctx) {
   elapsed -= m*60;
   s = (u_short)elapsed;
   elapsed -= s;
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Up: %1dd %02d:%02d:%02d.%02d",
-	   d, h, m, s, (u_short)(elapsed*100));
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "Up: %1dd %02d:%02d:%02d.%02d",
+                    d, h, m, s, (u_short)(elapsed*100));
 
   /* Display sequence name */
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Sequence: %s",
-	   (cur_seq->name != NULL) ? cur_seq->name : "(none)");
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "Sequence: %s",
+                    (cur_seq->name != NULL) ? cur_seq->name : "(none)");
 
   /* Display current bankset:bank */
   switch (ctx->bank_mode) {
   case SEQUENCES:
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Sequences bank: %d-%d",
-		      ctx->bankset[SEQUENCES]+1, ctx->bank[SEQUENCES]+1);
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Sequences bank: %d-%d",
+                      ctx->bankset[SEQUENCES]+1, ctx->bank[SEQUENCES]+1);
     break;
   case COLORMAPS:
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Colormaps bank: %d-%d",
-		      ctx->bankset[COLORMAPS]+1, ctx->bank[COLORMAPS]+1);
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Colormaps bank: %d-%d",
+                      ctx->bankset[COLORMAPS]+1, ctx->bank[COLORMAPS]+1);
     break;
   case IMAGES:
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Images bank: %d-%d",
-		      ctx->bankset[IMAGES]+1, ctx->bank[IMAGES]+1);
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Images bank: %d-%d",
+                      ctx->bankset[IMAGES]+1, ctx->bank[IMAGES]+1);
     break;
   }
 
   /* Display colormap and image (if any) */
-  assert(colormaps != NULL);
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Colormap: %s",
-		    (cur_seq->cmap_id) ? Colormaps_name(cur_seq->cmap_id) : "(default)");
+  if (colormaps != NULL) {
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Colormap: %s",
+    (cur_seq->cmap_id) ? Colormaps_name(cur_seq->cmap_id) : "(default)");
+  }
 
-  if (NULL != images)
-      dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Image: %s",
-			(cur_seq->image_id) ? Images_name(cur_seq->image_id) : "(default)");
+  if (images != NULL) {
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Image: %s",
+                      (cur_seq->image_id) ? Images_name(cur_seq->image_id) : "(default)");
+  }
 
   /* Display auto* stuff */
   if (ctx->random_mode != BR_NONE) {
     const char *what = NULL;
 
-    if (ctx->random_mode == BR_SCHEMES)
+    if (ctx->random_mode == BR_SCHEMES) {
       what = "Schemes";
-    else if (ctx->random_mode == BR_SEQUENCES)
+    } else if (ctx->random_mode == BR_SEQUENCES) {
       what = "Sequences";
-    else if (ctx->random_mode == BR_BOTH)
+    } else if (ctx->random_mode == BR_BOTH) {
       what = "Schemes+Sequences";
+    }
     snprintf(buff, OSD_BUFFLEN * sizeof(char), "Auto mode: %s", what);
-  } else
+  } else {
     snprintf(buff, OSD_BUFFLEN * sizeof(char), "Auto mode: Off");
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "%s", buff);
+  }
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "%s", buff);
 
   /* Display random cmap/image */
-  if (colormaps->size > 1)
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Random colormap: %s",
-		      ((ctx->sm->cur->auto_colormaps) ? "On" : "Off"));
+  if ((colormaps != NULL) && (colormaps->size > 1))
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Random colormaps: %s",
+                      ctx->auto_colormaps ? "On" : "Off");
 
   if ((images != NULL) && (images->size > 1))
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Random image: %s",
-		      (ctx->sm->cur->auto_images ? "On" : "Off"));
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Random images: %s",
+                      ctx->auto_images ? "On" : "Off");
 
   /* Display locked plugin, if any */
-  if (ctx->locked != NULL)
-    dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Locked: %s", Plugin_dname(ctx->locked));
+  if (ctx->locked != NULL) {
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Locked: %s", Plugin_dname(ctx->locked));
+  }
 
   /* Display phase-space delay */
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Phase-space delay: %d", Context_get_phase_space_delay(ctx));
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "Phase-space delay: %d", Context_get_phase_space_delay(ctx));
 
   /* Spline span size */
-  dst_y = osd_print(BORDER, dst_y, 0, 0, 0, "Span size: %d", Context_get_span_size(ctx));
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "Span size: %d", Context_get_span_size(ctx));
+
+  /* Volume scaling */
+  if (ctx->input != NULL) {
+    dst_y = osd_print(BORDER, dst_y, 0, 0, "Volume scale: %.1f", Context_get_volume_scale(ctx));
+  }
+
+  /* 3D scale factor */
+  dst_y = osd_print(BORDER, dst_y, 0, 0, "3D scale factor: %.2f", ctx->params3d.scale_factor);
 }
 
 
 static void
-osd_fps(const Context_t *ctx) {
-  (void)osd_print(BORDER, 0, 1, 1, 0, "%03d FPS (%03d)", (int)Context_fps(ctx), ctx->max_fps);
+osd_fps(const Context_t *ctx)
+{
+  (void)osd_print(BORDER, 0, 1, 1, "%03d FPS (%03d)", (int)Context_fps(ctx), ctx->max_fps);
 }
 
 
@@ -202,16 +225,15 @@ osd_sequence(const Context_t *ctx)
       const char *arrow = (P == plugins->selected) ? ARROW : "";
 
       if ((cur_seq->lens != NULL) && (P == cur_seq->lens)) {
-	lens_there = 1;
-	snprintf(buff, OSD_BUFFLEN*sizeof(char), "%s %s - %s", arrow, name, mode);
-      }
-      else {
-	const char lens_there_c = (lens_there) ? ' ' : '|';
-	snprintf(buff, OSD_BUFFLEN*sizeof(char), "%s %s %c %s", arrow, name, lens_there_c, mode);
+        lens_there = 1;
+        snprintf(buff, OSD_BUFFLEN*sizeof(char), "%s %s - %s", arrow, name, mode);
+      } else {
+        const char lens_there_c = (lens_there) ? ' ' : '|';
+        snprintf(buff, OSD_BUFFLEN*sizeof(char), "%s %s %c %s", arrow, name, lens_there_c, mode);
       }
       xfree(name);
 
-      dst_y = osd_print(BORDER, dst_y, 1, 0, 0, "%s", buff);
+      dst_y = osd_print(BORDER, dst_y, 1, 0, "%s", buff);
     }
     tmp = g_list_next(tmp);
   }
@@ -225,40 +247,41 @@ osd_plugins(const Context_t *ctx)
 {
   short n;
   short start;
-  u_short dst_y = 2*SHOW*fontlineskip - 2*SHOW;
+  u_short skip = fontlineskip - 1;
+  u_short dst_y = 2 * SHOW * skip + 2 * skip;
 
   start = plugins->selected_idx - SHOW;
-  while (start < 0)
+  while (start < 0) {
     start += plugins->size;
+  }
 
-  for (n = 0; (n < 2*SHOW+1) && (n < plugins->size); ) {
+  for (n = 0; (n < 2 * SHOW + 1) && (n < plugins->size); ) {
     const char *arrow;
     char in_sequence;
     char *name;
-    int disabled;
     Plugin_t *plugin = plugins->plugins[start];
 
-    disabled = (*(plugin)->options & BEQ_DISABLED) ? 1 : 0;
     arrow = (n == SHOW) ? ARROW : "  ";
     in_sequence = Sequence_find(ctx->sm->cur, plugin) ? '*' : ' ';
 
     name = Plugin_dname(plugin);
-    (void)osd_print(BORDER, dst_y, 0, 1, disabled, "%c|%c|%c|%c|%c %s %c %s",
-		    ((*plugin->options & BE_SFX2D) || (*plugin->options & BE_SFX3D)) ? 'S' : ' ',
-		    (*plugin->options & BE_GFX)  ? 'G' : ' ',
-		    ((*plugin->options & BE_BLUR) || (*plugin->options & BE_DISPLACE)
-		     || (*plugin->options & BE_ROLL) || (*plugin->options & BE_WARP)
-		     || (*plugin->options & BE_SCROLL) || (*plugin->options & BE_MIRROR))  ? 'F' : ' ',
-		    ((*plugin->options & BEQ_IMAGE) || (*plugin->options & BEQ_SPLASH))  ? 'I' : ' ',
-		    (*plugin->options & BE_LENS)  ? 'L' : ' ',
-		    arrow, in_sequence, name);
+    (void)osd_print(BORDER, dst_y, 0, 1, "%c|%c|%c|%c|%c %s %c %s",
+                    ((*plugin->options & BE_SFX2D) || (*plugin->options & BE_SFX3D)) ? 'S' : ' ',
+                    (*plugin->options & BE_GFX)  ? 'G' : ' ',
+                    ((*plugin->options & BE_BLUR) || (*plugin->options & BE_DISPLACE)
+                     || (*plugin->options & BE_ROLL) || (*plugin->options & BE_WARP)
+                     || (*plugin->options & BE_SCROLL) || (*plugin->options & BE_MIRROR))  ? 'F' : ' ',
+                    ((*plugin->options & BEQ_IMAGE) || (*plugin->options & BEQ_SPLASH))  ? 'I' : ' ',
+                    (*plugin->options & BE_LENS)  ? 'L' : ' ',
+                    arrow, in_sequence, name);
     xfree(name);
-    dst_y -= fontlineskip - 1;
+    dst_y -= skip;
     n++;
 
     start++;
-    if (start == plugins->size)
+    if (start == plugins->size) {
       start = 0;
+    }
   }
 }
 
@@ -269,12 +292,15 @@ osd_plugin_desc(const Context_t *ctx)
   char *dsc = NULL;
   int skip = fontlineskip - 1;
 
-  if (NULL == plugins->selected->desc)
-    dsc = "NO DESCRIPTION";
-  else
-    dsc = plugins->selected->desc;
+  if (NULL != plugins->selected) {
+    if (NULL == plugins->selected->desc) {
+      dsc = "NO DESCRIPTION";
+    } else {
+      dsc = plugins->selected->desc;
+    }
 
-  (void)osd_print(BORDER, skip, 1, 1, 0, "%s", dsc);
+    (void)osd_print(BORDER, skip, 1, 1, "%s", dsc);
+  }
 }
 
 
@@ -302,29 +328,33 @@ osd_random_mode_elapsed(const Context_t *ctx)
 
 
 void
-osd(const Context_t *ctx) {
+osd(const Context_t *ctx)
+{
   SDL_Rect r;
   int w, h;
 
   SDL_GetWindowSize(osd_window, &w, &h);
   r.x = r.y = 0;
-  r.w = OSD_WIDTH;
-  r.h = OSD_HEIGHT;
+  r.w = w;
+  r.h = h;
   SDL_FillRect(SDL_GetWindowSurface(osd_window), &r, 0);
 
   osd_info(ctx);
 
-  if (ctx->random_mode != BR_NONE)
+  if (ctx->random_mode != BR_NONE) {
     osd_random_mode_elapsed(ctx);
+  }
 
-  if (ctx->sync_fps)
+  if (ctx->sync_fps) {
     osd_fps(ctx);
+  }
 
   osd_sequence(ctx);
 
-  osd_plugins(ctx);
-
-  osd_plugin_desc(ctx);
+  if (plugins != NULL) {
+    osd_plugins(ctx);
+    osd_plugin_desc(ctx);
+  }
 
   if (SDL_UpdateWindowSurface(osd_window) < 0) {
     SDL_Log("SDL_UpdateWindowSurface failed: %s", SDL_GetError());
