@@ -26,8 +26,8 @@ void osd_quit();
 void osd(const Context_t *);
 
 u_short osd_print(const u_short, u_short,
-		  const u_char, const u_char,
-		  const u_char, const char *, ...);
+                  const u_char, const u_char,
+                  const char *, ...);
 
 void osd(const Context_t *);
 
