@@ -27,7 +27,6 @@
 
 static SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };
 static SDL_Color black = { 0, 0, 0, 0 };
-static SDL_Color red   = { 0xFF, 0, 0, 0 };
 
 static TTF_Font *font = NULL;
 u_short fontlineskip;
@@ -40,8 +39,9 @@ ttf_init()
 {
   /* Initialize the TTF library */
   if (!TTF_WasInit())
-    if (TTF_Init() < 0)
+    if (TTF_Init() < 0) {
       xerror("[SDL] Couldn't initialize TTF: %s\n", SDL_GetError());
+    }
 
   /* Get the font path */
   const char *font_path = getenv("LEBINIOU_FONT");
@@ -82,16 +82,17 @@ ttf_init()
 void
 ttf_quit()
 {
-  if (NULL != font)
+  if (NULL != font) {
     TTF_CloseFont(font);
+  }
   TTF_Quit();
 }
 
 
 u_short
 osd_print(const u_short x, u_short y,
-	  const u_char rev_x, const u_char rev_y,
-	  const int disabled, const char *fmt, ...)
+          const u_char rev_x, const u_char rev_y,
+          const char *fmt, ...)
 {
   char str[OSD_BUFFLEN+1];
   va_list ap;
@@ -108,7 +109,7 @@ osd_print(const u_short x, u_short y,
   vsprintf(str, fmt, ap); /* TODO vsnprintf */
   va_end(ap);
 
-  fg_color = (disabled) ? red : white;
+  fg_color = white;
 
   text = TTF_RenderText_Blended(font, str, black);
 
@@ -119,11 +120,11 @@ osd_print(const u_short x, u_short y,
     dstrect.h = text->h;
     for (dx = -2; dx <= 2; dx ++) {
       for (dy = -2; dy <= 2; dy ++) {
-	dstrect.x = (rev_x) ? (out_width - x - text->w) : x;
-	dstrect.y = (rev_y) ? (out_height - y - text->h) : y;
-	dstrect.x += dx;
-	dstrect.y += dy;
-	SDL_BlitSurface(text, NULL, SDL_GetWindowSurface(osd_window), &dstrect);
+        dstrect.x = (rev_x) ? (out_width - x - text->w) : x;
+        dstrect.y = (rev_y) ? (out_height - y - text->h) : y;
+        dstrect.x += dx;
+        dstrect.y += dy;
+        SDL_BlitSurface(text, NULL, SDL_GetWindowSurface(osd_window), &dstrect);
       }
     }
     SDL_FreeSurface(text);
