@@ -58,7 +58,7 @@ display_fonts()
 }
 
 
-void
+int8_t
 create(Context_t *ctx)
 {
   screen = xcalloc(SBUFFSIZE, sizeof(Pixel_t));
@@ -66,20 +66,22 @@ create(Context_t *ctx)
   display_fonts();
 
   cv = cucul_create_canvas(SWIDTH, SHEIGHT);
-  if (NULL == cv)
+  if (NULL == cv) {
     xerror("cucul_create_canvas\n");
+  }
 
   dp = caca_create_display(cv);
-  if (NULL == dp)
+  if (NULL == dp) {
     xerror("caca_create_display\n");
-  else {
+  } else {
     caca_set_display_title(dp, "cacaBiniou");
     caca_set_mouse(dp, 0);
   }
 
   dither = cucul_create_dither(8, SWIDTH, SHEIGHT, SWIDTH, 0, 0, 0, 0);
-  if (NULL == dither)
+  if (NULL == dither) {
     xerror("cucul_create_dither\n");
+  }
 
   /* cucul_set_dither_charset(dither, "shades"); */
   /* cucul_set_dither_gamma(dither, 0.5); */
@@ -94,6 +96,8 @@ create(Context_t *ctx)
       printf("[i] exporting caca display with prefix '%s'\n", export_prefix);
     }
   }
+
+  return 1;
 }
 
 
@@ -148,22 +152,27 @@ export(cucul_canvas_t *cv)
     // printf("[i] tmp_file= %s final= %s\n", fname[0], fname[1]);
 
     stream = fopen(fname[0], "w");
-    if (stream == NULL)
+    if (stream == NULL) {
       xperror("fopen");
+    }
 
     res = fwrite(data, sizeof(char), size, stream);
-    if (res != size)
+    if (res != size) {
       xerror("fwrite\n");
+    }
 
     xfree(data);
 
-    if (fclose(stream) != 0)
+    if (fclose(stream) != 0) {
       xperror("fclose");
+    }
 
-    if (rename(fname[0], fname[1]) != 0)
+    if (rename(fname[0], fname[1]) != 0) {
       xperror("rename");
-  } else
+    }
+  } else {
     printf("[!] cucul_export_canvas to format %s failed\n", export_format);
+  }
 }
 
 
@@ -186,17 +195,19 @@ run(Context_t *ctx)
   cucul_clear_canvas(cv);
 
   for (j = 0; j < HEIGHT; j += STEP)
-    for (i = 0; i < WIDTH; i += STEP)
+    for (i = 0; i < WIDTH; i += STEP) {
       *p++ = get_pixel_nc(src, i, MAXY-j);
+    }
   cucul_dither_bitmap(cv, 0, 0,
-		      cucul_get_canvas_width(cv),
-		      cucul_get_canvas_height(cv),
-		      dither, screen);
+                      cucul_get_canvas_width(cv),
+                      cucul_get_canvas_height(cv),
+                      dither, screen);
 
   caca_refresh_display(dp);
 
-  if (NULL != export_format)
+  if (NULL != export_format) {
     export(cv);
+  }
 
   get_events(ctx, dp);
 }
