@@ -61,8 +61,9 @@ Alarm_ring(Alarm_t *a)
   if (b_timer_elapsed(a->timer) >= (float)a->delay) {
     Alarm_init(a);
     return 1;
-  } else
+  } else {
     return 0;
+  }
 }
 
 
@@ -77,8 +78,9 @@ Alarm_elapsed_pct(Alarm_t *a)
 
   assert(pct >= 0);
 
-  if (pct > 1)
+  if (pct > 1) {
     pct = 1;
+  }
 
   return pct;
 }
