@@ -23,52 +23,126 @@
 #include "globals.h"
 #include "images.h"
 #include "colormaps.h"
-#include "pnglite.h"
+
+
+/* Auto-change timers and modes */
+static char *delay_names[MAX_TIMERS] = {
+  "colormaps",
+  "images",
+  "sequences"
+#ifdef WITH_WEBCAM
+  , "webcams"
+#endif
+};
+
+static int delays[MAX_TIMERS][2] = {
+  { DELAY_MIN, DELAY_MAX },  // colormaps
+  { DELAY_MIN, DELAY_MAX },  // images
+  { DELAY_MIN, DELAY_MAX }   // sequences
+#ifdef WITH_WEBCAM
+  , { DELAY_MIN, DELAY_MAX } // webcams
+#endif
+};
+
+uint8_t start_with_first_sequence = 0;
+
+static pthread_t images_thread;
+static struct Images_thread_args {
+  char *buf;
+  const char *themes;
+} images_thread_args;
+
+
+static void *
+biniou_images_thread(void *_args)
+{
+  struct Images_thread_args *args = (struct Images_thread_args *)_args;
+  Images_new(args->buf, args->themes);
+  g_free(args->buf);
+
+  return NULL;
+}
+
+
+static pthread_t colormaps_thread;
+static struct Colormaps_thread_args {
+  char *buf;
+} colormaps_thread_args;
+
+
+static void *
+biniou_colormaps_thread(void *_args)
+{
+  struct Colormaps_thread_args *args = (struct Colormaps_thread_args *)_args;
+  Colormaps_new(args->buf);
+  g_free(args->buf);
+
+  return NULL;
+}
 
 
 void
 biniou_new(const char *datadir, const char *pluginsdir,
-	   const char *schemes, const char *themes,
-#ifndef FIXED
-	   const u_short width, const u_short height,
-#endif
-	   const u_char options,
-	   const uint32_t input_size,
-	   const uint8_t phase_space_delay,
-	   const uint8_t span_size)
+           const char *schemes, const char *themes,
+           const u_char options,
+           const uint32_t input_size,
+           const uint8_t phase_space_delay,
+           const uint8_t span_size, const int webcams)
 {
-  char *buf;
-
-  if (options & B_INIT_VERBOSE)
+  if (options & B_INIT_VERBOSE) {
     libbiniou_verbose = 1;
-
-#ifndef FIXED
-  WIDTH = width;
-  HEIGHT = height;
-#endif
-
-  /* PRNG */
-  b_rand_init();
-
-  /* pnglite */
-  png_init((png_alloc_t)0, (png_free_t)0);
+  }
 
   if (datadir != NULL) {
+    VERBOSE(printf("[+] Loading data files\n"));
+
     /* Images */
-    buf = g_strdup_printf("%s/images/", datadir);
-    VERBOSE(printf("[+] Loading images\n"));
-    Images_new(buf, themes);
-    g_free(buf);
+    images_thread_args.buf = g_strdup_printf("%s/images/", datadir);
+    images_thread_args.themes = themes;
+    pthread_create(&images_thread, NULL, biniou_images_thread, (void *)&images_thread_args);
 
     /* Colormaps */
-    buf = g_strdup_printf("%s/colormaps/", datadir);
-    VERBOSE(printf("[+] Loading colormaps... "));
-    Colormaps_new(buf);
-    g_free(buf);
+    colormaps_thread_args.buf = g_strdup_printf("%s/colormaps/", datadir);
+    pthread_create(&colormaps_thread, NULL, biniou_colormaps_thread, (void *)&colormaps_thread_args);
+
+    pthread_join(images_thread, NULL);
+    pthread_join(colormaps_thread, NULL);
   } else {
     Colormaps_new(NULL);
   }
 
+  /* Create images fader and timer */
+  if (images != NULL) {
+    VERBOSE(printf("[+] Creating images fader (%i images)\n", images->size));
+    context->imgf = ImageFader_new(images->size);
+
+    VERBOSE(printf("[+] Creating images timer (%d..%d)\n", delays[BD_IMAGES][0], delays[BD_IMAGES][1]));
+    context->a_images = Alarm_new(delays[BD_IMAGES][0], delays[BD_IMAGES][1]);
+  }
+
+  /* Create colormaps fader and timer */
+  if (colormaps != NULL) {
+    VERBOSE(printf("[+] Creating colormaps fader (%i colormaps)\n", colormaps->size));
+    context->cf = CmapFader_new(colormaps->size);
+
+    VERBOSE(printf("[+] Creating colormaps timer (%d..%d)\n", delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]));
+    context->a_cmaps = Alarm_new(delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]);
+  }
+
+  /* Create sequences timer */
+  VERBOSE(printf("[+] Creating sequences timer (%d..%d)\n", delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]));
+  context->a_random = Alarm_new(delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]);
+  context->random_mode = BR_NONE;
+
+#ifdef WITH_WEBCAM
+  /* Create webcams timer */
+  if (webcams > 1) {
+    VERBOSE(printf("[+] Creating webcams timer (%d..%d)\n", delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]));
+    context->a_webcams = Alarm_new(delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]);
+    Alarm_init(context->a_webcams);
+  }
+#endif
+
   /* Schemes */
   if (options & B_INIT_SCHEMES) {
     VERBOSE(printf("[+] Loading schemes from %s\n", schemes));
@@ -78,16 +152,10 @@ biniou_new(const char *datadir, const char *pluginsdir,
     Schemes_new_default();
   }
 
-  /* Context */
-  context = Context_new();
-  Context_set_input_size(context, input_size);
-  Context_set_phase_space_delay(context, phase_space_delay);
-  Context_set_span_size(context, span_size);
-
   /* Plugins */
   VERBOSE(printf("[+] Loading plugins\n"));
   plugins = Plugins_new(pluginsdir);
-  Plugins_load(plugins);
+  Plugins_load(plugins, context);
 
   /* Sequences */
   if (options & B_INIT_SEQUENCES) {
@@ -114,13 +182,13 @@ biniou_start()
     VERBOSE(printf("[i] No user sequences found\n"));
     Schemes_random(context);
   } else {
-    GList *prout;
-    Sequence_t *first;
+    GList *item;
+    Sequence_t *start;
 
-    context->sm->curseq = prout = g_list_first(sequences->seqs);
-    first = (Sequence_t *)prout->data;
+    context->sm->curseq = item = (start_with_first_sequence ? g_list_first(sequences->seqs) : g_list_last(sequences->seqs));
+    start = (Sequence_t *)item->data;
 
-    Sequence_copy(first, context->sm->next);
+    Sequence_copy(start, context->sm->next);
     Shuffler_used(sequences->shuffler, 0);
   }
 
@@ -131,8 +199,9 @@ biniou_start()
   /* XXX */
   for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
-    if (output->fullscreen != NULL)
+    if (output->fullscreen != NULL) {
       output->fullscreen(context->fullscreen);
+    }
   }
 }
 
@@ -151,10 +220,11 @@ biniou_delete()
 void
 biniou_end()
 {
-  if (NULL == context)
+  if (NULL == context) {
     xerror("biniou_end() called but context is NULL\n");
-  else
-    context->running = 0; /* This will stop plugins running as threads */
+  } else {
+    context->running = 0;  /* This will stop plugins running as threads */
+  }
 
   /* TODO %d schemes as above */
   VERBOSE(printf("[+] Freeing schemes\n"));
@@ -198,8 +268,9 @@ biniou_run()
 int
 biniou_stop()
 {
-  if (context == NULL)
+  if (context == NULL) {
     return 0;
+  }
 
   context->running = 0;
   return 1;
@@ -207,14 +278,18 @@ biniou_stop()
 
 
 void
-biniou_load_input(const char *dir, const char *name)
+biniou_load_input(const char *dir, const char *name, const double volume_scale)
 {
   Plugin_t *p = NULL;
 
   p = Plugin_new(dir, name, PL_INPUT);
   if (NULL != p) {
-    Plugin_init(p);
-    context->input_plugin = p;
+    if (Plugin_init(p)) {
+      context->input_plugin = p;
+      Context_set_volume_scale(context, volume_scale);
+    } else {
+      xerror("Failed to initialize %s input_n", name);
+    }
   }
 }
 
@@ -241,8 +316,11 @@ biniou_load_output(const char *dir, const char *name)
   for ( ; *output != NULL; output++) {
     p = Plugin_new(dir, *output, PL_OUTPUT);
     if (NULL != p) {
-      Plugin_init(p);
-      context->outputs = g_slist_prepend(context->outputs, p);
+      if (Plugin_init(p)) {
+        context->outputs = g_slist_prepend(context->outputs, p);
+      } else {
+        xerror("Failed to initialize %s output\n", name);
+      }
     }
   }
 
@@ -289,8 +367,9 @@ biniou_go(const u_long nb_frames, const u_char exit)
 
     if (nb_frames != 0) {
       frames--;
-      if (!frames && exit)
-	context->running = 0;
+      if (!frames && exit) {
+        context->running = 0;
+      }
     }
   }
 
@@ -301,14 +380,23 @@ biniou_go(const u_long nb_frames, const u_char exit)
      biniou_go(N);
      biniou_end(); -> will have to do context->running = 0;
   */
-  if (exit)
+  if (exit) {
     biniou_end();
+  }
 }
 
 
 void
-biniou_set_events_cb(void (*f)(Context_t *ctx, const BKey_t *key))
+biniou_set_delay(const enum RandomDelays what, const int min, const int max)
 {
-  assert(NULL != context);
-  context->events_cb = f;
+  if ((max <= min) || (min < 1) || (max < 1)) {
+    xerror("Set random delay for %s: max (%d) must be > min (%d), both values must be > 1\n",
+           delay_names[what], max, min);
+  }
+
+#ifdef DEBUG
+  printf("[i] Setting min..max delays for %s: %d..%d\n", delay_names[what], min, max);
+#endif
+  delays[what][0] = min;
+  delays[what][1] = max;
 }
