@@ -30,10 +30,7 @@
 #define B_INIT_ALL          (B_INIT_SEQUENCES|B_INIT_SCHEMES)
 
 void biniou_new(const char *, const char *, const char *, const char *,
-#ifndef FIXED
-		const u_short, const u_short,
-#endif
-		const u_char, const uint32_t, const uint8_t, const uint8_t);
+                const u_char, const uint32_t, const uint8_t, const uint8_t, const int);
 void biniou_delete();
 
 /* vla le bordel */
@@ -44,18 +41,13 @@ void biniou_start();
 void biniou_end();
 int  biniou_stop();
 
-void biniou_load_input(const char *, const char *);
+void biniou_load_input(const char *, const char *, const double);
 void biniou_set_input(Input_t *);
 void biniou_load_output(const char *, const char *);
 void biniou_set_full_screen(const u_char);
 void biniou_set_max_fps(const u_short);
 void biniou_verbosity(const u_char);
 void biniou_set_random_mode(const enum RandomMode);
-
-/*!
- * Set the events callback function
- */
-void biniou_set_events_cb(void (*)(Context_t *, const BKey_t *));
-
+void biniou_set_delay(const enum RandomDelays, const int, const int);
 
 #endif /* __BINIOU_H */
