@@ -46,8 +46,9 @@ b_rand_init(void)
 void
 b_rand_free(void)
 {
-  if (brand != NULL)
+  if (brand != NULL) {
     g_rand_free(brand);
+  }
 }
 
 
