@@ -26,6 +26,8 @@ void b_rand_init(void);
 void b_rand_free(void);
 
 uint32_t b_rand_int(void);
+/* XXX this should be b_rand_uint_range...
+   b_rand_int_range should return int32_t */
 uint32_t b_rand_int_range(int32_t begin, int32_t end);
 double b_rand_double_range(double begin, double end);
 int b_rand_boolean();
