@@ -50,8 +50,9 @@ Buffer8_clone(const Buffer8_t *src)
 void
 Buffer8_delete(Buffer8_t *buff)
 {
-  if (buff != NULL)
+  if (buff != NULL) {
     xfree(buff->buffer);
+  }
   xfree(buff);
 }
 
@@ -67,13 +68,16 @@ ks_clip_line(short *exists, Point2d_t *p0, Point2d_t *q0, Point2d_t *p, Point2d_
   ks_region(&reg1, x1, y1);
   ks_region(&reg2, x2, y2);
 
-  if (reg1)
+  if (reg1) {
     ++outside;
-  if (reg2)
+  }
+  if (reg2) {
     ++outside;
+  }
 
-  if (!outside)
+  if (!outside) {
     return 0;
+  }
 
   while (reg1 | reg2) {
     if (reg1 & reg2) {
@@ -126,8 +130,10 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
     return;
   };
 
-  p.x = x1; p.y = y1;
-  q.x = x2; q.y = y2;
+  p.x = x1;
+  p.y = y1;
+  q.x = x2;
+  q.y = y2;
 
   if (!ks_clip_line (&exists, &p0, &q0, &p, &q)) {
   } else if (exists) {
@@ -157,23 +163,27 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
 
   if (dy <= dx) {
     for (mod = -((dx + 1) >> 1); ; x1++, mod += dy) {
-      if (mod >/*=*/ 0)
-	y1 += sgn_dy, mod -= dx;
+      if (mod >/*=*/ 0) {
+        y1 += sgn_dy, mod -= dx;
+      }
 
       set_pixel_nc(buff, x1, y1, c);
 
-      if (x1 == x2)
-	return;
+      if (x1 == x2) {
+        return;
+      }
     }
   } else {
     for (mod = -((dy + 1) >> 1); ; y1 += sgn_dy, mod += dx) {
-      if (mod >/*=*/ 0)
-	x1++, mod -= dy;
+      if (mod >/*=*/ 0) {
+        x1++, mod -= dy;
+      }
 
       set_pixel_nc(buff, x1, y1, c);
 
-      if (y1 == y2)
-	return;
+      if (y1 == y2) {
+        return;
+      }
     }
   }
 }
@@ -198,38 +208,14 @@ Buffer8_color_bar(Buffer8_t *buff, const u_short height)
 }
 
 
-void
-Buffer8_mix_interlaced2(Buffer8_t *s1, const Buffer8_t *s2)
-{
-  /* copy half of s2 into s1 */
-  Pixel_t *d = s1->buffer;
-  Pixel_t *s = (Pixel_t *)s2->buffer;
-
-  for (; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d += 2, s += 2)
-    *d = *s;
-}
-
-
-void
-Buffer8_mix_random(Buffer8_t *s1, const Buffer8_t *s2)
-{
-  /* copy half of s2 into s1 with random probability */
-  Pixel_t *d = s1->buffer;
-  Pixel_t *s = (Pixel_t *)s2->buffer;
-
-  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++)
-    if (b_rand_boolean())
-      *d = *s;
-}
-
-
 void
 Buffer8_randomize(Buffer8_t *buff)
 {
   Pixel_t *p = buff->buffer;
 
-  for ( ; p < buff->buffer + BUFFSIZE*sizeof(Pixel_t); p++)
+  for ( ; p < buff->buffer + BUFFSIZE*sizeof(Pixel_t); p++) {
     *p = b_rand_int_range(0, 255);
+  }
 }
 
 
@@ -240,8 +226,9 @@ Buffer8_overlay(Buffer8_t *s1, const Buffer8_t *s2)
   Pixel_t *d = s1->buffer;
   const Pixel_t *s = s2->buffer;
 
-  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++)
+  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++) {
     *d = (Pixel_t)((*s) ? *s : *d);
+  }
 }
 
 
@@ -250,10 +237,11 @@ Buffer8_XOR(Buffer8_t *s1, const Buffer8_t *s2)
 {
   /* XOR pixels from s2 with pixels from s1 */
   Pixel_t *d = s1->buffer;
-  Pixel_t *s = (Pixel_t *)s2->buffer;
+  const Pixel_t *s = s2->buffer;
 
-  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++)
+  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++) {
     *d ^= *s;
+  }
 }
 
 
@@ -262,32 +250,34 @@ Buffer8_average(Buffer8_t *s1, const Buffer8_t *s2)
 {
   /* mix pixels from s2 with pixels from s1 */
   Pixel_t *d = s1->buffer;
-  Pixel_t *s = (Pixel_t *)s2->buffer;
+  const Pixel_t *s = s2->buffer;
 
-  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++)
+  for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++) {
     *d = (Pixel_t)((u_short)*d + (u_short)*s) >> 1;
+  }
 }
 
 
 void
 gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const Pixel_t *grey_data)
 {
-  int srcStride[4]={0,0,0,0};
-  int dstStride[4]={0,0,0,0};
-  const uint8_t *srcSlice[4]={NULL,NULL,NULL,NULL};
-  uint8_t *dst[4]={NULL,NULL,NULL,NULL};
+  int srcStride[4]= {0,0,0,0};
+  int dstStride[4]= {0,0,0,0};
+  const uint8_t *srcSlice[4]= {NULL,NULL,NULL,NULL};
+  uint8_t *dst[4]= {NULL,NULL,NULL,NULL};
   struct SwsContext *sws_context = NULL;
   int ret;
 
   sws_context = sws_getContext(width, height, AV_PIX_FMT_GRAY8,
-			       WIDTH, HEIGHT, AV_PIX_FMT_GRAY8,
+                               WIDTH, HEIGHT, AV_PIX_FMT_GRAY8,
 #ifdef __NetBSD__
-			       SWS_BILINEAR, NULL, NULL, NULL);
+                               SWS_BILINEAR, NULL, NULL, NULL);
 #else
-			       SWS_FAST_BILINEAR, NULL, NULL, NULL);
+                               SWS_FAST_BILINEAR, NULL, NULL, NULL);
 #endif
-  if (NULL == sws_context)
+  if (NULL == sws_context) {
     xerror("sws_getContext\n");
+  }
 
   srcStride[0] = width;
   dstStride[0] = WIDTH;
@@ -295,14 +285,15 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
   dst[0] = (uint8_t *)grey_to;
 
   ret = sws_scale(sws_context,
-		  srcSlice,
-		  srcStride,
-		  0,
-		  height,
-		  dst,
-		  dstStride);
-  if (ret < 0)
+                  srcSlice,
+                  srcStride,
+                  0,
+                  height,
+                  dst,
+                  dstStride);
+  if (ret < 0) {
     xerror("sws_scale\n");
+  }
 
   sws_freeContext(sws_context);
 }
@@ -317,46 +308,46 @@ Buffer8_substract_y(const Buffer8_t *buff1, const Buffer8_t *buff2, const Pixel_
 
   /* let's do the simple form for now (check original code below) */
   /* TODO: optimize */
-  for (; d < dst->buffer+(BUFFSIZE*sizeof(Pixel_t)); b1++, b2++, d++)
+  for (; d < dst->buffer+(BUFFSIZE*sizeof(Pixel_t)); b1++, b2++, d++) {
     *d = (abs(*b1-*b2) > threshold) ? 255 : 0;
+  }
 
 #if 0
-unsigned char *image_bgsubtract_y(RGB32 *src)
-{
-	int i;
-	int R, G, B;
-	RGB32 *p;
-	short *q;
-	unsigned char *r;
-	int v;
+  unsigned char *image_bgsubtract_y(RGB32 *src) {
+    int i;
+    int R, G, B;
+    RGB32 *p;
+    short *q;
+    unsigned char *r;
+    int v;
 
-	p = src;
-	q = (short *)background;
-	r = diff;
-	for(i=0; i<video_area; i++) {
-		R = ((*p)&0xff0000)>>(16-1);
-		G = ((*p)&0xff00)>>(8-2);
-		B = (*p)&0xff;
-		v = (R + G + B) - (int)(*q);
-		*r = ((v + y_threshold)>>24) | ((y_threshold - v)>>24);
+    p = src;
+    q = (short *)background;
+    r = diff;
+    for(i=0; i<video_area; i++) {
+      R = ((*p)&0xff0000)>>(16-1);
+      G = ((*p)&0xff00)>>(8-2);
+      B = (*p)&0xff;
+      v = (R + G + B) - (int)(*q);
+      *r = ((v + y_threshold)>>24) | ((y_threshold - v)>>24);
 
-		p++;
-		q++;
-		r++;
-	}
+      p++;
+      q++;
+      r++;
+    }
 
-	return diff;
-/* The origin of subtraction function is;
- * diff(src, dest) = (abs(src - dest) > threshold) ? 0xff : 0;
- *
- * This functions is transformed to;
- * (threshold > (src - dest) > -threshold) ? 0 : 0xff;
- *
- * (v + threshold)>>24 is 0xff when v is less than -threshold.
- * (v - threshold)>>24 is 0xff when v is less than threshold.
- * So, ((v + threshold)>>24) | ((threshold - v)>>24) will become 0xff when
- * abs(src - dest) > threshold.
- */
-}
+    return diff;
+    /* The origin of subtraction function is;
+     * diff(src, dest) = (abs(src - dest) > threshold) ? 0xff : 0;
+     *
+     * This functions is transformed to;
+     * (threshold > (src - dest) > -threshold) ? 0 : 0xff;
+     *
+     * (v + threshold)>>24 is 0xff when v is less than -threshold.
+     * (v - threshold)>>24 is 0xff when v is less than threshold.
+     * So, ((v + threshold)>>24) | ((threshold - v)>>24) will become 0xff when
+     * abs(src - dest) > threshold.
+     */
+  }
 #endif
 }
