@@ -36,7 +36,8 @@ BufferRGBA_new()
 void
 BufferRGBA_delete(BufferRGBA_t *buff)
 {
-  if (buff != NULL)
+  if (buff != NULL) {
     xfree(buff->buffer);
+  }
   xfree(buff);
 }
