@@ -33,8 +33,8 @@ Cmap8_new()
   for (i = 0; i < 256; i++)
     cmap->colors[i].col.r =
       cmap->colors[i].col.g =
-      cmap->colors[i].col.b =
-      cmap->colors[i].col.a = i;
+        cmap->colors[i].col.b =
+          cmap->colors[i].col.a = i;
 
   cmap->min = 0;
   cmap->max = 255;
@@ -47,8 +47,9 @@ void
 Cmap8_delete(Cmap8_t *cmap)
 {
   xfree(cmap->name);
-  if (cmap->filename != NULL)
+  if (cmap->filename != NULL) {
     xfree(cmap->filename);
+  }
   xfree(cmap);
 }
 
@@ -72,8 +73,9 @@ Cmap8_load(Cmap8_t *cmap, const char *filename)
   }
 
   stream = fopen(filename, "r");
-  if (stream == NULL)
+  if (stream == NULL) {
     xperror("fopen");
+  }
 
   /* TODO: fscanf() verfsion */
   for (i = 0; i < 256; ) {
@@ -121,16 +123,18 @@ Cmap8_copy(const Cmap8_t *from, Cmap8_t *to)
   assert(from != NULL);
   assert(to != NULL);
 
-  if (to->name != NULL)
+  if (to->name != NULL) {
     xfree(to->name);
+  }
 
   assert(from->name != NULL);
   to->name = strdup(from->name);
 
   to->id = from->id;
 
-  for (i = 0; i < 256; i++)
+  for (i = 0; i < 256; i++) {
     to->colors[i] = from->colors[i];
+  }
 
   to->min = from->min;
   to->max = from->max;
@@ -173,22 +177,25 @@ Cmap8_load_binary(Cmap8_t *cmap, const char *filename)
   size_t res;
 
   fd = open(filename, O_RDONLY);
-  if (fd == -1)
+  if (fd == -1) {
     return -1;
+  }
 
 #define BTR (256*sizeof(rgba_t)) /* Bytes To Read */
   res = read(fd, (void *)cmap->colors, BTR);
   if (res != BTR) {
     printf("[!] short read in Cmap8_load_binary '%s'\n", filename);
     r = close(fd);
-    if (r == -1)
+    if (r == -1) {
       xperror("close");
+    }
     return -1;
   }
 
   r = close(fd);
-  if (r == -1)
+  if (r == -1) {
     xperror("close");
+  }
 
   cmap->compressed = 1;
 
@@ -224,8 +231,9 @@ Cmap8_save(Cmap8_t *cmap)
     printf("[!] short write in Cmap8_save\n");
     fclose(stream);
     return -1;
-  } else
+  } else {
     fclose(stream);
+  }
 
   cmap->compressed = 1; /* to NOT save it again on disk if calling Cmap8_save */
 
@@ -239,7 +247,8 @@ Cmap8_shift_left(Cmap8_t *cmap)
   int i;
   rgba_t col0 = cmap->colors[0];
 
-  for (i = 0; i < 255; i++)
+  for (i = 0; i < 255; i++) {
     cmap->colors[i] = cmap->colors[i+1];
+  }
   cmap->colors[255] = col0;
 }
