@@ -67,32 +67,32 @@ CmapFader_init(CmapFader_t *cf)
     const RGBA_t col_dst = cf->dst->colors[i].col;
 
     /* delta values */
-/*     cf->fader->delta[i*3+0] = */
-/*       ((float)col_dst.r-(float)col_src.r) */
-/*       / (float)(cf->fader->max); */
-/*     cf->fader->delta[i*3+1] = */
-/*       ((float)col_dst.g-(float)col_src.g) */
-/*       / (float)(cf->fader->max); */
-/*     cf->fader->delta[i*3+2] = */
-/*       ((float)col_dst.b-(float)col_src.b) */
-/*       / (float)(cf->fader->max); */
+    /*     cf->fader->delta[i*3+0] = */
+    /*       ((float)col_dst.r-(float)col_src.r) */
+    /*       / (float)(cf->fader->max); */
+    /*     cf->fader->delta[i*3+1] = */
+    /*       ((float)col_dst.g-(float)col_src.g) */
+    /*       / (float)(cf->fader->max); */
+    /*     cf->fader->delta[i*3+2] = */
+    /*       ((float)col_dst.b-(float)col_src.b) */
+    /*       / (float)(cf->fader->max); */
     fader->delta[i*3+0] = (long)
-      ((float)col_dst.r-(float)col_src.r)
-      / (float)(fader->max)*MFACTOR;
+                          ((float)col_dst.r-(float)col_src.r)
+                          / (float)(fader->max)*MFACTOR;
     fader->delta[i*3+1] = (long)
-      ((float)col_dst.g-(float)col_src.g)
-      / (float)(fader->max)*MFACTOR;
+                          ((float)col_dst.g-(float)col_src.g)
+                          / (float)(fader->max)*MFACTOR;
     fader->delta[i*3+2] = (long)
-      ((float)col_dst.b-(float)col_src.b)
-      / (float)(fader->max)*MFACTOR;
+                          ((float)col_dst.b-(float)col_src.b)
+                          / (float)(fader->max)*MFACTOR;
     fader->delta[i*3+3] = (long)
-      ((float)col_dst.a-(float)col_src.a)
-      / (float)(fader->max)*MFACTOR;
+                          ((float)col_dst.a-(float)col_src.a)
+                          / (float)(fader->max)*MFACTOR;
 
     /* initial values */
-/*     cf->fader->tmp[i*3+0] = (float)col_src.r; */
-/*     cf->fader->tmp[i*3+1] = (float)col_src.g; */
-/*     cf->fader->tmp[i*3+2] = (float)col_src.b; */
+    /*     cf->fader->tmp[i*3+0] = (float)col_src.r; */
+    /*     cf->fader->tmp[i*3+1] = (float)col_src.g; */
+    /*     cf->fader->tmp[i*3+2] = (float)col_src.b; */
     fader->tmp[i*3+0] = (u_long)col_src.r*MFACTOR;
     fader->tmp[i*3+1] = (u_long)col_src.g*MFACTOR;
     fader->tmp[i*3+2] = (u_long)col_src.b*MFACTOR;
@@ -110,6 +110,9 @@ CmapFader_run(CmapFader_t *cf)
   Cmap8_t *cur = cf->cur;
   const u_long elapsed = Fader_elapsed(fader);
 
+#ifdef DEBUG_FADERS
+  printf("Cf ");
+#endif
   Fader_start(fader);
   fader->faded += elapsed;
 
@@ -125,20 +128,20 @@ CmapFader_run(CmapFader_t *cf)
       /* FADE DA HOUSE */
       /* TODO optimize pointer version array toussa --oliv3 */
       cur->colors[i].col.r =
-	(u_char)((fader->tmp[i*3+0] +=
-		  elapsed*fader->delta[i*3+0])/MFACTOR);
+        (u_char)((fader->tmp[i*3+0] +=
+                    elapsed*fader->delta[i*3+0])/MFACTOR);
       cur->colors[i].col.g =
-	(u_char)((fader->tmp[i*3+1] +=
-		  elapsed*fader->delta[i*3+1])/MFACTOR);
+        (u_char)((fader->tmp[i*3+1] +=
+                    elapsed*fader->delta[i*3+1])/MFACTOR);
       cur->colors[i].col.b =
-	(u_char)((fader->tmp[i*3+2] +=
-		  elapsed*fader->delta[i*3+2])/MFACTOR);
+        (u_char)((fader->tmp[i*3+2] +=
+                    elapsed*fader->delta[i*3+2])/MFACTOR);
 
       /* FIXME alpha fading seems broken */
       cur->colors[i].col.a = 255;
       /* cur->colors[i].col.a = */
-      /* 	(u_char)((fader->tmp[i*3+3] += */
-      /* 		  elapsed*fader->delta[i*3+3])/MFACTOR); */
+      /*   (u_char)((fader->tmp[i*3+3] += */
+      /*       elapsed*fader->delta[i*3+3])/MFACTOR); */
     }
   }
   Cmap8_findMinMax(cur);
@@ -152,16 +155,15 @@ CmapFader_set(CmapFader_t *cf)
   cf->dst = colormaps->cmaps[cf->fader->target];
 
   if (cf->dst->name != NULL) {
-    if (libbiniou_verbose)
+    if (libbiniou_verbose) {
       printf("[i] Using colormap '%s'\n", cf->dst->name);
-  } else
+    }
+  } else {
     xerror("Colormap without name, WTF #@!\n");
+  }
 
-  if (cf->fader->fade)
-    CmapFader_init(cf);
-  else
-    Cmap8_copy(cf->dst, cf->cur);
-  cf->fader->fading = cf->fader->fade;
+  CmapFader_init(cf);
+  cf->fader->fading = 1;
   Cmap8_findMinMax(cf->cur);
   cf->refresh = 1;
 }
