@@ -20,7 +20,6 @@
 #include "globals.h"
 #include "colormaps.h"
 #include "brandom.h"
-#include "pbar.h"
 
 
 Colormaps_t *colormaps = NULL;
@@ -49,29 +48,27 @@ Colormaps_new(const char *directoryname)
   GSList *tmp = NULL;
   uint16_t size = 0;
   GSList *t;
-  PBar_t *pb = NULL;
 
-  if (directoryname == NULL)
+  if (directoryname == NULL) {
     goto error;
+  }
 
   dir = opendir(directoryname);
   if (dir == NULL) {
     fprintf(stderr, "[!] Error while reading colormaps directory content: %s\n",
-	    strerror(errno));
+            strerror(errno));
     goto error;
   }
 
-  if (libbiniou_verbose)
-    pb = pbar_new();
-
   while ((entry = readdir(dir)) != NULL) {
     uint32_t hash;
     Cmap8_t *map;
     char *filename;
     const char *sentry = entry->d_name;
 
-    if (sentry[0] == '.')
+    if (sentry[0] == '.') {
       continue;
+    }
 
     /* we only look for filenames that end with
      * ".map" (fractint colormaps)
@@ -79,10 +76,13 @@ Colormaps_new(const char *directoryname)
      */
     if ((filename = strrchr(sentry, '.')) == NULL)
       /* does not have a trailing '.' -> next one */
+    {
       continue;
+    }
 
-    if (strncmp(filename, ".map", 4*sizeof(char)) && strncmp(filename, ".gpl", 4*sizeof(char)))
+    if (strncmp(filename, ".map", 4*sizeof(char)) && strncmp(filename, ".gpl", 4*sizeof(char))) {
       continue;
+    }
 
     map = Cmap8_new();
     hash = FNV_hash(sentry);
@@ -99,32 +99,22 @@ Colormaps_new(const char *directoryname)
       g_free(filename);
 
       /* we reuse char *filename here */
-      if ((filename = strrchr(map->name, '.')) != NULL)
-	*filename = '\0'; /* spr0tch */
+      if ((filename = strrchr(map->name, '.')) != NULL) {
+        *filename = '\0';  /* spr0tch */
+      }
 
       Cmap8_findMinMax(map);
     }
 
     tmp = g_slist_prepend(tmp, (gpointer)map);
     size++;
-
-    if (libbiniou_verbose && !(size % 5))
-      pbar_step(pb);
-
-    for (t = g_slist_next(tmp);
-	 t != NULL;
-	 t = g_slist_next(t))
-      if (((Cmap8_t *)t->data)->id == hash)
-	xerror("Duplicated colormap hash: %s / %s, %li\n",
-	       ((Cmap8_t *)t->data)->name, sentry, hash);
   }
-  if (closedir(dir) == -1)
+  if (closedir(dir) == -1) {
     xperror("closedir");
+  }
 
   colormaps = xcalloc(1, sizeof(Colormaps_t));
   if (libbiniou_verbose) {
-    printf("done.\n");
-    pbar_delete(pb);
     printf("[c] Loaded %d colormaps\n", size);
   }
 
@@ -133,20 +123,20 @@ Colormaps_new(const char *directoryname)
 
     colormaps->cmaps = xcalloc(size, sizeof(Cmap8_t *));
     for (i = 0, t = tmp;
-	 t != NULL;
-	 t = g_slist_next(t), i++) {
+         t != NULL;
+         t = g_slist_next(t), i++) {
       colormaps->cmaps[i] = (Cmap8_t *)t->data;
     }
     g_slist_free(tmp);
     colormaps->size = size;
 
     qsort((void *)colormaps->cmaps, (size_t)colormaps->size,
-	  (size_t)sizeof(Cmap8_t *), &Colormaps_compare);
+          (size_t)sizeof(Cmap8_t *), &Colormaps_compare);
 
     return;
   }
 
- error:
+error:
   colormaps = xcalloc(1, sizeof(Colormaps_t));
   colormaps->cmaps = xcalloc(1, sizeof(Cmap8_t *));
   colormaps->size = 1;
@@ -160,8 +150,9 @@ Colormaps_delete()
   if (colormaps != NULL) {
     uint16_t i;
 
-    for (i = 0; i < colormaps->size; i++)
+    for (i = 0; i < colormaps->size; i++) {
       Cmap8_delete(colormaps->cmaps[i]);
+    }
     xfree(colormaps->cmaps);
     xfree(colormaps);
   }
@@ -176,11 +167,13 @@ Colormaps_name(const uint32_t id)
   assert(colormaps != NULL);
 
   for (i = 0; i < colormaps->size; i++)
-    if (colormaps->cmaps[i]->id == id)
+    if (colormaps->cmaps[i]->id == id) {
       return colormaps->cmaps[i]->name;
+    }
 
-  if (id == 0)
+  if (id == 0) {
     return colormaps->cmaps[0]->name;
+  }
 
   xerror("Colormaps_name: id %li not found\n", id);
 
@@ -196,8 +189,9 @@ Colormaps_index(const uint32_t id)
   assert(colormaps != NULL);
 
   for (i = 0; i < colormaps->size; i++)
-    if (colormaps->cmaps[i]->id == id)
+    if (colormaps->cmaps[i]->id == id) {
       return i;
+    }
 
   xerror("Colormaps_index: id %li not found\n", id);
 
@@ -213,8 +207,9 @@ Colormaps_find(const char *name)
   assert(colormaps != NULL); /* should have at least a grayscale colormap */
 
   for (i = 0; i < colormaps->size; i++)
-    if (!strcmp(colormaps->cmaps[i]->name, name))
+    if (!strcmp(colormaps->cmaps[i]->name, name)) {
       return colormaps->cmaps[i]->id;
+    }
 
   fprintf(stderr, "[!] Colormap '%s' not found\n", name);
   return colormaps->cmaps[0]->id; /* Use the first colormap by default */
@@ -227,11 +222,11 @@ Colormaps_random_id()
   uint16_t idx = 0;
 
   assert(colormaps != NULL);
+  assert(colormaps->size); // There is at least a default colormap
 
-  /* printf("b_rand_int_range(0, %d)\n", cmaps->size-1); */
-  if (colormaps->size > 1)
-    idx = b_rand_int_range(0, colormaps->size-1);
-  else {
+  if (colormaps->size > 1) {
+    idx = b_rand_int_range(0, colormaps->size - 1);
+  } else {
     /* no colormaps loaded but the default */
 #ifdef DEBUG
     printf("[i] Tututut no colormaps loaded, random gives the default\n");
