@@ -54,7 +54,7 @@ extern unsigned short WIDTH, HEIGHT;
 #define MAXLEN     _POSIX2_LINE_MAX
 
 /* maximum length of a sequence */
-#define MAX_SEQ_LEN	254
+#define MAX_SEQ_LEN  254
 
 /* handy shortcuts */
 #define DEC(val, maxval) do { if (!val) val = maxval-1; else --val; } while (0)
@@ -69,4 +69,16 @@ extern unsigned short WIDTH, HEIGHT;
 /* 3D z-buffer */
 #define ZMAX 6.0
 
+/* volume scaling */
+#define VOLUME_SCALE_STEP 0.1
+
+/* 3D scale factor */
+#define SCALE_FACTOR_MIN  1.03
+#define SCALE_FACTOR_MULT 0.9 // OSD changes via mouse wheel
+/* 3D rotations */
+#define DEFAULT_ROT_AMOUNT 0.0025
+#define ROT_AMOUNT_MIN     0.001
+/* rotations factor */
+#define DEFAULT_ROT_FACTOR 4
+
 #endif /* __BINIOU_CONSTANTS_H */
