@@ -33,7 +33,7 @@
 #include "brandom.h"
 #include "buffer_RGBA.h"
 
-#define NFPS       25 /* to get mean fps */
+#define NFPS     25 /* to get mean fps */
 
 enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 
@@ -42,9 +42,9 @@ enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 #define DELAY_MAX 30
 enum RandomDelays { BD_COLORMAPS=0, BD_IMAGES=1, BD_SEQUENCES=2
 #ifdef WITH_WEBCAM
-		    , BD_WEBCAMS=3
+, BD_WEBCAMS=3
 #endif
-} RandomDelays_e;
+                  } RandomDelays_e;
 
 
 #define ACTIVE_BUFFER  0
@@ -57,7 +57,7 @@ enum RandomDelays { BD_COLORMAPS=0, BD_IMAGES=1, BD_SEQUENCES=2
 #define NSCREENS 3
 #endif
 
-#define MAX_CAMS       2
+#define MAX_CAMS       6
 
 /* store the last N frames from the webcam -same as EffectTV */
 #define CAM_SAVE 32
@@ -81,11 +81,21 @@ typedef struct Context_s {
    * 2 = save_buffer    - push/pop screen for lens effects
    */
 
+  int webcams;
 #ifdef WITH_WEBCAM
   /* webcam */
   Buffer8_t *cam_save[MAX_CAMS][CAM_SAVE];
   Buffer8_t *cam_ref[MAX_CAMS];
+  Buffer8_t *cam_ref0[MAX_CAMS]; /* reference picture taken on program start */
   u_char ref_taken[MAX_CAMS];
+
+  /* auto-change webcams */
+  Shuffler_t *webcams_shuffler;
+  Alarm_t    *a_webcams;
+
+  /* Webcam */
+  pthread_mutex_t cam_mtx[MAX_CAMS];
+  u_char cam; /* active webcam */
 #endif
 
   /* Faders */
@@ -99,19 +109,12 @@ typedef struct Context_s {
 
   SequenceManager_t *sm;
 
-  /* TODO move this to a global */
   Params3d_t params3d;
 
   /* auto-change sequences (user or generated) */
   enum RandomMode random_mode;
   Alarm_t  *a_random;
 
-#ifdef WITH_WEBCAM
-  /* auto-change webcams */
-  Shuffler_t *webcams_shuffler;
-  Alarm_t    *a_webcams;
-#endif
-
   u_long   frames;
 
   GList    *events;
@@ -126,25 +129,18 @@ typedef struct Context_s {
   int      fps[NFPS];
   BTimer_t  *fps_timer;
 
+  uint8_t  window_decorations:1;
   u_char   fullscreen:1;
   u_char   display_colormap:1;
   u_char   take_screenshot:1;
   u_char   bypass:1;
 
-  void (*events_cb)(struct Context_s *, const BKey_t *); /* events callback */
-
   /* Banks */
   u_char   bank_mode; /* will default to SEQUENCES */
   uint32_t banks[3][MAX_BANKS][MAX_BANKS];
   u_char   bankset[3];
   u_char   bank[3]; /* the bank used */
 
-#ifdef WITH_WEBCAM
-  /* Webcam */
-  pthread_mutex_t cam_mtx[MAX_CAMS];
-  u_char cam; /* active webcam */
-#endif
-
   /* OpenGL */
 #ifdef WITH_GL
   u_char texture_ready:1;
@@ -164,10 +160,16 @@ typedef struct Context_s {
   uint32_t input_size;
   uint8_t phase_space_delay;
   uint8_t span_size;
+
+  char auto_colormaps;
+  char auto_images;
+
+  /* used to randomly mix buffers */
+  Buffer8_t *random;
 } Context_t;
 
 
-Context_t *Context_new();
+Context_t *Context_new(const int);
 void Context_delete(Context_t *);
 
 void Context_set(Context_t *);
@@ -177,7 +179,7 @@ void Context_run(Context_t *);
 void Context_update(Context_t *);
 void Context_update_auto(Context_t *);
 
-int  Context_add_rand(Sequence_t *, const enum PluginOptions, const int);
+int  Context_add_rand(Sequence_t *, const enum PluginOptions, const int, const Plugin_t *);
 void Context_randomize(Context_t *);
 
 void Context_set_max_fps(Context_t *, const u_short);
@@ -200,7 +202,7 @@ int Context_event(Context_t *, const Event_t *); /* TODO void ? */
 void Context_process_events(Context_t *);
 void Context_add_event(Context_t *, const Event_t *);
 void Context_send_event(Context_t *, const enum RcptTo, const enum Command,
-		        const enum Arg);
+                        const enum Arg);
 
 Buffer8_t *active_buffer(const Context_t *);
 Buffer8_t *passive_buffer(const Context_t *);
@@ -260,7 +262,6 @@ void Context_make_GL_RGBA_texture(Context_t *ctx, const u_char);
 void Context_make_GL_gray_texture(Context_t *ctx, const u_char);
 #endif
 
-void Context_set_delay(const enum RandomDelays, const int, const int);
 void Context_set_shuffler_mode(const enum RandomDelays, const enum ShufflerMode);
 enum ShufflerMode Context_get_shuffler_mode(const enum RandomDelays);
 
@@ -275,4 +276,10 @@ uint32_t Context_get_phase_space_samples(const Context_t *);
 void Context_set_span_size(Context_t *, const uint8_t);
 uint8_t Context_get_span_size(const Context_t *);
 
+/* volume scaling */
+void Context_set_volume_scale(Context_t *, const double);
+double Context_get_volume_scale(const Context_t *);
+
+void Context_mix_buffers(const Context_t *, Buffer8_t *[2]);
+
 #endif /* __BINIOU_CONTEXT_H */
