@@ -26,12 +26,13 @@ void
 Context_store_bank(Context_t *ctx, const u_char bank)
 {
   assert(bank < MAX_BANKS);
-  if (ctx->bank_mode == SEQUENCES)
+  if (ctx->bank_mode == SEQUENCES) {
     ctx->banks[SEQUENCES][ctx->bankset[SEQUENCES]][bank] = ctx->sm->cur->id;
-  else if (ctx->bank_mode == COLORMAPS)
+  } else if (ctx->bank_mode == COLORMAPS) {
     ctx->banks[COLORMAPS][ctx->bankset[COLORMAPS]][bank] = ctx->sm->cur->cmap_id;
-  else if (ctx->bank_mode == IMAGES)
+  } else if (ctx->bank_mode == IMAGES) {
     ctx->banks[IMAGES][ctx->bankset[IMAGES]][bank] = ctx->sm->cur->image_id;
+  }
 }
 
 
@@ -65,25 +66,25 @@ Context_save_banks(const Context_t *ctx)
   for (m = 0; m < 3; m++)
     for (bs = 0; bs < MAX_BANKS; bs++)
       for (b = 0; b < MAX_BANKS; b++)
-	if (ctx->banks[m][bs][b]) {
-	  char str[20];
-	  xmlNode *nd;
+        if (ctx->banks[m][bs][b]) {
+          char str[20];
+          xmlNode *nd;
 
-	  memset(str, '\0', 20);
-	  g_snprintf(str, 19, "%"PRIu32, ctx->banks[m][bs][b]);
+          memset(str, '\0', 20);
+          g_snprintf(str, 19, "%"PRIu32, ctx->banks[m][bs][b]);
 
-	  nd = xmlNewChild(node, NULL, (const xmlChar *)"bank", (const xmlChar *)str);
+          nd = xmlNewChild(node, NULL, (const xmlChar *)"bank", (const xmlChar *)str);
 
-	  memset(str, '\0', 20);
-	  g_snprintf(str, 19, "%d", bs);
-	  xmlSetProp(nd, (const xmlChar *)"set", (const xmlChar *)str);
+          memset(str, '\0', 20);
+          g_snprintf(str, 19, "%d", bs);
+          xmlSetProp(nd, (const xmlChar *)"set", (const xmlChar *)str);
 
-	  memset(str, '\0', 20);
-	  g_snprintf(str, 19, "%d", m);
-	  xmlSetProp(nd, (const xmlChar *)"mode", (const xmlChar *)str);
+          memset(str, '\0', 20);
+          g_snprintf(str, 19, "%d", m);
+          xmlSetProp(nd, (const xmlChar *)"mode", (const xmlChar *)str);
 
-	  xml_set_id(nd, b);
-	}
+          xml_set_id(nd, b);
+        }
 
   xmlKeepBlanksDefault(0);
   xmlSaveFormatFile(filename, doc, 1);
@@ -106,15 +107,18 @@ Context_load_banks(Context_t *ctx)
 
   for (m = 0; m < 3; m++)
     for (i = 0; i < MAX_BANKS; i++)
-      for (j = 0; j < MAX_BANKS; j++)
-       ctx->banks[m][i][j] = 0;
+      for (j = 0; j < MAX_BANKS; j++) {
+        ctx->banks[m][i][j] = 0;
+      }
 
   home_dir = g_get_home_dir();
   filename = g_strdup_printf("%s/." PACKAGE_NAME "/banks.xml", home_dir);
 
   res = stat(filename, &dummy);
-  if (-1 == res)
+  if (-1 == res) {
+    g_free(filename);
     return;
+  }
 
   /* BLA ! */
   xmlKeepBlanksDefault(0);
@@ -122,20 +126,24 @@ Context_load_banks(Context_t *ctx)
 
   doc = xmlParseFile(filename);
   g_free(filename);
-  if (doc == NULL)
+  if (doc == NULL) {
     return;
+  }
 
   node = xmlDocGetRootElement(doc);
-  if (node == NULL)
+  if (node == NULL) {
     xerror("Banks: xmlDocGetRootElement error\n");
+  }
 
   node = xmlFindElement("banks", node);
-  if (node == NULL)
+  if (node == NULL) {
     xerror("Banks: no <banks> found\n");
+  }
 
   bank_node = node->xmlChildrenNode;
-  if (bank_node == NULL) /* Empty banks.xml file */
+  if (bank_node == NULL) { /* Empty banks.xml file */
     return;
+  }
 
   while (bank_node != NULL) {
     long tmp0, tmp1, tmp2;
@@ -146,9 +154,9 @@ Context_load_banks(Context_t *ctx)
     youhou = xmlGetProp(bank_node, (const xmlChar *)"mode");
     tmp0 = getintfield(youhou);
     xmlFree(youhou);
-    if (-1 == tmp0)
+    if (-1 == tmp0) {
       tmp0 = SEQUENCES;
-    else {
+    } else {
       assert(tmp0 >= 0);
       assert(tmp0 < 3);
     }
@@ -166,9 +174,9 @@ Context_load_banks(Context_t *ctx)
     assert(tmp2 < MAX_BANKS);
 
     res = xmlGetOptionalLong(doc, bank_node, &tmp3);
-    if (res == -1)
+    if (res == -1) {
       xerror("Banks: no value set\n");
-    else {
+    } else {
       ctx->banks[tmp0][tmp1][tmp2] = tmp3;
 #ifdef DEBUG
       printf("[i] Mode: %li Bankset: %li Bank: %li id: %li\n", tmp0, tmp1, tmp2, tmp3);
