@@ -29,8 +29,9 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   Pixel_t *res;
   u_long c, i = 0;
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
   src = buf->buffer;
 
   res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
@@ -41,8 +42,9 @@ export_RGB_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
     res[i++] = colors[src[c]].col.b;
   }
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
 
   return res;
 }
@@ -57,8 +59,9 @@ export_BGR_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   Pixel_t *res;
   u_long c, i = 0;
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
   src = buf->buffer;
 
   res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
@@ -69,8 +72,9 @@ export_BGR_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
     res[i++] = colors[src[c]].col.r;
   }
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
 
   return res;
 }
@@ -99,8 +103,9 @@ export_YUV_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
   Pixel_t *res;
   u_long c, i = 0;
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
   src = buf->buffer;
 
   res = xmalloc(3*BUFFSIZE*sizeof(Pixel_t));
@@ -122,8 +127,9 @@ export_YUV_buffer(const Context_t *ctx, const u_char screen, const u_char flip)
     res[i++] = 0.615*CR - 0.51498*CG - 0.10001*CB;
   }
 
-  if (flip)
+  if (flip) {
     Buffer8_flip_v(buf);
+  }
 
   return res;
 }
@@ -146,8 +152,9 @@ export_RGBA_buffer(const Context_t *ctx, const u_char screen)
   assert(NULL != dst);
   start = src;
 
-  for ( ; src < start+BUFFSIZE*sizeof(Pixel_t); src++, dst++)
+  for ( ; src < start+BUFFSIZE*sizeof(Pixel_t); src++, dst++) {
     *dst = colors[*src].col;
+  }
 
   return ctx->rgba_buffers[screen]->buffer;
 }
