@@ -29,10 +29,6 @@
 
 #define BARSIZE (HEIGHT/20) /* Colormap bar size */
 
-#ifdef WITH_WEBCAM
-extern int webcams;
-#endif
-
 
 static void
 Context_boundary(Context_t *ctx)
@@ -63,12 +59,14 @@ Context_sync(Context_t *ctx)
   const float rrt = b_timer_elapsed(ctx->fps_timer);
   const float sleep = ctx->i_max_fps - rrt;
 
-  for (i = 0; i < NFPS-1; i++)
+  for (i = 0; i < NFPS-1; i++) {
     ctx->fps[i] = ctx->fps[i+1];
+  }
   ctx->fps[i] = (rrt > 0) ? (1.0/rrt) : 0.0;
 
-  if (sleep > 0)
+  if (sleep > 0) {
     ms_sleep(sleep*MFACTOR);
+  }
 
   b_timer_start(ctx->fps_timer);
 }
@@ -91,14 +89,15 @@ Context_sequence(Context_t *ctx)
     Plugin_t *P = layer->plugin;
 
     assert(P != NULL);
-    if (P == ctx->sm->cur->lens)
+    if (P == ctx->sm->cur->lens) {
       push_buffer(ctx);
+    }
 
     if (P->run != NULL)
       if (!ctx->bypass || (ctx->bypass && !(*P->options & BEQ_MUTE_CAM))) {
-	P->run(ctx);
-	P->calls++;
-	count++;
+        P->run(ctx);
+        P->calls++;
+        count++;
       }
 
     switch (layer->mode) {
@@ -121,9 +120,11 @@ Context_sequence(Context_t *ctx)
       Buffer8_average(active_buffer(ctx), passive_buffer(ctx));
       break;
 
-    case RANDOM:
-      Buffer8_mix_random(active_buffer(ctx), passive_buffer(ctx));
-      break;
+    case RANDOM: {
+      Buffer8_t *buffs[2] = { active_buffer(ctx), passive_buffer(ctx) };
+      Context_mix_buffers(ctx, buffs);
+    }
+    break;
 
     default:
       xerror("Unsupported layer mode %d\n", layer->mode);
@@ -147,38 +148,41 @@ Context_run(Context_t *ctx)
   GSList *outputs = ctx->outputs;
 
   /* sync fps */
-  if (ctx->sync_fps)
+  if (ctx->sync_fps) {
     Context_sync(ctx);
+  }
 
   /* Auto-change sequence */
   if (Alarm_ring(ctx->a_random)) {
     if (ctx->random_mode == BR_SCHEMES) {
-      if ((NULL != schemes) && (schemes->size > 1))
-	Schemes_random(ctx);
+      if ((NULL != schemes) && (schemes->size > 1)) {
+        Schemes_random(ctx);
+      }
     } else if (ctx->random_mode == BR_SEQUENCES) {
-      if ((NULL != sequences) && (sequences->size > 1))
-	Context_random_sequence(ctx);
+      if ((NULL != sequences) && (sequences->size > 1)) {
+        Context_random_sequence(ctx);
+      }
     } else if (ctx->random_mode == BR_BOTH) {
       if (b_rand_boolean()) {
-	if ((NULL != schemes) && (schemes->size > 1)) {
-	  printf("[+] Random scheme\n");
-	  Schemes_random(ctx);
-	}
+        if ((NULL != schemes) && (schemes->size > 1)) {
+          printf("[+] Random scheme\n");
+          Schemes_random(ctx);
+        }
       } else {
-	if ((NULL != sequences) && (sequences->size > 1)) {
-	  printf("[+] Random sequence\n");
-	  Context_random_sequence(ctx);
-	}
+        if ((NULL != sequences) && (sequences->size > 1)) {
+          printf("[+] Random sequence\n");
+          Context_random_sequence(ctx);
+        }
       }
     }
   }
 
   /* Auto-change image */
-  /* Only if there are more than one image loaded */
-  if ((images != NULL) && (images->size > 1)) {
+  if (ctx->imgf != NULL) {
     /* Timer elapsed ? */
-    if (ctx->imgf->on && Alarm_ring(ctx->a_images))
+    if (ctx->imgf->on && Alarm_ring(ctx->a_images)) {
       ImageFader_random(ctx->imgf);
+    }
     /* Fade image */
     if (ImageFader_ring(ctx->imgf)) {
       ImageFader_run(ctx->imgf);
@@ -187,22 +191,19 @@ Context_run(Context_t *ctx)
   }
 
   /* Auto-change colormap */
-  assert(colormaps != NULL);
-  /* Only if there are more than one colormap loaded */
-  if (colormaps->size > 1) {
-    /* Timer elapsed ? */
-    if (ctx->cf->on && Alarm_ring(ctx->a_cmaps))
-      CmapFader_random(ctx->cf);
-    /* Fade colormap */
-    if (CmapFader_ring(ctx->cf)) {
-      CmapFader_run(ctx->cf);
-      ctx->sm->cur->cmap_id = ctx->cf->dst->id;
-    }
+  /* Timer elapsed ? */
+  if (ctx->cf->on && Alarm_ring(ctx->a_cmaps)) {
+    CmapFader_random(ctx->cf);
+  }
+  /* Fade colormap */
+  if (CmapFader_ring(ctx->cf)) {
+    CmapFader_run(ctx->cf);
+    ctx->sm->cur->cmap_id = ctx->cf->dst->id;
   }
 
 #ifdef WITH_WEBCAM
   /* Auto-change webcam */
-  if ((webcams > 1) && Alarm_ring(ctx->a_webcams)) {
+  if ((ctx->webcams > 1) && Alarm_ring(ctx->a_webcams)) {
     u_short cam_no = Shuffler_get(ctx->webcams_shuffler);
     ctx->cam = cam_no;
 #ifdef DEBUG
@@ -217,10 +218,12 @@ Context_run(Context_t *ctx)
     input->run(ctx);
     input->calls++;
   }
+  if (ctx->input != NULL) {
+    Input_process(ctx->input);
+  }
 
   /* 3D stuff */
-  if (ctx->params3d.do_auto_rotate)
-    Params3d_change_rotations(&ctx->params3d);
+  Params3d_change_rotations(&ctx->params3d);
 
 #ifdef WITH_GL
   glClearColor(0, 0, 0, 0);
@@ -231,15 +234,15 @@ Context_run(Context_t *ctx)
   glLoadIdentity();
 
   gluPerspective(ctx->params3d.gl_fov, (float)WIDTH/(float)HEIGHT,
-		 0.1, 10); //ZMAX);
+                 0.1, 10); //ZMAX);
   gluLookAt(0, 0, 5, //3.14,
-	    0, 0, -1, //-3.14,
-	    0, 1, 0);
+            0, 0, -1, //-3.14,
+            0, 1, 0);
 
   glShadeModel(GL_SMOOTH);
 
   glClearDepth(ZMAX),
-  glEnable(GL_DEPTH_TEST);
+               glEnable(GL_DEPTH_TEST);
   glDepthFunc(GL_LEQUAL);
 
   glEnable(GL_BLEND);
@@ -264,18 +267,15 @@ Context_run(Context_t *ctx)
 
   /* show the current colormap */
   if (ctx->display_colormap) {
-    if (ctx->sm->cur->lens == NULL)
-	push_buffer(ctx);
+    if (ctx->sm->cur->lens == NULL) {
+      push_buffer(ctx);
+    }
     Buffer8_color_bar(active_buffer(ctx), BARSIZE);
   }
 
-  /* TODO: use plugin on_key callback */
   for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
 
-    if ((ctx->cf != NULL) && ctx->cf->refresh && (output->set_cmap != NULL))
-      output->set_cmap(ctx);
-
     /* TODO print a warning: an output plugin without run() is a bug */
     if (output->run != NULL) {
       output->run(ctx);
@@ -293,8 +293,9 @@ Context_run(Context_t *ctx)
   }
 
   /* Restore possibly saved buffer */
-  if ((ctx->sm->cur->lens != NULL) || ctx->display_colormap)
+  if ((ctx->sm->cur->lens != NULL) || ctx->display_colormap) {
     pop_buffer(ctx);
+  }
 
   /* Process events */
   Context_process_events(ctx);
