@@ -21,7 +21,8 @@
 
 
 Fader_t *
-Fader_new(const u_long size) {
+Fader_new(const u_long size)
+{
   Fader_t *fa = NULL;
 
   fa = xcalloc(1, sizeof(Fader_t));
@@ -29,7 +30,6 @@ Fader_new(const u_long size) {
   fa->target = 0;
   fa->delta = xcalloc(size, sizeof(long));
   fa->tmp = xcalloc(size, sizeof(u_long));
-  fa->fade = 1;
   fa->fading = 1;
   fa->max = 0;
   fa->faded = 0;
