@@ -19,6 +19,7 @@
 
 #include "globals.h"
 
+int32_t     WIDTH_ORIGIN, HEIGHT_ORIGIN;
 #ifndef FIXED
 u_short     WIDTH, HEIGHT;
 #endif
@@ -29,3 +30,15 @@ Context_t   *context   = NULL;
 Schemes_t   *schemes   = NULL;
 
 u_char libbiniou_verbose = 1;
+
+char *data_dir = NULL;
+#ifdef WITH_WEBCAM
+int webcams = 1;
+int hflip = 1;
+int vflip = 1;
+char *video_base;
+#else
+int webcams = 0;
+#endif
+
+char *video_filename = NULL; // video plugin
