@@ -25,13 +25,22 @@
 #include "schemes.h"
 #include "context.h"
 
+extern int32_t     WIDTH_ORIGIN;
+extern int32_t     HEIGHT_ORIGIN;
 #ifndef FIXED
-extern u_short      WIDTH;
-extern u_short      HEIGHT;
+extern u_short     WIDTH;
+extern u_short     HEIGHT;
 #endif
-extern Plugins_t    *plugins;
-extern Sequences_t  *sequences;
-extern Schemes_t    *schemes;
-extern Context_t    *context;
+extern Plugins_t   *plugins;
+extern Sequences_t *sequences;
+extern Schemes_t   *schemes;
+extern Context_t   *context;
+
+#ifdef WITH_WEBCAM
+#define MAX_TIMERS 4
+#else
+#define MAX_TIMERS 3
+#endif
+extern int webcams;
 
 #endif /* __BINIOU_GLOBALS_H */
