@@ -33,7 +33,7 @@ Image8_t *Image8_new(void);
 Image8_t *Image8_new_default(void);
 void Image8_delete(Image8_t *);
 int Image8_load(Image8_t *, const uint32_t, const char *, const char *);
-int Image8_load_PNG(Image8_t *, const char *);
+int Image8_load_any(Image8_t *, const char *);
 void Image8_copy(const Image8_t *, Image8_t *);
 
 #endif /* __BINIOU_IMAGE_8BITS_H */
