@@ -31,8 +31,9 @@ ImageFader_new(const u_short size)
 
   pf->on = 0;
   pf->cur = Image8_new();
-  if (images != NULL)
+  if (images != NULL) {
     pf->dst = images->imgs[0];
+  }
   pf->fader = Fader_new(BUFFSIZE);
   pf->shf = Shuffler_new(size);
   Shuffler_set_mode(pf->shf, Context_get_shuffler_mode(BD_IMAGES));
@@ -65,9 +66,9 @@ ImageFader_init(ImageFader_t *pf)
   for (i = BUFFSIZE; i--; ) { /* i < BUFFSIZE; i++) { */
     /* delta values for fading */
     fader->delta[i] = (long)(
-			     ((float)dst->buffer[i] - (float)src->buffer[i])
-			     / (float)(fader->max)
-			     * MFACTOR);
+                        ((float)dst->buffer[i] - (float)src->buffer[i])
+                        / (float)(fader->max)
+                        * MFACTOR);
 
     /* initial values for fading */
     /* fader->tmp[i] = (float)src->buffer[i]; */
@@ -83,6 +84,9 @@ ImageFader_run(ImageFader_t *pf)
   Fader_t *fader = pf->fader;
   const u_long elapsed = Fader_elapsed(fader);
 
+#ifdef DEBUG_FADERS
+  printf("If ");
+#endif
   Fader_start(fader);
   fader->faded += elapsed;
 
@@ -98,7 +102,9 @@ ImageFader_run(ImageFader_t *pf)
 
     for (i = BUFFSIZE; i--; ptr++, tmp++, delta++)
       /**ptr = (Pixel_t)(*tmp += (elapsed * *delta));*/
+    {
       *ptr = (Pixel_t)((*tmp += (elapsed * *delta))/MFACTOR);
+    }
   } else {
     /* we're done */
     fader->fading = 0;
@@ -117,17 +123,12 @@ ImageFader_set(ImageFader_t *pf)
 
   if (pf->dst->name != NULL) {
     VERBOSE(printf("[i] Using image '%s'\r\n", pf->dst->name));
-  } else
+  } else {
     xerror("Image without name, WTF #@!\r\n");
-
-  if (pf->cur != NULL && pf->dst->id != pf->cur->id) {
-    if (fader->fade)
-      ImageFader_init(pf);
-    else
-      pf->cur = pf->dst;
-
-    fader->fading = fader->fade;
   }
+
+  ImageFader_init(pf);
+  fader->fading = 1;
 }
 
 
