@@ -20,7 +20,6 @@
 #include <inttypes.h>
 #include "images.h"
 #include "brandom.h"
-#include "pbar.h"
 
 
 Images_t *images = NULL;
@@ -49,15 +48,11 @@ Images_new(const char *basedir, const char *themes)
   GSList *tmp = NULL;
   uint16_t size = 0;
   GSList *t;
-  PBar_t *pb = NULL;
   gchar **tokens, **theme;
 
   assert(basedir != NULL);
   assert(themes != NULL);
 
-  if (libbiniou_verbose)
-    pb = pbar_new();
-
   tokens = g_strsplit(themes, ",", 0);
   theme = tokens;
 
@@ -65,23 +60,24 @@ Images_new(const char *basedir, const char *themes)
     char *directoryname;
     char *th = *theme;
 
-    VERBOSE(printf("[+] Loading theme '%s': ", th));
+    VERBOSE(printf("[+] Loading theme '%s'\n", th));
     fflush(stdout);
     if (*th == '~') {
       th++;
-      if (*th != '\0')
-	directoryname = g_strdup_printf("%s/." PACKAGE_NAME "/images/%s", g_get_home_dir(), th);
-      else {
-	fprintf(stderr, "[!] Not a valid tilde-theme: %s\n", *theme);
-	continue;
+      if (*th != '\0') {
+        directoryname = g_strdup_printf("%s/." PACKAGE_NAME "/images/%s", g_get_home_dir(), th);
+      } else {
+        fprintf(stderr, "[!] Not a valid tilde-theme: %s\n", *theme);
+        continue;
       }
-    } else
+    } else {
       directoryname = g_strdup_printf("%s/%s", basedir, *theme);
+    }
 
     dir = opendir(directoryname);
     if (dir == NULL) {
       fprintf(stderr, "[!] Error while reading image directory %s content: %s\n",
-	      directoryname, strerror(errno));
+              directoryname, strerror(errno));
       g_free(directoryname);
       continue;
     }
@@ -90,70 +86,66 @@ Images_new(const char *basedir, const char *themes)
       uint32_t hash;
       Image8_t *pic;
 
-      if (entry->d_name[0] == '.')
-	continue;
+      if (entry->d_name[0] == '.') {
+        continue;
+      }
 
       hash = FNV_hash(entry->d_name);
 
       char ignore = 0;
       for (t = g_slist_next(tmp);
-	   t != NULL;
-	   t = g_slist_next(t))
-	if (((Image8_t *)t->data)->id == hash) {
-	  const char *name = ((Image8_t *)t->data)->name;
+           t != NULL;
+           t = g_slist_next(t))
+        if (((Image8_t *)t->data)->id == hash) {
+          const char *name = ((Image8_t *)t->data)->name;
 
-	  if (strcmp(name, entry->d_name))
-	    printf("[!] Ignoring image '%s'\n"
-		   "[!]   (same hash as '%s': %"PRIu32")\n",
-		   entry->d_name, name, hash);
-	  ignore = 1;
-	}
+          if (strcmp(name, entry->d_name))
+            printf("[!] Ignoring image '%s'\n"
+                   "[!]   (same hash as '%s': %"PRIu32")\n",
+                   entry->d_name, name, hash);
+          ignore = 1;
+        }
 
       if (!ignore) {
-	pic = Image8_new();
+        pic = Image8_new();
 
-	if (Image8_load(pic, hash, directoryname,
-			  entry->d_name) != 0) {
-	  Image8_delete(pic);
-	} else {
-	  size++;
-	  if (libbiniou_verbose && !(size % 5))
-	    pbar_step(pb);
-
-	  tmp = g_slist_prepend(tmp, (gpointer)pic);
-	}
+        if (Image8_load(pic, hash, directoryname,
+                        entry->d_name) != 0) {
+          Image8_delete(pic);
+        } else {
+          size++;
+          tmp = g_slist_prepend(tmp, (gpointer)pic);
+        }
       }
     }
 
-    if (closedir(dir) == -1)
+    if (closedir(dir) == -1) {
       xperror("closedir");
+    }
     g_free(directoryname);
-    VERBOSE(printf("done.\n"));
   }
 
   g_strfreev(tokens);
 
   images = xmalloc(sizeof(Images_t));
   if (libbiniou_verbose) {
-    pbar_delete(pb);
     VERBOSE(printf("[p] Loaded %d images\n", size));
   }
 
   if (size) {
     uint16_t i;
 
-    images->imgs = xmalloc(size*sizeof(Image8_t *));
+    images->imgs = xmalloc(size * sizeof(Image8_t *));
     for (i = 0, t = tmp;
-	 t != NULL;
-	 t = g_slist_next(t), i++) {
+         t != NULL;
+         t = g_slist_next(t), i++) {
       images->imgs[i] = (Image8_t *)t->data;
     }
     g_slist_free(tmp);
     images->size = size;
 
     qsort((void *)images->imgs, (size_t)images->size,
-	  (size_t)sizeof(Image8_t *), &Images_compare);
-
+          (size_t)sizeof(Image8_t *), &Images_compare);
   } else {
     xfree(images);
   }
@@ -166,8 +158,9 @@ Images_delete()
   if (images != NULL) {
     uint16_t i;
 
-    for (i = 0; i < images->size; i++)
+    for (i = 0; i < images->size; i++) {
       Image8_delete(images->imgs[i]);
+    }
     xfree(images->imgs);
     xfree(images);
   }
@@ -185,11 +178,13 @@ Images_name(const uint32_t id)
   }
 
   for (i = 0; i < images->size; i++)
-    if (images->imgs[i]->id == id)
+    if (images->imgs[i]->id == id) {
       return images->imgs[i]->name;
+    }
 
-  if (id == 0)
+  if (id == 0) {
     return images->imgs[0]->name;
+  }
 
   VERBOSE(fprintf(stderr, "[!] Images_name: id %"PRIu16" not found\r\n", id));
 
@@ -208,8 +203,9 @@ Images_index(const uint32_t id)
   }
 
   for (i = 0; i < images->size; i++)
-    if (images->imgs[i]->id == id)
+    if (images->imgs[i]->id == id) {
       return i;
+    }
 
   VERBOSE(fprintf(stderr, "[!] Images_index: id %"PRIu16" not found\r\n", id));
 
@@ -228,8 +224,9 @@ Images_find(const char *name)
   }
 
   for (i = 0; i < images->size; i++)
-    if (!strcmp(images->imgs[i]->name, name))
+    if (!strcmp(images->imgs[i]->name, name)) {
       return images->imgs[i]->id;
+    }
 
   VERBOSE(fprintf(stderr, "[!] Image '%s' not found\r\n", name));
 
@@ -243,11 +240,11 @@ Images_random_id()
   uint16_t idx = 0;
 
   assert(images != NULL);
-  if (!images->size)
-    return 0;
+  assert(images->size); // There is at least a default image
 
-  if (images->size > 1)
+  if (images->size > 1) {
     idx = b_rand_int_range(0, images->size - 1);
+  }
 
   return images->imgs[idx]->id;
 }
@@ -259,11 +256,10 @@ Images_random()
   uint16_t idx = 0;
 
   assert(images != NULL);
-  if (NULL == images)
-    return NULL;
 
-  if (images->size > 1)
+  if (images->size > 1) {
     idx = b_rand_int_range(0, images->size - 1);
+  }
 
   return images->imgs[idx];
 }
