@@ -25,6 +25,7 @@
 #ifdef DEBUG
 #include "btimer.h"
 #endif
+#include "buffer_8bits.h"
 
 /* A_STEREO is only used in calls to Input_set() */
 enum Channel { A_MONO=0, A_LEFT=1, A_RIGHT=2, A_STEREO };
@@ -36,10 +37,11 @@ typedef struct Input_s {
 
   /* FFTW stuff */
   fftw_plan plan_fft[3];
-  
+
   /* input buffer size */
   // FIXME make this a uint16_t
   uint32_t size;
+  uint32_t size2; /* number of samples in data2 */
 
   /* to get Mytho Random Numbers(c)(r)(tm) */
   // FIXME make this a uint16_t
@@ -51,11 +53,15 @@ typedef struct Input_s {
   /* Write raw input data here then call Input_set(...) */
   /* the input data, [-1..1] */
   double *data[3];
+  /* all frames after last context_run
+     If plugin can handle variable size input, this should be used instead
+     of data. Variable size includes zero size. */
+  double *data2[3];
 
   /*
    * these should be seen as Read-Only
    */
-  /* the input data, [0..1] */
+  /* unsigned input, used for PRNGs */
   double *data_u[3];
 
   /* spectrum info */
@@ -75,6 +81,16 @@ typedef struct Input_s {
 #ifdef DEBUG
   BTimer_t *timer;
 #endif
+
+  double volume_scale;
+  double volume;
+  double volume2; /* volume of data2 */
+  double maxpeak; /* highest peak on history buffer */
+  double curpeak; /* highest peak on data2 */
+  double average; /* average value on data2 */
+  u_char on_beat; /* are we on frame where beat happens */
+  double peakpower; /* power value (squared) of highest peak */
+  double rms;     /* rms power of data2 */
 } Input_t;
 
 
@@ -89,8 +105,8 @@ void Input_set(Input_t *, u_char);
 float  Input_random_s_u_float(Input_t *);
 /* random float [0.0 .. 1.0] */
 float  Input_random_u_u_float(Input_t *);
-/* random u_char [0 .. 255] */
-u_char Input_random_u_char(Input_t *);
+/* random Pixel_t [0 .. 255] */
+Pixel_t Input_random_color(Input_t *);
 /* random float [min .. max] */
 float  Input_random_float_range(Input_t *, const float, const float);
 /* random short [min .. max] */
@@ -100,4 +116,15 @@ float  Input_get_volume(Input_t *);
 
 void   Input_toggle_mute(Input_t *);
 
+/* volume scaling */
+void   Input_volume_upscale(Input_t *);
+void   Input_volume_downscale(Input_t *);
+
+double Input_clamp(const double);
+void   Input_process(Input_t *);
+
+/* signal processing */
+double compute_avg_abs(double *buf, u_long a, u_long b);
+u_short compute_avg_freq_id(Input_t *input, double spectrum_low_treshold_factor);
+
 #endif /* INPUT_H */
