@@ -25,11 +25,12 @@
 gchar *keyfile = NULL;
 
 /* groups */
-#define PLUGINS "Plugins"
-#define SCREEN  "Screen"
-#define ENGINE  "Engine"
-#define INPUT   "Input"
-#define WEBCAM  "Webcam"
+#define PLUGINS  "Plugins"
+#define SCREEN   "Screen"
+#define ENGINE   "Engine"
+#define INPUT    "Input"
+#define WEBCAM   "Webcam"
+#define PARAMS3D "3D"
 
 extern float phase;
 #ifdef WITH_WEBCAM
@@ -39,10 +40,16 @@ extern char *video_base;
 extern char *video_filename;
 extern char *data_dir;
 extern uint32_t input_size;
+extern double volume_scale;
+extern double scale_factor; // 3D scale factor
+extern double rot_amount;
+extern uint8_t rotation_factor;
+extern uint8_t start_with_first_sequence;
 
 
 static void process_timers(GKeyFile *);
 static void process_change_modes(GKeyFile *);
+static void process_3d_parameters(GKeyFile *);
 
 
 static void
@@ -65,6 +72,8 @@ process(GKeyFile *kf)
 #endif
   gchar *kf_sequences_dir = NULL;
   gchar *kf_data_dir = NULL;
+  double kf_volume_scale = 0;
+  gchar first_sequence = FALSE;
 
   input = g_key_file_get_string(kf, PLUGINS, "Input", NULL);
   if (NULL != input) {
@@ -105,13 +114,22 @@ process(GKeyFile *kf)
     error = NULL;
   }
 
+  first_sequence = g_key_file_get_boolean(kf, ENGINE, "StartWithFirstSequence", &error);
+  if (NULL == error) {
+    start_with_first_sequence = first_sequence;
+    VERBOSE(printf("[k] Starting with the %s sequence\n", (start_with_first_sequence ? "first" : "last")));
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
 #ifndef FIXED
   kf_width = g_key_file_get_integer(kf, SCREEN, "Width", &error);
   if (NULL == error) {
     if (kf_width > 0)
       if (width != kf_width) {
-	width = kf_width;
-	VERBOSE(printf("[k] Setting screen width to %d\n", width));
+        width = kf_width;
+        VERBOSE(printf("[k] Setting screen width to %d\n", width));
       }
   } else {
     g_error_free(error);
@@ -122,8 +140,8 @@ process(GKeyFile *kf)
   if (NULL == error) {
     if (kf_height > 0)
       if (height != kf_height) {
-	height = kf_height;
-	VERBOSE(printf("[k] Setting screen height to %d\n", height));
+        height = kf_height;
+        VERBOSE(printf("[k] Setting screen height to %d\n", height));
       }
   } else {
     g_error_free(error);
@@ -135,8 +153,8 @@ process(GKeyFile *kf)
   if (NULL == error) {
     if (kf_fps > 0)
       if (max_fps != kf_fps) {
-	max_fps = kf_fps;
-	VERBOSE(printf("[k] Setting FPS to %li\n", max_fps));
+        max_fps = kf_fps;
+        VERBOSE(printf("[k] Setting FPS to %li\n", max_fps));
       }
   } else {
     g_error_free(error);
@@ -147,8 +165,8 @@ process(GKeyFile *kf)
   if (NULL == error) {
     if ((kf_rnd >= BR_NONE) && (kf_rnd <= BR_BOTH))
       if ((gint)random_mode != kf_rnd) {
-	random_mode = kf_rnd;
-	VERBOSE(printf("[k] Setting random mode to %d\n", kf_rnd));
+        random_mode = kf_rnd;
+        VERBOSE(printf("[k] Setting random mode to %d\n", kf_rnd));
       }
   } else {
     g_error_free(error);
@@ -184,6 +202,21 @@ process(GKeyFile *kf)
     error = NULL;
   }
 
+  kf_volume_scale = g_key_file_get_double(kf, INPUT, "VolumeScale", &error);
+  if (NULL == error) {
+    if (kf_volume_scale > 0) {
+      VERBOSE(printf("[k] Setting volume scale to %.1f\n", kf_volume_scale));
+      volume_scale = kf_volume_scale;
+    } else {
+      xerror("VolumeScale must be > 0\n");
+    }
+  } else if (G_KEY_FILE_ERROR_INVALID_VALUE == error->code) {
+    xerror("Invalid VolumeScale\n");
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
 #ifdef WITH_WEBCAM
   whflip = g_key_file_get_boolean(kf, WEBCAM, "HorizontalFlip", &error);
   if (NULL == error) {
@@ -227,7 +260,7 @@ process(GKeyFile *kf)
 #endif /* WITH_WEBCAM */
 
   blacklist = g_key_file_get_string_list(kf, PLUGINS, "Blacklist",
-					 &blacklist_length, NULL);
+                                         &blacklist_length, NULL);
   if (blacklist_length) {
     VERBOSE(printf("[k] Plugins: blacklist of %"G_GSIZE_FORMAT" plugins\n", blacklist_length));
   }
@@ -253,13 +286,15 @@ read_keyfile()
     if (G_FILE_ERROR_NOENT == error->code) {
       g_free(keyfile);
       return;
-    } else
-      xerror("failed to load %s\n", keyfile);
+    } else {
+      xerror("Failed to load %s\n", keyfile);
+    }
   }
 
   process(kf);
   process_timers(kf);
   process_change_modes(kf);
+  process_3d_parameters(kf);
 
   g_free(keyfile);
 }
@@ -297,7 +332,7 @@ process_timers(GKeyFile *kf)
     error = NULL;
   }
 
-  Context_set_delay(BD_COLORMAPS, colormaps_min, colormaps_max);
+  biniou_set_delay(BD_COLORMAPS, colormaps_min, colormaps_max);
 
   images_min = g_key_file_get_integer(kf, ENGINE, "ImagesMin", &error);
   if (NULL == error) {
@@ -323,7 +358,7 @@ process_timers(GKeyFile *kf)
     error = NULL;
   }
 
-  Context_set_delay(BD_IMAGES, images_min, images_max);
+  biniou_set_delay(BD_IMAGES, images_min, images_max);
 
   sequences_min = g_key_file_get_integer(kf, ENGINE, "SequencesMin", &error);
   if (NULL == error) {
@@ -349,7 +384,7 @@ process_timers(GKeyFile *kf)
     error = NULL;
   }
 
-  Context_set_delay(BD_SEQUENCES, sequences_min, sequences_max);
+  biniou_set_delay(BD_SEQUENCES, sequences_min, sequences_max);
 
 #ifdef WITH_WEBCAM
   gint webcams_min, webcams_max;
@@ -378,7 +413,7 @@ process_timers(GKeyFile *kf)
     error = NULL;
   }
 
-  Context_set_delay(BD_WEBCAMS, webcams_min, webcams_max);
+  biniou_set_delay(BD_WEBCAMS, webcams_min, webcams_max);
 #endif
 }
 
@@ -402,18 +437,21 @@ process_change_modes(GKeyFile *kf)
   if (NULL != colormaps_mode) {
     VERBOSE(printf("[k] Setting colormaps mode: %s\n", colormaps_mode));
     Context_set_shuffler_mode(BD_COLORMAPS, Shuffler_parse_mode(colormaps_mode));
+    xfree(colormaps_mode);
   }
 
   images_mode = g_key_file_get_string(kf, ENGINE, "ImagesMode", NULL);
   if (NULL != images_mode) {
-    VERBOSE(printf("[k] Setting images mode: %s\n", colormaps_mode));
+    VERBOSE(printf("[k] Setting images mode: %s\n", images_mode));
     Context_set_shuffler_mode(BD_IMAGES, Shuffler_parse_mode(images_mode));
+    xfree(images_mode);
   }
 
   sequences_mode = g_key_file_get_string(kf, ENGINE, "SequencesMode", NULL);
   if (NULL != sequences_mode) {
     VERBOSE(printf("[k] Setting sequences mode: %s\n", sequences_mode));
     Context_set_shuffler_mode(BD_SEQUENCES, Shuffler_parse_mode(sequences_mode));
+    xfree(sequences_mode);
   }
 
 #ifdef WITH_WEBCAM
@@ -425,3 +463,58 @@ process_change_modes(GKeyFile *kf)
   }
 #endif
 }
+
+
+static void
+process_3d_parameters(GKeyFile *kf)
+{
+  GError *error = NULL;
+  double kf_scale_factor = 0;
+  double kf_rot_amount = 0;
+  int kf_rotation_factor = 0;
+
+  kf_scale_factor = g_key_file_get_double(kf, PARAMS3D, "ScaleFactor", &error);
+  if (NULL == error) {
+    if (kf_scale_factor >= SCALE_FACTOR_MIN) {
+      VERBOSE(printf("[k] Setting scale factor to %.2f\n", kf_scale_factor));
+      scale_factor = kf_scale_factor;
+    } else {
+      xerror("ScaleFactor must be >= %.2f\n", SCALE_FACTOR_MIN);
+    }
+  } else if (G_KEY_FILE_ERROR_INVALID_VALUE == error->code) {
+    xerror("Invalid ScaleFactor\n");
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
+  kf_rot_amount = g_key_file_get_double(kf, PARAMS3D, "RotationAmount", &error);
+  if (NULL == error) {
+    if (kf_rot_amount >= ROT_AMOUNT_MIN) {
+      VERBOSE(printf("[k] Setting rotation amount to %.4f\n", kf_rot_amount));
+      rot_amount = kf_rot_amount;
+    } else {
+      xerror("RotationAmount must be >= %.4f\n", ROT_AMOUNT_MIN);
+    }
+  } else if (G_KEY_FILE_ERROR_INVALID_VALUE == error->code) {
+    xerror("Invalid RotationAmount\n");
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+
+  kf_rotation_factor = g_key_file_get_integer(kf, PARAMS3D, "RotationFactor", &error);
+  if (NULL == error) {
+    if (kf_rotation_factor > 1) {
+      rotation_factor = kf_rotation_factor;
+      VERBOSE(printf("[k] Setting rotation factor to %d\n", rotation_factor));
+    } else {
+      xerror("RotationFactor must be > 1\n");
+    }
+  } else if (G_KEY_FILE_ERROR_INVALID_VALUE == error->code) {
+    xerror("Invalid RotationFactor\n");
+  } else {
+    g_error_free(error);
+    error = NULL;
+  }
+}
