@@ -27,40 +27,48 @@
 static inline int
 BKEY(const BKey_t *k, const uint32_t v)
 {
-  if (k->mod == KMOD_NONE)
+  if (k->mod == KMOD_NONE) {
     return (k->val == v);
+  }
   return ((k->val == v) && (k->mod & KMOD_NUM)
-	  && (!(k->mod & KMOD_SHIFT))
-	  && (!(k->mod & KMOD_CTRL))
-	  && (!(k->mod & KMOD_ALT)));
+          && (!(k->mod & KMOD_SHIFT))
+          && (!(k->mod & KMOD_CTRL))
+          && (!(k->mod & KMOD_ALT)));
 }
 
 
 static inline int
 BSHIFT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_SHIFT));
+  return ((k->val == v) && (k->mod & KMOD_SHIFT) && !(k->mod & KMOD_CTRL) && !(k->mod & KMOD_ALT));
 }
 
 
 static inline int
 BCTRL(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_CTRL));
+  return ((k->val == v) && (k->mod & KMOD_CTRL) && !(k->mod & KMOD_SHIFT) && !(k->mod & KMOD_ALT));
 }
 
 
 static inline int
 BALT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_ALT));
+  return ((k->val == v) && (k->mod & KMOD_ALT) && !(k->mod & KMOD_SHIFT) && !(k->mod & KMOD_CTRL));
 }
 
+
 static inline int
 BCTRLSHIFT(const BKey_t *k, const uint32_t v)
 {
-  return ((k->val == v) && (k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT));
+  return ((k->val == v) && (k->mod & KMOD_CTRL) && (k->mod & KMOD_SHIFT) && !(k->mod & KMOD_ALT));
 }
 
 
+static inline int
+BALTSHIFT(const BKey_t *k, const uint32_t v)
+{
+  return ((k->val == v) && (k->mod & KMOD_ALT) && (k->mod & KMOD_SHIFT));
+}
+
 #endif /* __BINIOU_EVENTS_H */
