@@ -51,14 +51,31 @@ Layer_copy(const Layer_t *from)
 
 
 enum LayerMode
-LayerMode_from_string(const char *mode)
-{
-  if (!strcmp(mode, "none")) return NONE;
-  if (!strcmp(mode, "normal")) return NORMAL;
-  if (!strcmp(mode, "overlay")) return OVERLAY;
-  if (!strcmp(mode, "xor")) return XOR;
-  if (!strcmp(mode, "average")) return AVERAGE;
-  if (!strcmp(mode, "random")) return RANDOM;
+LayerMode_from_string(const char *mode) {
+  if (!strcmp(mode, "none"))
+  {
+    return NONE;
+  }
+  if (!strcmp(mode, "normal"))
+  {
+    return NORMAL;
+  }
+  if (!strcmp(mode, "overlay"))
+  {
+    return OVERLAY;
+  }
+  if (!strcmp(mode, "xor"))
+  {
+    return XOR;
+  }
+  if (!strcmp(mode, "average"))
+  {
+    return AVERAGE;
+  }
+  if (!strcmp(mode, "random"))
+  {
+    return RANDOM;
+  }
 
   printf("[!] Failed to parse mode '%s', setting to NORMAL\n", mode);
 
@@ -104,10 +121,11 @@ LayerMode_to_string(const enum LayerMode mode)
 
 
 const char *
-LayerMode_to_OSD_string(const enum LayerMode mode) {
-  if ((unsigned)mode > RANDOM)
+LayerMode_to_OSD_string(const enum LayerMode mode)
+{
+  if ((unsigned)mode > RANDOM) {
     return "???";
-  else
+  } else
     return
       &"---\0NOR\0OVL\0XOR\0AVG\0RND\0"[4*mode*sizeof(char)];
 }
