@@ -23,26 +23,21 @@
 #include "colormaps.h"
 
 
-char *data_dir = NULL;
 char *base_dir = NULL;
 char *schemes_file = NULL;
 char *input_plugin = NULL;
 char *output_plugin = NULL;
 char fullscreen = 0;
 long max_fps = 50;
+char window_decorations = 1;
+int32_t x_origin = INT32_MIN;
+int32_t y_origin = INT32_MIN;
 u_short width = DEFAULT_WIDTH;
 u_short height = DEFAULT_HEIGHT;
 enum RandomMode random_mode = BR_SCHEMES;
 char *pid_file  = "/tmp/lebiniou.pid";
 char *themes = NULL;
-#ifdef WITH_WEBCAM
-int hflip = 1;
-int vflip = 1;
-int webcams = 1;
-char *video_base;
-#endif
 uint8_t statistics = 0; // Display statistics
-char *video_filename = NULL; // video plugin
 
 /* default input size (samples) */
 #define DEFAULT_INPUT_SIZE 1024
@@ -53,21 +48,24 @@ uint8_t phase_space_delay = DEFAULT_PHASE_SPACE_DELAY;
 /* default spline span size */
 #define DEFAULT_SPAN_SIZE 6
 uint8_t span_size = DEFAULT_SPAN_SIZE;
+/* volume scaling */
+double volume_scale = 1.0;
 
-#define _BANNER "\n"					\
-  "      _          ___ _      _          \n"		\
-  "     | |   ___  | _ | )_ _ ( )___ _  _ \n"		\
-  "     | |__/ -_) | _ \\ | ' \\| / _ \\ || |\n"	\
-  "     |____\\___| |___/_|_||_|_\\___/\\_,_|\n"	\
-  "\n"							\
-  "           .:[ " PACKAGE_STRING " ]:.\n"             \
-  " -------------------------------------------\n"	\
-  "  \"Une cause très petite, qui nous échappe,\n"	\
-  "  détermine un effet considérable que nous \n"	\
-  "  ne pouvons pas ne pas voir, et alors nous\n"	\
-  "  disons que cet effet est dû au hasard.\" \n"	\
-  "\n"				 			\
-  "    -- Henri Poincaré, 1908\n"  	                \
+
+#define _BANNER "\n"                               \
+  "      _          ___ _      _          \n"      \
+  "     | |   ___  | _ | )_ _ ( )___ _  _ \n"      \
+  "     | |__/ -_) | _ \\ | ' \\| / _ \\ || |\n"   \
+  "     |____\\___| |___/_|_||_|_\\___/\\_,_|\n"   \
+  "\n"                                             \
+  "           .:[ " PACKAGE_STRING " ]:.\n"        \
+  " -------------------------------------------\n" \
+  "  \"Une cause très petite, qui nous échappe,\n" \
+  "  détermine un effet considérable que nous \n"  \
+  "  ne pouvons pas ne pas voir, et alors nous\n"  \
+  "  disons que cet effet est dû au hasard.\" \n"  \
+  "\n"                                             \
+  "    -- Henri Poincaré, 1908\n"                  \
   " -------------------------------------------\n"
 
 
@@ -83,8 +81,9 @@ get_pid_file()
 {
   static char buff[1025];
 
-  if (NULL == pid_file)
+  if (NULL == pid_file) {
     xerror("NULL pid_file");
+  }
 
   memset(buff, '0', 1025*sizeof(char));
   snprintf(buff, 1024*sizeof(char), "%s", pid_file);
@@ -107,19 +106,22 @@ write_pid_file()
   buff = get_pid_file();
 
   fd = open(buff, O_CREAT|O_WRONLY, S_IRUSR|S_IWUSR);
-  if (-1 == fd)
+  if (-1 == fd) {
     xperror("creat");
+  }
 
   /* buff is 1025 char long */
   memset(buff, '0', 1025*sizeof(char));
   snprintf(buff, 1024*sizeof(char), "%d", getpid());
   res = write(fd, buff, strlen(buff)*sizeof(char));
-  if (-1 == res)
+  if (-1 == res) {
     xperror("write");
+  }
 
   res2 = close(fd);
-  if (-1 == res2)
+  if (-1 == res2) {
     xperror("close");
+  }
 }
 
 
@@ -130,8 +132,9 @@ remove_pid_file()
   int res;
 
   res = unlink(buff);
-  if (-1 == res)
+  if (-1 == res) {
     xperror("unlink");
+  }
 }
 
 
@@ -143,19 +146,47 @@ main(int argc, char **argv)
   register_signals();
 
   /* Banner */
-  if (NULL == getenv("LEBINIOU_NO_BANNER"))
+  if (NULL == getenv("LEBINIOU_NO_BANNER")) {
     do_banner();
+  }
 
-  /* Initialize library */
-  biniou_new(data_dir, base_dir, schemes_file, themes,
+  WIDTH_ORIGIN = x_origin;
+  HEIGHT_ORIGIN = y_origin;
 #ifndef FIXED
-	     width, height,
+  WIDTH = width;
+  HEIGHT = height;
 #endif
-	     B_INIT_ALL
+
+  /* PRNG */
+  b_rand_init();
+
+  /* Create context */
+  context = Context_new(webcams);
+  Context_set_input_size(context, input_size);
+  Context_set_phase_space_delay(context, phase_space_delay);
+  Context_set_span_size(context, span_size);
+
+  biniou_set_max_fps(max_fps);
+
+  /* Load input */
+  if (NULL != input_plugin) {
+    biniou_load_input(base_dir, input_plugin, volume_scale);
+  }
+
+  /* Load output */
+  if (NULL != output_plugin) {
+    context->window_decorations = window_decorations;
+    biniou_load_output(base_dir, output_plugin);
+    biniou_set_full_screen(fullscreen);
+  }
+
+  /* Initialize */
+  biniou_new(data_dir, base_dir, schemes_file, themes,
+             B_INIT_ALL
 #ifdef DEBUG
-	     |B_INIT_VERBOSE
+             |B_INIT_VERBOSE
 #endif
-	     , input_size, phase_space_delay, span_size);
+             , input_size, phase_space_delay, span_size, webcams);
   xfree(themes);
 
   if (statistics) {
@@ -183,25 +214,8 @@ main(int argc, char **argv)
 
   write_pid_file();
 
-  biniou_set_max_fps(max_fps);
   biniou_set_random_mode(random_mode);
 
-  /* Load input */
-  if (NULL != input_plugin) {
-    biniou_load_input(base_dir, input_plugin);
-    xfree(input_plugin);
-  }
-
-  /* Load output */
-  if (NULL != output_plugin) {
-    biniou_load_output(base_dir, output_plugin);
-    xfree(output_plugin);
-    biniou_set_full_screen(fullscreen);
-  }
-
-  /* Set events callback */
-  biniou_set_events_cb(on_key);
-
   /* Main loop */
   biniou_run();
 
