@@ -30,6 +30,9 @@ extern char *input_plugin;
 extern char *output_plugin;
 extern char fullscreen;
 extern long max_fps;
+extern char window_decorations;
+extern int32_t x_origin;
+extern int32_t y_origin;
 #ifndef FIXED
 extern u_short width;
 extern u_short height;
