@@ -38,7 +38,6 @@ enum PluginOptions {
   BE_CLEAN      = 1 << 10, /* obvious */
 
   /* BEQ_ stands for "Biniou Effect Qualifier" */
-  /* --- Those MUST NOT be selectable */
   BEQ_HOR        = 1 << 11,
   BEQ_VER        = 1 << 12,
   BEQ_DIAG       = 1 << 13,
@@ -52,22 +51,20 @@ enum PluginOptions {
   BEQ_THREAD     = 1 << 21, /* thread, do not use in sequences */
   BEQ_IMAGE      = 1 << 22, /* uses background image */
   BEQ_NORANDOM   = 1 << 23, /* don't select at random */
-  BEQ_DISABLED   = 1 << 24, /* unusable plugin: no selection or random possible */
-  BEQ_WEBCAM     = 1 << 25, /* uses a webcam input */
-  BEQ_UNIQUE     = 1 << 26, /* plugin must be alone to be cool */
-  BEQ_FIRST      = 1 << 27, /* insert plugin at the begining */
-  BEQ_LAST       = 1 << 28, /* insert plugin at the end */
-  BEQ_MUTE_CAM   = 1 << 29  /* some plugins (eg webcams) can be muted */
+  BEQ_WEBCAM     = 1 << 24, /* uses a webcam input */
+  BEQ_UNIQUE     = 1 << 25, /* plugin must be alone to be cool */
+  BEQ_FIRST      = 1 << 26, /* insert plugin at the begining */
+  BEQ_LAST       = 1 << 27, /* insert plugin at the end */
+  BEQ_MUTE_CAM   = 1 << 28  /* some plugins (eg webcams) can be muted */
 } PluginOptions_e;
 
-#define MAX_STYPES 11       /* user-selectable types */
-#define MAX_TYPES  30       /* all types available */
+#define MAX_TYPES  29       /* all types available */
 
 /* -- PluginType -- */
 
 typedef struct PluginType_s {
   enum PluginOptions option;
-  
+
   char    *name;
   char    *oname;
   u_short count;
