@@ -37,11 +37,14 @@ Porteuse_new(uint32_t size, u_char channel)
   Porteuse_t *p = xcalloc(1, sizeof(Porteuse_t));
 
   p->size = size;
+  p->color = xcalloc(p->size, sizeof(Pixel_t));
   p->trans = xcalloc(size, sizeof(Transform_t));
   p->channel = channel;
 
-  for (i = 0; i < size; i++)
+  for (i = 0; i < size; i++) {
     Transform_init(&p->trans[i]);
+    p->color[i] = PIXEL_MAXVAL;
+  }
 
   return p;
 }
@@ -50,7 +53,10 @@ Porteuse_new(uint32_t size, u_char channel)
 void
 Porteuse_delete(Porteuse_t *p)
 {
-  xfree(p->trans);
+  if (p) {
+    xfree(p->color);
+    xfree(p->trans);
+  }
   xfree(p);
 }
 
@@ -89,7 +95,6 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
   Transform_t *t = &p->trans[i];
   Point2d_t sigval;
   float vy, sina, cosa, x, y, xi, yi;
-  static const Pixel_t color = 250;
 
   Buffer8_t *dst = passive_buffer(ctx);
 
@@ -125,7 +130,7 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
   origin = p2d_add(&origin, &t->v_after);
 
   for (i = 1; i < p->size; i++) {
-    /* Pixel_t color = b_rand_int_range(1, 254); */
+    Pixel_t color = p->color[i];
 
     t = &p->trans[i];
 
@@ -148,14 +153,14 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
     yi += origin.y;
 
     /* XXX TODO split off in two functions: draw_line & draw_dots */
-    if (connect)
+    if (connect) {
       draw_line(dst, last.x, last.y, (short)xi, (short)yi, color);
-    else {
-      set_pixel(dst, (short)xi  , (short)yi-1, color/2);
-      set_pixel(dst, (short)xi  , (short)yi+1, color/2);
-      set_pixel(dst, (short)xi-1, (short)yi  , color/2);
-      set_pixel(dst, (short)xi+1, (short)yi  , color/2);
-      set_pixel(dst, (short)xi  , (short)yi  , color);
+    } else {
+      set_pixel(dst, (short)xi, (short)yi-1, color/2);
+      set_pixel(dst, (short)xi, (short)yi+1, color/2);
+      set_pixel(dst, (short)xi-1, (short)yi, color/2);
+      set_pixel(dst, (short)xi+1, (short)yi, color/2);
+      set_pixel(dst, (short)xi, (short)yi, color);
     }
 
     last.x = xi;
