@@ -68,32 +68,22 @@ init_sphere_3d(void)
 }
 
 
-Params3d_t *
-Params3d_new()
-{
-  Params3d_t *p = NULL;
-
-  p = xcalloc(1, sizeof(Params3d_t));
-
-  Params3d_init(p);
-
-  return p;
-}
-
-
 void
-Params3d_init(Params3d_t *p)
+Params3d_init(Params3d_t *p, const float rotate_amount, const double scale_factor,
+              const uint8_t rotation_factor)
 {
   int i;
 
-  for (i = 0; i < 3; i++) {
+  p->rotation_factor = rotation_factor;
+
+  p->rotate_amount = rotate_amount;
+  for (i = X_AXIS; i <= Z_AXIS; i++) {
     p->rotations[i] = 0;
-    p->auto_rotate[i] = 0;
-    p->rotate_amount[i] = ROT_STEP;
+    p->rotate_factor[i] = 0; // TODO get from configuration
   }
   update(p);
 
-  p->scale_factor = HEIGHT/(16.0/9.0);
+  p->scale_factor = scale_factor;
   p->draw_boundary = 0;
 
   p->xs = p->xe = HWIDTH;
@@ -106,74 +96,66 @@ Params3d_init(Params3d_t *p)
   init_sphere_3d();
   zero_3d(p);
 
-  p->auto_rotate[Y_AXIS] = 1;
-  p->rotate_amount[Y_AXIS] = 3 * ROT_STEP;
-
-  p->do_auto_rotate = 0;
-  p->rotate_amount[X_AXIS] = 1 * ROT_STEP;
-  p->rotate_amount[Y_AXIS] = 2 * ROT_STEP;
-  p->rotate_amount[Z_AXIS] = 4 * ROT_STEP;
-
 #ifdef WITH_GL
   p->gl_fov = 45; /* FIXME empirical value */
 #endif
 }
 
 
-void
-Params3d_delete(Params3d_t *p)
-{
-  xfree(p);
-}
-
-
 void
 Params3d_randomize(Params3d_t *p)
 {
-  p->do_auto_rotate = 1;
-  p->auto_rotate[X_AXIS] =  b_rand_boolean();
-  p->auto_rotate[Y_AXIS] =  b_rand_boolean();
-  p->auto_rotate[Z_AXIS] =  b_rand_boolean();
-
-  if (!p->auto_rotate[X_AXIS] && !p->auto_rotate[Y_AXIS] && !p->auto_rotate[Z_AXIS]) {
-    /* 2, c'est mieux qu'un :) */
-    u_short idx = b_rand_int_range(0, 100) % 3;
-    p->auto_rotate[idx] = p->auto_rotate[(idx+1) % 3] = 1;
-  }
+  do {
+    int i;
+    // FIXME b_rand_int_range returns uint32_t !!!
+    // this should be b_rand_int_range(-RAND_FACTOR, RAND_FACTOR)..
+    p->rotate_factor[X_AXIS] = b_rand_int_range(0, p->rotation_factor);
+    p->rotate_factor[Y_AXIS] = b_rand_int_range(0, p->rotation_factor);
+    p->rotate_factor[Z_AXIS] = b_rand_int_range(0, p->rotation_factor);
+    // XXX poor random sign changing
+    for (i = X_AXIS; i <= Z_AXIS; i++) {
+      if (b_rand_boolean()) {
+        p->rotate_factor[i] = -p->rotate_factor[i];
+      }
+    }
+  } while (!Params3d_is_rotating(p));
 }
 
 
-void
+inline void
 draw_sphere_3d(const Params3d_t *params3d, Buffer8_t *b, const Pixel_t color)
 {
   u_short it, ip;
 
   for (it = 0; it < NSAMPLES; it++)
-    for (ip = 0; ip < NSAMPLES; ip++)
+    for (ip = 0; ip < NSAMPLES; ip++) {
       set_pixel_3d(params3d, b, &Sphere3d[it][ip], color);
+    }
 }
 
 
-void
+inline void
 draw_sphere_wireframe_3d(const Params3d_t *params3d, Buffer8_t *b, const Pixel_t color)
 {
   u_short it, ip;
 
   for (it = 0; it < NSAMPLES-1; it++) {
-    for (ip = 0; ip < NSAMPLES; ip++)
+    for (ip = 0; ip < NSAMPLES; ip++) {
       draw_line_3d(params3d, b, &Sphere3d[it][ip], &Sphere3d[it+1][ip], color);
+    }
   }
-  for (ip = 0; ip < NSAMPLES; ip++)
+  for (ip = 0; ip < NSAMPLES; ip++) {
     draw_line_3d(params3d, b, &Sphere3d[0][ip], &Sphere3d[NSAMPLES-1][ip], color);
+  }
   for (it = 0; it < NSAMPLES; it++) {
-    for (ip = 0; ip < NSAMPLES-1; ip++)
+    for (ip = 0; ip < NSAMPLES-1; ip++) {
       draw_line_3d(params3d, b, &Sphere3d[it][ip], &Sphere3d[it][ip+1], color);
+    }
   }
 }
 
 
-/* not inlinable */
-void
+inline void
 draw_cube_3d(const Params3d_t *p, Buffer8_t *b, const Pixel_t color)
 {
   draw_line_3d(p, b, &Cube3d[7], &Cube3d[6], color);
@@ -209,7 +191,7 @@ draw_line_3d(const Params3d_t *p, Buffer8_t *b, const Point3d_t *p1, const Point
 }
 
 
-void
+inline void
 Params3d_rotate(Params3d_t *p)
 {
   float dx = (p->xe-p->xs)/(float)(WIDTH/8);
@@ -221,15 +203,17 @@ Params3d_rotate(Params3d_t *p)
   p->rotations[Y_AXIS] += dx;
   p->rotations[X_AXIS] += dy;
 
-  if (p->rotations[X_AXIS] > 2 * M_PI)
+  if (p->rotations[X_AXIS] > 2 * M_PI) {
     p->rotations[X_AXIS] -= 2 * M_PI;
-  else if (p->rotations[X_AXIS] < -2 * M_PI)
+  } else if (p->rotations[X_AXIS] < -2 * M_PI) {
     p->rotations[X_AXIS] += 2 * M_PI;
+  }
 
-  if (p->rotations[Z_AXIS] > 2 * M_PI)
+  if (p->rotations[Z_AXIS] > 2 * M_PI) {
     p->rotations[Z_AXIS] -= 2 * M_PI;
-  else if (p->rotations[Z_AXIS] < -2 * M_PI)
+  } else if (p->rotations[Z_AXIS] < -2 * M_PI) {
     p->rotations[Z_AXIS] += 2 * M_PI;
+  }
 
   p->xs = p->xe;
   p->ys = p->ye;
@@ -238,6 +222,7 @@ Params3d_rotate(Params3d_t *p)
 }
 
 
+#ifdef WITH_GL
 void
 Params3d_rotate_GL(Params3d_t *p)
 {
@@ -249,33 +234,33 @@ Params3d_rotate_GL(Params3d_t *p)
   p->gl_rotations[Y_AXIS] += dx*30;
   p->gl_rotations[X_AXIS] += dy*30;
 
-  if (p->gl_rotations[Y_AXIS] > 360)
+  if (p->gl_rotations[Y_AXIS] > 360) {
     p->gl_rotations[Y_AXIS] -= 360;
-  else if (p->gl_rotations[Y_AXIS] < 0)
+  } else if (p->gl_rotations[Y_AXIS] < 0) {
     p->gl_rotations[Y_AXIS] += 360;
+  }
 
-  if (p->rotations[X_AXIS] > 360)
+  if (p->rotations[X_AXIS] > 360) {
     p->rotations[X_AXIS] -= 360;
-  else if (p->rotations[X_AXIS] < 0)
+  } else if (p->rotations[X_AXIS] < 0) {
     p->rotations[X_AXIS] += 360;
+  }
 
   p->gl_xs = p->gl_xe;
   p->gl_ys = p->gl_ye;
 }
+#endif
 
 
-void
+inline void
 Params3d_change_rotations(Params3d_t *p)
 {
-  int i, changed = 0;
+  int i;
 
-  for (i = X_AXIS; i <= Z_AXIS; i++)
-    if (p->auto_rotate[i]) {
-      p->rotations[i] += p->rotate_amount[i];
-      changed = 1;
-    }
-  if (changed)
-    update(p);
+  for (i = X_AXIS; i <= Z_AXIS; i++) {
+    p->rotations[i] += (p->rotate_factor[i] * p->rotate_amount);
+  }
+  update(p);
 }
 
 
