@@ -23,38 +23,38 @@
 #include "point3d.h"
 #include "buffer_8bits.h"
 
-#define ROT_STEP 0.0025         /* for 3D auto_rotations */
-
 enum Axes { X_AXIS, Y_AXIS, Z_AXIS };
 
 #define DIST 4
 
 typedef struct Params3d_s {
-  u_short scale_factor;
-  u_char  do_auto_rotate;
-  u_char  auto_rotate[3];
-  float   rotate_amount[3];
+  double  scale_factor;
+  float   rotate_amount;
+  float   rotate_factor[3];
+  uint8_t draw_boundary; /* for 3D objects */
+  uint8_t rotation_factor;
+
+  /* should only be modified by update_ functions ! */
   float   rotations[3];
-  float   Cos[3]; /* TODO precompute 360 deg */
-  float   Sin[3]; /* TODO precompute 360 deg */
-  u_char  draw_boundary; /* for 3D objects */
-  int     xs, ys; /* to handle drag/drop 3D rotations */
+  float   Cos[3];
+  float   Sin[3];
+
+  /* handle drag/drop 3D rotations */
+  int     xs, ys;
   int     xe, ye;
+
+#ifdef WITH_GL
   /* OpenGL */
   float   gl_rotations[3];
   int     gl_xs, gl_ys;
   int     gl_xe, gl_ye;
   float   gl_fov;
+#endif
 } Params3d_t;
 
 
-Params3d_t *Params3d_new(void);
-void Params3d_init(Params3d_t *);
-void Params3d_delete(Params3d_t *);
-
+void Params3d_init(Params3d_t *, const float, const double, const uint8_t);
 void Params3d_randomize(Params3d_t *);
-
-
 void update_x(Params3d_t *);
 void update_y(Params3d_t *);
 void update_z(Params3d_t *);
@@ -73,19 +73,17 @@ static inline void
 zero_3d(Params3d_t *p)
 {
   int i;
-	
-  for (i = 0; i < 3; i++) {
-    p->rotations[i] = 0;
-    p->auto_rotate[i] = 0;
-    p->rotate_amount[i] = ROT_STEP;
-  }
 
+  for (i = X_AXIS; i <= Z_AXIS; i++) {
+    p->rotations[i] = 0;
+    p->rotate_factor[i] = 0;
+  }
   update(p);
 }
 
 
 static inline void
-spin_x(const Params3d_t *params3d, Point3d_t *p) 
+spin_x(const Params3d_t *params3d, Point3d_t *p)
 {
   /* Spin x */
   float tmp1, tmp2;
@@ -140,7 +138,7 @@ projection_perspective(const Params3d_t *params3d, const Point3d_t *p)
 {
   Point2d_t P;
   Point3d_t q = *p;
-	
+
   spin(params3d, &q);
 
   P.x = DIST * q.pos.x / (DIST + q.pos.z);
@@ -162,34 +160,16 @@ pixel_ecran(const Params3d_t *params3d, const Point2d_t *p)
 }
 
 
-static inline void
-set_pixel_3d_nc(const Params3d_t *params3d, Buffer8_t *b, const Point3d_t *p, const Pixel_t color) {
-  Point2d_t pp;
-  Point2d_t a;
-
-  pp = projection_perspective(params3d, p);
-  a = pixel_ecran(params3d, &pp);
-	
-  /*  if ((a.x >= MINX) && (a.x < WIDTH)
-      && (a.y >= MINY) && (a.y < HEIGHT)) */
-  if (((unsigned)(a.x-MINX) < (WIDTH-MINX)) && ((unsigned)(a.y-MINY) < (HEIGHT-MINY)))
-    set_pixel_nc(b, (short)a.x, (short)a.y, color);
-}
-
-
 static inline void
 set_pixel_3d(const Params3d_t *params3d, Buffer8_t *b, const Point3d_t *p, const guchar color)
 {
   Point2d_t pp;
   Point2d_t a;
-	
+
   pp = projection_perspective(params3d, p);
   a = pixel_ecran(params3d, &pp);
-  
-  /*  if ((a.x >= MINX) && (a.x < WIDTH)
-      && (a.y >= MINY) && (a.y < HEIGHT)) */
-  if (((unsigned)(a.x-MINX) < (WIDTH-MINX)) && ((unsigned)(a.y-MINY) < (HEIGHT-MINY)))
-    set_pixel_nc(b, (short)a.x, (short)a.y, color);
+
+  set_pixel(b, (short)a.x, (short)a.y, color);
 }
 
 
@@ -199,7 +179,17 @@ void draw_sphere_wireframe_3d(const Params3d_t *, Buffer8_t *, const Pixel_t);
 void draw_line_3d(const Params3d_t *, Buffer8_t *, const Point3d_t *, const Point3d_t *, const Pixel_t);
 
 void Params3d_rotate(Params3d_t *);
+#ifdef WITH_GL
 void Params3d_rotate_GL(Params3d_t *);
+#endif
 void Params3d_change_rotations(Params3d_t *);
 
+static inline int
+Params3d_is_rotating(const Params3d_t *params3d)
+{
+  return (params3d->rotate_factor[X_AXIS]
+          || params3d->rotate_factor[Y_AXIS]
+          || params3d->rotate_factor[Z_AXIS]);
+}
+
 #endif /* __BINIOU_PARAMS3D_H */
