@@ -44,14 +44,14 @@ Particle_delete(Particle_t *p)
 void
 Particle_System_delete(Particle_System_t *ps)
 {
-  GSList *p = ps->particles;
+  GSList *p = ps->particles, *p0 = p;
 
   while (p != NULL) {
     Particle_t *dp = (Particle_t *)p->data;
     p = g_slist_next(p);
     Particle_delete(dp);
   }
-  g_slist_free(p);
+  g_slist_free(p0);
 
   xfree(ps);
 }
@@ -100,10 +100,11 @@ Particle_new_rgba(float ttl, rgba_t rgba, Point3d_t pos, Point3d_t vel, Point3d_
 u_char
 Particle_System_can_add(const Particle_System_t *ps)
 {
-  if (ps->max_particles == PS_NOLIMIT)
+  if (ps->max_particles == PS_NOLIMIT) {
     return 1;
-  else
+  } else {
     return (ps->nb_particles < ps->max_particles);
+  }
 }
 
 
@@ -142,9 +143,9 @@ Particle_System_decay(Particle_System_t *ps)
       /* die, particle, die ! */
       Particle_delete(dp);
       ps->nb_particles--;
-    }
-    else
+    } else {
       newp = g_slist_prepend(newp, dp);
+    }
 
     tmp = g_slist_next(tmp);
   }
@@ -195,8 +196,7 @@ Particle_System_draw(const Particle_System_t *ps, const Params3d_t *params3d, Bu
 
   while (p != NULL) {
     Particle_t *dp = (Particle_t *)p->data;
-    set_pixel_3d_nc(params3d, dst, &dp->pos, dp->col.idx);
-
+    set_pixel_3d(params3d, dst, &dp->pos, dp->col.idx);
     p = g_slist_next(p);
   }
 }
