@@ -26,14 +26,14 @@
  */
 
 #ifdef DEBUG
-#define B_DLSYM(VAR, SYM)						\
-  (VAR) = (void (*)(struct Context_s *)) dlsym(p->handle, (SYM));	\
-  if (libbiniou_verbose && ((VAR) != NULL))				\
+#define B_DLSYM(VAR, SYM)                                         \
+  (VAR) = (void (*)(struct Context_s *)) dlsym(p->handle, (SYM)); \
+  if (libbiniou_verbose && ((VAR) != NULL))                       \
     printf("[p] >> %s has '%s'\n", p->name, (SYM))
-#define B_GOTSYM(VAR, SYM) if ((VAR) != NULL)		                \
+#define B_GOTSYM(VAR, SYM) if ((VAR) != NULL)                     \
     printf("[p] >> %s has '%s'\n", p->name, (SYM));
 #else
-#define B_DLSYM(VAR, SYM)						\
+#define B_DLSYM(VAR, SYM)                                         \
   (VAR) = (void (*)(struct Context_s *)) dlsym(p->handle, (SYM))
 #define B_GOTSYM(VAR, SYM) { }
 #endif
@@ -81,8 +81,9 @@ Plugin_load(Plugin_t *p)
   if (_tmp == NULL) {
     error = dlerror();
     xerror("Plugin MUST define options (%s)\n", error);
-  } else
+  } else {
     p->options = _tmp;
+  }
 
   _tmp = (u_long *) dlsym(p->handle, "mode");
   p->mode = _tmp;
@@ -90,24 +91,21 @@ Plugin_load(Plugin_t *p)
   /* get display name */
   p->dname = (char *) dlsym(p->handle, "dname");
   B_GOTSYM(p->dname, "dname");
-  if (p->dname == NULL)
+  if (p->dname == NULL) {
     p->dname = p->name;
+  }
 
   /* get description */
   p->desc = (char *) dlsym(p->handle, "desc");
   B_GOTSYM(p->desc, "desc");
 
-  B_DLSYM(p->create, "create");
+  p->create = (int8_t (*)(struct Context_s *)) dlsym(p->handle, "create");
   B_DLSYM(p->destroy, "destroy");
   B_DLSYM(p->run, "run");
   B_DLSYM(p->on_switch_on, "on_switch_on");
   B_DLSYM(p->on_switch_off, "on_switch_off");
-  p->on_key = (void (*)(u_char)) dlsym(p->handle, "on_key");
-  B_GOTSYM(p->on_key, "on_key");
 
   /* Output plugin stuff */
-  /* TODO: remove, use on_key callbacks */
-  B_DLSYM(p->set_cmap, "set_cmap");
   p->fullscreen = (void (*)(int)) dlsym(p->handle, "fullscreen");
   B_GOTSYM(p->fullscreen, "fullscreen");
   p->switch_cursor = (void (*)(void)) dlsym(p->handle, "switch_cursor");
@@ -133,14 +131,15 @@ Plugin_unload(Plugin_t *p)
   } else {
     if (p->calls) {
       VERBOSE(printf("[p] Unloading plugin '%s' (%li call%s)... ", p->name, p->calls,
-		     ((p->calls == 1) ? "" : "s")));
+                     ((p->calls == 1) ? "" : "s")));
     } else {
       VERBOSE(printf("[p] Unloading plugin '%s'... ", p->name));
     }
   }
 
-  if (p->destroy != NULL)
+  if (p->destroy != NULL) {
     p->destroy(context);
+  }
 
 #ifndef DISABLE_DLCLOSE
   VERBOSE(printf("dlclose... "));
@@ -162,12 +161,13 @@ Plugin_new(const char *directory, const char *name, const enum PluginType type)
   p->name = strdup(name);
   p->calls = 0;
 
-  if (type == PL_INPUT)
+  if (type == PL_INPUT) {
     p->file = g_strdup_printf("%s/input/%s/%s.so", directory, name, name);
-  else if (type == PL_MAIN)
+  } else if (type == PL_MAIN) {
     p->file = g_strdup_printf("%s/main/%s/%s.so", directory, name, name);
-  else if (type == PL_OUTPUT)
+  } else if (type == PL_OUTPUT) {
     p->file = g_strdup_printf("%s/output/%s/%s.so", directory, name, name);
+  }
 
   return Plugin_load(p);
 }
@@ -194,20 +194,23 @@ Plugin_reload(Plugin_t *p)
 }
 
 
-void
+int8_t
 Plugin_init(Plugin_t *p)
 {
+  int8_t res = 1;
   assert(p != NULL);
 
   if (p->create != NULL) {
     VERBOSE(printf("[+] Initializing plugin %s\n", p->name));
-    p->create(context);
+    res = p->create(context);
   }
 
-  if (p->jthread != NULL) {
+  if ((p->jthread != NULL) && res) {
     pthread_create(&p->thread, NULL, p->jthread, (void *)context);
     VERBOSE(printf("[p] Launched thread %s\n", p->name));
   }
+
+  return res;
 }
 
 
@@ -241,21 +244,3 @@ Plugin_dname(const Plugin_t *p)
   assert(p != NULL);
   return Plugin_uppercase(p->dname);
 }
-
-
-void
-Plugin_on_key(const uint32_t id, const u_char k)
-{
-  Plugin_t *p = Plugins_find(id);
-
-  if (NULL == p) {
-    printf("[!] Plugin id %"PRIu32" not found\n", id);
-    return;
-  }
-
-  if (NULL == p->on_key) {
-    printf("[!] Plugin id %"PRIu32" has no on_key callback\n", id);
-    return;
-  } else
-    p->on_key(k);
-}
