@@ -44,7 +44,7 @@ typedef struct Plugin_s {
 
   /* TODO a struct callbacks */
   /* callbacks */
-  void   (*create)(struct Context_s *);	        /* constructor */
+  int8_t (*create)(struct Context_s *);	        /* constructor */
   void   (*destroy)(struct Context_s *);	/* destructor */
 
   void   (*run)(struct Context_s *);	        /* run function */
@@ -53,23 +53,18 @@ typedef struct Plugin_s {
   void   (*on_switch_on)(struct Context_s *);	/* switching on */
   void   (*on_switch_off)(struct Context_s *);	/* switching off */
 
-  void   (*on_key)(const u_char);               /* key pressed callback */
-
   /* Output plugin stuff */
-  void (*set_cmap)(struct Context_s *); /* TODO Use plugin on_key callback */
-  void (*fullscreen)(const int); /* TODO Use plugin on_key callback */
-  void (*switch_cursor)(); /* TODO Use plugin on_key callback */
+  void (*fullscreen)(const int);
+  void (*switch_cursor)();
 } Plugin_t;
 
 Plugin_t *Plugin_new(const char *, const char *, const enum PluginType);
 void Plugin_delete(Plugin_t *);
 void Plugin_reload(Plugin_t *);
 
-void Plugin_init(Plugin_t *);
+int8_t Plugin_init(Plugin_t *);
 
 char *Plugin_name(const Plugin_t *);
 char *Plugin_dname(const Plugin_t *);
 
-void Plugin_on_key(const uint32_t, const u_char);
-
 #endif /* __BINIOU_PLUGIN_H */
