@@ -33,7 +33,7 @@ blacklisted(const char *name)
   if (p == NULL) {
     return 0;
   }
-  
+
   while (*p != NULL) {
     if (!strcmp(name, *p)) {
 #ifdef DEBUG
@@ -54,8 +54,9 @@ Plugins_new(const char *path)
 {
   Plugins_t *p = NULL;
 
-  if (NULL == path)
+  if (NULL == path) {
     path = ".";
+  }
 
   p = xcalloc(1, sizeof(Plugins_t));
 
@@ -74,8 +75,9 @@ Plugins_delete(Plugins_t *p)
 {
   short i;
 
-  for (i = 0; i < p->size; i++)
+  for (i = 0; i < p->size; i++) {
     Plugin_delete(p->plugins[i]);
+  }
   xfree(p->plugins);
   xfree(p->path);
   xfree(p);
@@ -86,22 +88,48 @@ Plugins_delete(Plugins_t *p)
 void
 Plugins_init(Plugins_t *ps)
 {
-  short i;
+  uint16_t i;
+  uint16_t old_size = ps->size;
 
-  if (libbiniou_verbose)
-    printf("[+] Initializing %d plugin%c\n", ps->size, (ps->size == 1) ? ' ' : 's');
-  for (i = 0; i < ps->size; i++) {
+  VERBOSE(printf("[+] Initializing %d plugin%c\n", ps->size, (ps->size == 1) ? ' ' : 's'));
+  for (i = 0; i < old_size; i++) {
     Plugin_t *p = ps->plugins[i];
-    u_short t;
 
-    Plugin_init(p);
+    if (!Plugin_init(p)) {
+      VERBOSE(printf("[!] Failed to initialize %s\n", p->name));
 
-    /* re-adjust on-boot B_DISABLED plugins */
-    for (t = 0; t < MAX_TYPES; t++)
-      if (*p->options & (1 << t))
-	if (*p->options & BEQ_DISABLED)
-	  if (pTypes[t].count > 0) /* XXX should not need this test */
-	    pTypes[t].count--;
+      /* plugin types stuff */
+      for (int t = 0; t < MAX_TYPES; t++)
+	if (*p->options & (1 << t)) {
+#ifdef DEBUG
+	  printf("[T] Has type %s\n", pTypes[t].name);
+#endif
+	  pTypes[t].count--;
+	}
+
+      if (plugins->selected == p) {
+	plugins->selected = NULL;
+	plugins->selected_idx = 0;
+      }
+      Plugin_delete(p);
+      ps->plugins[i] = NULL;
+      ps->size--;
+    }
+  }
+
+  // clean up disabled plugins
+  if (ps->size != old_size) {
+    Plugin_t **res = xcalloc(ps->size, sizeof(Plugin_t *));
+    uint16_t idx = 0;
+
+    for (i = 0; i < old_size; i++) {
+      if (ps->plugins[i] != NULL) {
+        res[idx++] = ps->plugins[i];
+      }
+    }
+
+    xfree(ps->plugins);
+    ps->plugins = res;
   }
 }
 
@@ -120,16 +148,18 @@ isPluginDir(const char *dir, const char *name)
   int rc = -1;
   char *soname = NULL;
 
-  if (name[0] == '.')
+  if (name[0] == '.') {
     return 0;
+  }
 
   /* XXX hardcoded main */
   soname = g_strdup_printf("%s/main/%s/%s.so", dir, name, name);
 
   rc = stat(soname, &istics);
   g_free(soname);
-  if (rc == -1)
+  if (rc == -1) {
     return 0;
+  }
 
   return ((rc == 0) && S_ISREG(istics.st_mode));
 }
@@ -164,29 +194,32 @@ Plugins_compare(const void *_p0, const void *_p1)
 
 
 void
-Plugins_load(Plugins_t *ps)
+Plugins_load(Plugins_t *ps, const Context_t *ctx)
 {
   DIR *da_dir;
   struct dirent *da_ent;
-  int i;
+  uint16_t i, old_size;
   gchar *blah;
 
   blah = g_strdup_printf("%s/main", ps->path);
-  if (libbiniou_verbose)
-    printf("[i] Loading plugins from %s\n", blah);
+  VERBOSE(printf("[i] Loading plugins from %s\n", blah));
 
-  if ((da_dir = opendir(blah)) == NULL)
+  if ((da_dir = opendir(blah)) == NULL) {
     xperror("opendir");
+  }
 
   g_free(blah);
   while ((da_ent = readdir(da_dir)) != NULL)
-    if (isPluginDir(ps->path, da_ent->d_name))
+    if (isPluginDir(ps->path, da_ent->d_name)) {
       ps->size++;
+    }
 
-  if (!ps->size)
+  if (!ps->size) {
     xerror("Won't do anything without a plugin, stupid\n");
+  }
   ps->plugins = xcalloc(ps->size, sizeof(Plugin_t *));
-
+  old_size = ps->size;
+  
   rewinddir(da_dir);
   i = 0;
 
@@ -196,8 +229,9 @@ Plugins_load(Plugins_t *ps)
     int j;
     const char *name = da_ent->d_name;
 
-    if (!isPluginDir(ps->path, name))
+    if (!isPluginDir(ps->path, name)) {
       continue;
+    }
 
     /* check if plugin is in the blacklist */
     if (blacklisted(name)) {
@@ -211,41 +245,70 @@ Plugins_load(Plugins_t *ps)
     /* load the plugin */
     p = ps->plugins[i] = Plugin_new(ps->path, name, PL_MAIN);
     if (NULL != p) {
-      if (libbiniou_verbose) {
-	if (NULL != p->desc)
-	  printf("        %s\n", p->desc);
-	else
-	  printf("!!! FIXME: %s has no description\n", name);
-      }
-
-      for (j = 0; j < i; j++)
-	if (p->id == ps->plugins[j]->id)
-	  xerror("Duplicated plugin id: %li\n", p->id);
-
-      /* plugin types stuff */
-      for (t = 0; t < MAX_TYPES; t++)
-	if (*p->options & (1 << t)) {
+      if (
+        ((ctx->input != NULL) ||
+        ((ctx->input == NULL) && (!(*p->options & BE_SFX2D) && !(*p->options & BE_SFX3D))))
+        // check if plugin needs input
+        &&
+        // check if plugin needs images
+        ((ctx->imgf != NULL) ||
+         ((ctx->imgf == NULL) && (!(*p->options & BEQ_IMAGE))))
+        &&
+        // check if plugin needs webcam
+        ((ctx->webcams > 0) ||
+         (!ctx->webcams && (!(*p->options & BEQ_MUTE_CAM))))
+        ) {
+        if (libbiniou_verbose) {
+          if (NULL != p->desc) {
+            printf("        %s\n", p->desc);
+          } else {
+            printf("!!! FIXME: %s has no description\n", name);
+          }
+        }
+        for (j = 0; j < i; j++)
+          if (p->id == ps->plugins[j]->id) {
+            xerror("Duplicated plugin id: %li\n", p->id);
+          }
+        /* plugin types stuff */
+	for (t = 0; t < MAX_TYPES; t++)
+	  if (*p->options & (1 << t)) {
 #ifdef DEBUG
-	  printf("[T] Has type %s\n", pTypes[t].name);
+	    printf("[T] Has type %s\n", pTypes[t].name);
 #endif
-	  if (!(*p->options & BEQ_NORANDOM))
 	    pTypes[t].count++;
-	}
+	  }
 #ifdef DEBUG
-      printf("\n");
+        printf("\n");
 #endif
-      i++;
-    } else
+        i++;
+      } else {
+        ps->plugins[i] = NULL;
+        Plugin_delete(p);
+        ps->size--;
+      }
+    } else {
       ps->size--;
+    }
   }
   closedir(da_dir);
 
+  Plugin_t **res = xcalloc(ps->size, sizeof(Plugin_t *));
+  int idx = 0;
+  for (i = 0; i < old_size; i++) {
+    if (ps->plugins[i] != NULL) {
+      res[idx++] = ps->plugins[i];
+    }
+  }
+  xfree(ps->plugins);
+  ps->plugins = res;
+  
   /* sort the plugins array */
   qsort((void *)ps->plugins, (size_t)ps->size,
-	(size_t)sizeof(Plugin_t *), &Plugins_compare);
+        (size_t)sizeof(Plugin_t *), &Plugins_compare);
 
-  if (libbiniou_verbose)
+  if (libbiniou_verbose) {
     printf("[+] Loaded %d plugin%c\n", ps->size, (ps->size == 1 ? ' ' : 's'));
+  }
 
   Plugins_select(ps, ps->plugins[0]);
 }
@@ -257,23 +320,26 @@ Plugins_find(const u_long id)
   short i;
 
   for (i = 0; i < plugins->size; i++)
-    if (plugins->plugins[i]->id == id)
+    if (plugins->plugins[i]->id == id) {
       return plugins->plugins[i];
+    }
 
   return NULL;
 }
 
 
 Plugin_t *
-Plugins_get_random(const enum PluginOptions feat)
+Plugins_get_random(const enum PluginOptions feat, const Plugin_t *locked)
 {
   int i;
   u_short rand = 0;
+  Plugin_t *chosen = NULL;
 
   /* check if we can select at random or not */
   for (i = 0; i < MAX_TYPES; i++)
-    if (pTypes[i].count && ((1 << i) & feat))
+    if (pTypes[i].count && ((1 << i) & feat)) {
       break;
+    }
 
   if (i == MAX_TYPES) {
     /* TODO option_to_string */
@@ -282,37 +348,45 @@ Plugins_get_random(const enum PluginOptions feat)
   }
   // else printf("pTypes[%d].count= %d\n", i, pTypes[i].count);
 
-  do {
-    rand = b_rand_int_range(0, plugins->size);
-  } while (!(*plugins->plugins[rand]->options & feat)
-	   || (*plugins->plugins[rand]->options & BEQ_NORANDOM)
-	   || (*plugins->plugins[rand]->options & BEQ_DISABLED));
+  uint8_t ignore_beq_norandom = (getenv("LEBINIOU_IGNORE_BEQ_NORANDOM") != NULL);
 
-  return plugins->plugins[rand];
+  int retry;
+  do {
+    retry = 0;
+    rand = b_rand_int_range(0, plugins->size);
+    chosen = plugins->plugins[rand];
+    if (!(*chosen->options & feat)) {
+      retry = 1;
+    } else {
+      if (!ignore_beq_norandom && (*chosen->options & BEQ_NORANDOM) && (chosen != locked)) {
+	retry = 1;
+      }
+    }
+  } while (retry);
+
+  return chosen;
 }
 
 
 void
 Plugins_next()
 {
-  do {
-    if (++plugins->selected_idx == plugins->size)
-      plugins->selected_idx = 0;
-    plugins->selected = plugins->plugins[plugins->selected_idx];
-  } while (*plugins->selected->options & BEQ_DISABLED);
-  printf("[i] Selected plugin: '%s' (%s)\n", plugins->selected->name, plugins->selected->dname);
+  if (++plugins->selected_idx == plugins->size) {
+    plugins->selected_idx = 0;
+  }
+  plugins->selected = plugins->plugins[plugins->selected_idx];
+  VERBOSE(printf("[i] Selected plugin: '%s' (%s)\n", plugins->selected->name, plugins->selected->dname));
 }
 
 
 void
 Plugins_prev()
 {
-  do {
-    if (--plugins->selected_idx == -1)
-      plugins->selected_idx = plugins->size-1;
-    plugins->selected = plugins->plugins[plugins->selected_idx];
-  } while (*plugins->selected->options & BEQ_DISABLED);
-  printf("[i] Selected plugin: '%s' (%s)\n", plugins->selected->name, plugins->selected->dname);
+  if (--plugins->selected_idx == -1) {
+    plugins->selected_idx = plugins->size - 1;
+  }
+  plugins->selected = plugins->plugins[plugins->selected_idx];
+  VERBOSE(printf("[i] Selected plugin: '%s' (%s)\n", plugins->selected->name, plugins->selected->dname));
 }
 
 
@@ -321,8 +395,9 @@ Plugins_next_n(const u_short n)
 {
   u_short i;
 
-  for (i = 0; i < n; i++)
+  for (i = 0; i < n; i++) {
     Plugins_next();
+  }
 }
 
 
@@ -331,8 +406,9 @@ Plugins_prev_n(const u_short n)
 {
   u_short i;
 
-  for (i = 0; i < n; i++)
+  for (i = 0; i < n; i++) {
     Plugins_prev();
+  }
 }
 
 
@@ -343,8 +419,9 @@ Plugins_change_run_callback(const u_long id, void (*run)(struct Context_s *))
 
   p = Plugins_find(id);
 
-  if (p != NULL)
+  if (p != NULL) {
     p->run = run;
+  }
 }
 
 
