@@ -23,37 +23,114 @@
 
 
 static enum PluginOptions
-Schemes_parse_one_option(const char *opt)
-{
-  if (!strcmp(opt, "SFX2D")) return BE_SFX2D;
-  if (!strcmp(opt, "SFX3D")) return BE_SFX3D;
-  if (!strcmp(opt, "GFX")) return BE_GFX;
-  if (!strcmp(opt, "BLUR")) return BE_BLUR;
-  if (!strcmp(opt, "DISPLACE")) return BE_DISPLACE;
-  if (!strcmp(opt, "LENS")) return BE_LENS;
-  if (!strcmp(opt, "SCROLL")) return BE_SCROLL;
-  if (!strcmp(opt, "MIRROR")) return BE_MIRROR;
-  if (!strcmp(opt, "ROLL")) return BE_ROLL;
-  if (!strcmp(opt, "WARP")) return BE_WARP;
-  if (!strcmp(opt, "CLEAN")) return BE_CLEAN;
-  if (!strcmp(opt, "HOR")) return BEQ_HOR;
-  if (!strcmp(opt, "VER")) return BEQ_VER;
-  if (!strcmp(opt, "DIAG")) return BEQ_DIAG;
-  if (!strcmp(opt, "UP")) return BEQ_UP;
-  if (!strcmp(opt, "DOWN")) return BEQ_DOWN;
-  if (!strcmp(opt, "LEFT")) return BEQ_LEFT;
-  if (!strcmp(opt, "RIGHT")) return BEQ_RIGHT;
-  if (!strcmp(opt, "COLORMAP")) return BEQ_COLORMAP;
-  if (!strcmp(opt, "PARTICLES")) return BEQ_PARTICLES;
-  if (!strcmp(opt, "SPLASH")) return BEQ_SPLASH;
+Schemes_parse_one_option(const char *opt) {
+  if (!strcmp(opt, "SFX2D"))
+  {
+    return BE_SFX2D;
+  }
+  if (!strcmp(opt, "SFX3D"))
+  {
+    return BE_SFX3D;
+  }
+  if (!strcmp(opt, "GFX"))
+  {
+    return BE_GFX;
+  }
+  if (!strcmp(opt, "BLUR"))
+  {
+    return BE_BLUR;
+  }
+  if (!strcmp(opt, "DISPLACE"))
+  {
+    return BE_DISPLACE;
+  }
+  if (!strcmp(opt, "LENS"))
+  {
+    return BE_LENS;
+  }
+  if (!strcmp(opt, "SCROLL"))
+  {
+    return BE_SCROLL;
+  }
+  if (!strcmp(opt, "MIRROR"))
+  {
+    return BE_MIRROR;
+  }
+  if (!strcmp(opt, "ROLL"))
+  {
+    return BE_ROLL;
+  }
+  if (!strcmp(opt, "WARP"))
+  {
+    return BE_WARP;
+  }
+  if (!strcmp(opt, "CLEAN"))
+  {
+    return BE_CLEAN;
+  }
+  if (!strcmp(opt, "HOR"))
+  {
+    return BEQ_HOR;
+  }
+  if (!strcmp(opt, "VER"))
+  {
+    return BEQ_VER;
+  }
+  if (!strcmp(opt, "DIAG"))
+  {
+    return BEQ_DIAG;
+  }
+  if (!strcmp(opt, "UP"))
+  {
+    return BEQ_UP;
+  }
+  if (!strcmp(opt, "DOWN"))
+  {
+    return BEQ_DOWN;
+  }
+  if (!strcmp(opt, "LEFT"))
+  {
+    return BEQ_LEFT;
+  }
+  if (!strcmp(opt, "RIGHT"))
+  {
+    return BEQ_RIGHT;
+  }
+  if (!strcmp(opt, "COLORMAP"))
+  {
+    return BEQ_COLORMAP;
+  }
+  if (!strcmp(opt, "PARTICLES"))
+  {
+    return BEQ_PARTICLES;
+  }
+  if (!strcmp(opt, "SPLASH"))
+  {
+    return BEQ_SPLASH;
+  }
   /*  if (!strcmp(opt, "THREAD")) return BEQ_THREAD; */ /* can not occur in a scheme */
-  if (!strcmp(opt, "IMAGE")) return BEQ_IMAGE;
-  if (!strcmp(opt, "PICTURE")) return BEQ_IMAGE; // backward compatibility for versions < 3.28
+  if (!strcmp(opt, "IMAGE"))
+  {
+    return BEQ_IMAGE;
+  }
+  if (!strcmp(opt, "PICTURE"))
+  {
+    return BEQ_IMAGE;  // backward compatibility for versions < 3.28
+  }
   /*  if (!strcmp(opt, "NORANDOM")) return BEQ_NORANDOM; */ /* can not occur in a scheme */
   /*  if (!strcmp(opt, "DISABLED")) return BEQ_DISABLED; */ /* idem */
-  if (!strcmp(opt, "UNIQUE")) return BEQ_UNIQUE;
-  if (!strcmp(opt, "FIRST")) return BEQ_FIRST;
-  if (!strcmp(opt, "LAST")) return BEQ_LAST;
+  if (!strcmp(opt, "UNIQUE"))
+  {
+    return BEQ_UNIQUE;
+  }
+  if (!strcmp(opt, "FIRST"))
+  {
+    return BEQ_FIRST;
+  }
+  if (!strcmp(opt, "LAST"))
+  {
+    return BEQ_LAST;
+  }
   /*  if (!strcmp(opt, "NONE")) return BE_NONE; */ /* can not occur in a scheme */
 
   xerror("[!] Failed to parse option '%s'\n", opt);
@@ -63,26 +140,30 @@ Schemes_parse_one_option(const char *opt)
 
 
 static enum PluginOptions
-Schemes_parse_option(const char *opt)
-{
+Schemes_parse_option(const char *opt) {
   int o = 0;
   char *pipe = NULL;
 
-  while ((pipe = strchr(opt, '|')) != NULL) {
+  while ((pipe = strchr(opt, '|')) != NULL)
+  {
     *pipe = '\0';
     if (*opt == '-') {
       opt++;
       o |= -Schemes_parse_one_option(opt);
-    } else
+    } else {
       o |= Schemes_parse_one_option(opt);
+    }
     opt = pipe + sizeof(char);
   }
 
-  if (*opt == '-') {
+  if (*opt == '-')
+  {
     opt++;
     o |= -Schemes_parse_one_option(opt);
   } else
+  {
     o |= Schemes_parse_one_option(opt);
+  }
 
   return (enum PluginOptions)o;
 }
@@ -97,8 +178,9 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
 
   /* Start at Root Element */
   schemes_node = xmlDocGetRootElement(doc);
-  if (schemes_node == NULL)
+  if (schemes_node == NULL) {
     xerror("xmlDocGetRootElement error\n");
+  }
 
   schemes_node = xmlFindElement("schemes", schemes_node);
   if (schemes_node == NULL) {
@@ -141,25 +223,28 @@ Schemes_parse(Schemes_t *schemes, const xmlDocPtr doc)
 
       type_node = xmlFindElement("type", type_node);
       if (type_node == NULL) {
-	int k;
+        int k;
 
-	printf("[!] No <type> found\n");
-	for (k = 0; k <= i; k++)
-	  xfree(schemes->schemes[k]);
-	xfree(schemes->schemes);
+        printf("[!] No <type> found\n");
+        for (k = 0; k <= i; k++) {
+          xfree(schemes->schemes[k]);
+        }
+        xfree(schemes->schemes);
 
-	return 0;
+        return 0;
       }
 
       wizz = xmlGetProp(type_node, (const xmlChar *)"proba");
       res = getfloatfield_optional(wizz, &p);
       xmlFree(wizz);
-      if (res == -1)
-	p = 1.0;
+      if (res == -1) {
+        p = 1.0;
+      }
 
       token = xmlNodeListGetString(doc, type_node->xmlChildrenNode, 1);
-      if (token == NULL)
-	xerror("No data in <type> element\n");
+      if (token == NULL) {
+        xerror("No data in <type> element\n");
+      }
 
       o = Schemes_parse_option((const char *)token);
       xmlFree(token);
@@ -182,8 +267,9 @@ Schemes_new(const char *file)
 {
   xmlDocPtr doc = NULL; /* XmlTree */
 
-  if (NULL == file)
+  if (NULL == file) {
     xerror("Schemes_new() called but file is NULL\n");
+  }
 
   schemes = xcalloc(1, sizeof(Schemes_t));
 
@@ -205,16 +291,20 @@ Schemes_new(const char *file)
   xmlFreeDoc(doc);
 
   if (!schemes->size) {
-    if (libbiniou_verbose)
+    if (libbiniou_verbose) {
       printf("[!] No schemes loaded\n");
+    }
     xfree(schemes); /* xfree sets the pointer to NULL */
   } else {
-    if (libbiniou_verbose)
+    if (libbiniou_verbose) {
       printf("[i] Loaded %d scheme%s\n", schemes->size, (schemes->size == 1) ? "": "s");
+    }
   }
 
   schemes->shuffler = Shuffler_new(schemes->size);
+#ifdef DEBUG
   Shuffler_verbose(schemes->shuffler);
+#endif
 }
 
 
@@ -240,11 +330,13 @@ Schemes_delete()
   if (schemes != NULL) {
     u_short i;
 
-    for (i = 0; i < schemes->size; i++)
+    for (i = 0; i < schemes->size; i++) {
       xfree(schemes->schemes[i]);
+    }
     xfree(schemes->schemes);
-    if (NULL != schemes->shuffler)
+    if (NULL != schemes->shuffler) {
       Shuffler_delete(schemes->shuffler);
+    }
     xfree(schemes);
   }
 }
