@@ -53,8 +53,9 @@ Sequence_find_position(const Sequence_t *s, const Plugin_t *p)
   tmp = g_list_first(s->layers);
   while (tmp != NULL) {
     Layer_t *l = (Layer_t *)tmp->data;
-    if (l->plugin == p)
+    if (l->plugin == p) {
       return pos;
+    }
     pos++;
     tmp = g_list_next(tmp);
   }
@@ -69,6 +70,7 @@ Sequence_new(const uint32_t id)
   Sequence_t *s = xcalloc(1, sizeof(Sequence_t));
 
   s->id = id;
+  s->auto_colormaps = s->auto_images = -1; // undefined by default
 
   return s;
 }
@@ -79,13 +81,15 @@ Sequence_clear(Sequence_t *s, const uint32_t new_id)
 {
   GList *tmp;
 
-  if (s == NULL)
+  if (s == NULL) {
     xerror("Attempt to Sequence_clear() a NULL sequence\n");
+  }
 
   s->id = new_id ? new_id : 0;
 
-  if (NULL != s->name)
+  if (NULL != s->name) {
     xfree(s->name);
+  }
 
   tmp = g_list_first(s->layers);
   while (tmp != NULL) {
@@ -99,10 +103,10 @@ Sequence_clear(Sequence_t *s, const uint32_t new_id)
   s->lens = NULL;
 
   s->image_id = 0;
-  s->auto_images = 0;
+  s->auto_images = -1; // undefined
 
   s->cmap_id = 0;
-  s->auto_colormaps = 0;
+  s->auto_colormaps = -1; // undefined
 
   Sequence_changed(s);
 }
@@ -111,8 +115,9 @@ Sequence_clear(Sequence_t *s, const uint32_t new_id)
 void
 Sequence_changed(Sequence_t *s)
 {
-  if (NULL != s)
+  if (NULL != s) {
     s->changed = 1;
+  }
 }
 
 
@@ -132,11 +137,11 @@ Sequence_delete(Sequence_t *s)
     }
 
     g_list_free(s->layers);
-    if (s->name != NULL)
+    if (s->name != NULL) {
       g_free(s->name);
+    }
     xfree(s);
-  } else
-    xerror("Attempt to free a NULL Sequence\n");
+  }
 }
 
 
@@ -149,20 +154,20 @@ Sequence_display(const Sequence_t *s)
   const char *image_name;
   int after_lens = 0;
 
-  if (s == NULL)
+  if (s == NULL) {
     xerror("Attempt to display a NULL Sequence\n");
-  else {
+  } else {
     VERBOSE(printf("[s] Sequence id: %"PRIu32"\n", s->id));
   }
 
   VERBOSE(printf("[s] Name: %s\n", (s->name != NULL) ? s->name : "(none)"));
 
   if (images != NULL) {
-    image_name = (s->image_id != 0) ? Images_name(s->image_id) : "default";
+    image_name = (s->image_id != 0) ? Images_name(s->image_id) : "current";
     VERBOSE(printf("[s] Image: %s\n", image_name));
   }
 
-  cmap_name = (s->cmap_id != 0) ? Colormaps_name(s->cmap_id) : "default";
+  cmap_name = (s->cmap_id != 0) ? Colormaps_name(s->cmap_id) : "current";
   VERBOSE(printf("[s] Colormap: %s\n", cmap_name));
 
   for (tmp = g_list_first(s->layers); tmp != NULL; tmp = g_list_next(tmp)) {
@@ -171,17 +176,22 @@ Sequence_display(const Sequence_t *s)
 
     if (P != NULL) {
       if ((s->lens != NULL) && (P == s->lens)) {
-	if (!after_lens) {
-	  VERBOSE(printf("--- %s\n", P->name));
-	  after_lens = 1;
-	} else {
-	  VERBOSE(printf("   %s\n", P->name));
-	}
+        if (!after_lens) {
+          VERBOSE(printf("[s] --- %s\n", P->name));
+          after_lens = 1;
+        } else {
+          VERBOSE(printf("[s]     %s\n", P->name));
+        }
       } else {
-	VERBOSE(printf(" |  %s\n", P->name));
+        if (after_lens) {
+          VERBOSE(printf("[s]     %s\n", P->name));
+        } else {
+          VERBOSE(printf("[s]  |  %s\n", P->name));
+        }
       }
-    } else
+    } else {
       xerror("Oops got a NULL plugin\n");
+    }
   }
 }
 
@@ -193,11 +203,13 @@ Sequence_copy(const Sequence_t *from, Sequence_t *to)
 
   to->id = from->id;
 
-  if (to->name != NULL)
+  if (to->name != NULL) {
     xfree(to->name);
+  }
 
-  if (from->name != NULL)
+  if (from->name != NULL) {
     to->name = strdup(from->name);
+  }
 
   tmp = g_list_first(to->layers);
   while (tmp != NULL) {
@@ -237,7 +249,7 @@ Sequence_sort_func(gconstpointer a, gconstpointer b)
   assert(sa != NULL);
   assert(sb != NULL);
 
-  return (sb->id - sa->id);
+  return (sa->id - sb->id);
 }
 
 
@@ -246,9 +258,12 @@ Sequence_insert(Sequence_t *s, Plugin_t *p) /* TODO LayerMode ? */
 {
   Layer_t *layer = Layer_new(p);
 
+  assert(p != NULL);
   /* set layer mode */
-  if (p->mode != NULL)
-    layer->mode = (enum LayerMode)*p->mode;
+  if (p->mode != NULL) {
+    assert(*(p->mode) < NB_LAYER_MODES);
+    layer->mode = (enum LayerMode)*(p->mode);
+  }
 
   /* insert plugin in sequence */
   if (*p->options & BEQ_FIRST) {
@@ -277,15 +292,17 @@ Sequence_insert_at_position(Sequence_t *s, const u_short position, Plugin_t *p)
   Layer_t *layer = Layer_new(p);
 
   /* set layer mode */
-  if (p->mode != NULL)
+  if (p->mode != NULL) {
     layer->mode = (enum LayerMode)*p->mode;
+  }
 
   /* insert plugin in sequence */
   s->layers = g_list_insert(s->layers, (gpointer)layer, position);
 
   /* set as lens if it's a lens, and there is no lens yet */
-  if ((*p->options & BE_LENS) && (s->lens == NULL))
+  if ((*p->options & BE_LENS) && (s->lens == NULL)) {
     s->lens = (Plugin_t *)p;
+  }
 
   Sequence_changed(s);
 }
@@ -303,8 +320,9 @@ Sequence_remove(Sequence_t *s, const Plugin_t *p)
   s->layers = g_list_remove(s->layers, (gconstpointer)layer);
 
   /* unset if it is a lens we removed */
-  if (s->lens == p)
+  if (s->lens == p) {
     s->lens = NULL;
+  }
 
   Sequence_changed(s);
 }
