@@ -32,24 +32,14 @@ typedef struct Sequence_s {
   GList    *layers;         /* list of plugins to run */
   Plugin_t *lens;           /* lens, NULL if none */
 
-  /* TODO ShufflerMode_e */
-  u_char   auto_colormaps;  /* Auto-change colormaps at random interval */
-  uint32_t cmap_id;         /* colormap to use, -1 if default */
+  char     auto_colormaps;  /* change colormaps at random interval (-1 == undefined) */
+  uint32_t cmap_id;         /* colormap to use, 0 if use current */
 
-  /* TODO ShufflerMode_e */
-  u_char   auto_images;     /* Auto-change images  at random interval */
-  uint32_t image_id;        /* image to use, 0 if default */
+  char     auto_images;     /* change images at random interval (-1 == undefined) */
+  uint32_t image_id;        /* image to use, 0 if use current */
 } Sequence_t;
 
 
-/*
- * TODO events callbacks:
- * F5/F6: shuffler mode = NONE
- * Shift+: SHUFFLE
- * Ctrl+: CYCLE
- * Alt+: RANDOM
- */
-
 Sequence_t *Sequence_new(const uint32_t);
 void Sequence_delete(Sequence_t *);
 
@@ -65,7 +55,7 @@ void Sequence_remove(Sequence_t *, const Plugin_t *);
 GList *Sequence_find(const Sequence_t *, const Plugin_t *);
 short Sequence_find_position(const Sequence_t *, const Plugin_t *);
 
-void Sequence_save(Sequence_t *, int, const int);
+void Sequence_save(Sequence_t *, int, const int, const uint8_t, const char, const char);
 Sequence_t *Sequence_load(const char *);
 
 gint Sequence_sort_func(gconstpointer, gconstpointer);
