@@ -39,9 +39,11 @@ Sequence_load(const char *file)
   char *dot = NULL;
   gchar *blah = NULL;
   xmlChar *youhou;
+  int legacy = 0;
 
-  if (file == NULL)
+  if (file == NULL) {
     xerror("Attempt to load a sequence with a NULL filename\n");
+  }
 
   dot = strrchr(file, '.');
   if ((dot == NULL) || strcasecmp(dot, ".xml")) {
@@ -66,8 +68,9 @@ Sequence_load(const char *file)
 
   doc = xmlParseFile(blah);
   g_free(blah);
-  if (doc == NULL)
+  if (doc == NULL) {
     xerror("xmlParseFile error\n");
+  }
 
   sequence_node = xmlDocGetRootElement(doc);
   if (sequence_node == NULL) {
@@ -84,34 +87,45 @@ Sequence_load(const char *file)
   youhou = xmlGetProp(sequence_node, (const xmlChar *)"id");
   tmp = getintfield(youhou);
   xmlFree(youhou);
-  assert(tmp > 0);
+
+  if (tmp <= 0) {
+    VERBOSE(printf("[!] Sequence %s: id must be > 0\n", file));
+    goto error;
+  }
 
   s = Sequence_new(tmp);
 
   /* first, get <auto_colormaps> */
-  sequence_node = sequence_node->xmlChildrenNode;
+  sequence_node_save = sequence_node = sequence_node->xmlChildrenNode;
 
   sequence_node = xmlFindElement("auto_colormaps", sequence_node);
   if (sequence_node == NULL) {
-    VERBOSE(printf("[!] Sequence %s: no <auto_colormaps> found\n", file));
-    goto error;
+    sequence_node = sequence_node_save;
+    goto bare_sequence;
   }
   res = xmlGetOptionalLong(doc, sequence_node, &tmp);
-  if (res == -1)
+  if (res == -1) {
     s->auto_colormaps = 0;
-  else
+  } else {
     s->auto_colormaps = (u_char)tmp;
+  }
   assert((s->auto_colormaps == 0) || (s->auto_colormaps == 1));
+#ifdef DEBUG
+  printf("[i] Random colormaps: %s\n", (s->auto_colormaps ? "on" : "off"));
+#endif
 
   if (!s->auto_colormaps) {
     /* not auto*, get colormap name */
     char *cmap = xmlGetMandatoryString(doc, "colormap", sequence_node);
+#ifdef DEBUG
+    printf("[i] Need colormap: '%s'\n", cmap);
+#endif
     s->cmap_id = Colormaps_find(cmap);
     xfree(cmap);
-  } else
+  } else {
     s->cmap_id = Colormaps_random_id();
+  }
 
-  int legacy = 0;
   /* then, get  <auto_images> or (legacy) <auto_pictures> */
   sequence_node_save = sequence_node = sequence_node->next;
   sequence_node = xmlFindElement("auto_images", sequence_node);
@@ -126,10 +140,11 @@ Sequence_load(const char *file)
     }
   }
   res = xmlGetOptionalLong(doc, sequence_node, &tmp);
-  if (res == -1)
+  if (res == -1) {
     s->auto_images = 0;
-  else
+  } else {
     s->auto_images = (u_char)tmp;
+  }
   assert((s->auto_images == 0) || (s->auto_images == 1));
 #ifdef DEBUG
   printf("[i] Random images: %s\n", (s->auto_images ? "on" : "off"));
@@ -148,7 +163,7 @@ Sequence_load(const char *file)
     } else {
       s->image_id = Images_find(image);
       if (s->image_id == 0) {
-	VERBOSE(printf("[!] Image '%s' not found, using default\n", image));
+        VERBOSE(printf("[!] Image '%s' not found, using default\n", image));
       }
       xfree(image);
     }
@@ -157,10 +172,12 @@ Sequence_load(const char *file)
       s->broken = 1;
       s->image_id = -1;
       s->auto_images = 0;
-    } else
+    } else {
       s->image_id = Images_random_id();
+    }
   }
 
+bare_sequence:
   /* now, get plugins */
   plugins_node = xmlFindElement("plugins", sequence_node);
   if (plugins_node == NULL) {
@@ -184,30 +201,32 @@ Sequence_load(const char *file)
     youhou = xmlGetProp(plugins_node, (const xmlChar *)"id");
     tmp = getintfield(youhou);
     xmlFree(youhou);
-    if (!tmp)
+    if (!tmp) {
       goto error;
+    }
 
     p = Plugins_find((u_long)tmp);
-    if (p == NULL)
+    if (p == NULL) {
       goto error;
+    }
 
-    if (!(*p->options & BEQ_DISABLED)) {
-      enum LayerMode mode;
+    enum LayerMode mode;
 
-      layer = Layer_new(p);
+    layer = Layer_new(p);
 
-      youhou = xmlGetProp(plugins_node, (const xmlChar *)"mode");
-      if (youhou != NULL) {
-	mode = LayerMode_from_string((const char *)youhou);
-	xmlFree(youhou);
-      } else
-	mode = NORMAL;
-      layer->mode = mode;
+    youhou = xmlGetProp(plugins_node, (const xmlChar *)"mode");
+    if (youhou != NULL) {
+      mode = LayerMode_from_string((const char *)youhou);
+      xmlFree(youhou);
+    } else {
+      mode = NORMAL;
+    }
+    layer->mode = mode;
 
-      s->layers = g_list_append(s->layers, (gpointer)layer);
+    s->layers = g_list_append(s->layers, (gpointer)layer);
 
-      if (lens)
-	s->lens = (Plugin_t *)p;
+    if (lens) {
+      s->lens = (Plugin_t *)p;
     }
 
     plugins_node = plugins_node->next;
@@ -225,7 +244,7 @@ Sequence_load(const char *file)
 
   return s;
 
- error:
+error:
   VERBOSE(printf("[!] Failed to load sequence from file '%s'\n", file));
 
   /* Clean up */
