@@ -26,7 +26,8 @@
 
 
 static void
-Sequence_write(const Sequence_t *s, const char *filename)
+Sequence_write(const Sequence_t *s, const char *filename,
+               const uint8_t full)
 {
   xmlDoc *doc;
   GList *layers;
@@ -37,17 +38,20 @@ Sequence_write(const Sequence_t *s, const char *filename)
   node = doc->children = xmlNewDocNode(doc, NULL, (const xmlChar *)"sequence", NULL);
   xml_set_id(node, s->id);
 
-  xmlNewChild(node, NULL, (const xmlChar *)"auto_colormaps",
-              (const xmlChar *)((s->auto_colormaps) ? "1" : "0"));
+  if (full) {
+    /* here auto_colormaps and auto_images are 0 or 1, not -1 */
+    xmlNewChild(node, NULL, (const xmlChar *)"auto_colormaps",
+                (const xmlChar *)((s->auto_colormaps) ? "1" : "0"));
+    if (!s->auto_colormaps) {
+      xmlNewTextChild(node, NULL, (const xmlChar *)"colormap", (const xmlChar *)Colormaps_name(s->cmap_id));
+    }
 
-  if (!s->auto_colormaps)
-    xmlNewTextChild(node, NULL, (const xmlChar *)"colormap", (const xmlChar *)Colormaps_name(s->cmap_id));
-
-  xmlNewChild(node, NULL, (const xmlChar *)"auto_images",
-              (const xmlChar *)((s->auto_images) ? "1" : "0"));
-
-  if (!s->auto_images)
-    xmlNewTextChild(node, NULL, (const xmlChar *)"image", (const xmlChar *)Images_name(s->image_id));
+    xmlNewChild(node, NULL, (const xmlChar *)"auto_images",
+                (const xmlChar *)((s->auto_images) ? "1" : "0"));
+    if (!s->auto_images) {
+      xmlNewTextChild(node, NULL, (const xmlChar *)"image", (const xmlChar *)Images_name(s->image_id));
+    }
+  }
 
   /* create <plugins> block */
   plugins_node = xmlNewChild(node, NULL, (const xmlChar *)"plugins", NULL);
@@ -60,10 +64,11 @@ Sequence_write(const Sequence_t *s, const char *filename)
     const char *tmp;
 
     /* decide whether block is <lens> or <plugin> */
-    if ((s->lens != NULL) && (p == s->lens))
+    if ((s->lens != NULL) && (p == s->lens)) {
       tmp = "lens";
-    else
+    } else {
       tmp = "plugin";
+    }
 
     nd = xmlNewChild(plugins_node, NULL, (const xmlChar *)tmp, NULL);
 
@@ -85,7 +90,8 @@ Sequence_write(const Sequence_t *s, const char *filename)
 
 
 void
-Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
+Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
+              const uint8_t bare, const char auto_colormaps, const char auto_images)
 {
   char *filename = NULL;
   Sequence_t *store = NULL;
@@ -109,8 +115,9 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
     s->id = unix_timestamp();
   }
 
-  if (s->name != NULL)
+  if (s->name != NULL) {
     xfree(s->name);
+  }
   s->name = g_strdup_printf("%"PRIu32, s->id);
   printf("[s] Saving sequence %"PRIu32"\n", s->id);
 
@@ -118,14 +125,24 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
   rmkdir(blah);
   // g_free(blah);
 
-  if (overwrite)
+  if (overwrite) {
     filename = g_strdup_printf("%s/%s.xml", blah, s->name);
-  else
+  } else {
     filename = g_strdup_printf("%s/%"PRIu32".xml", blah, s->id);
+  }
 
   printf("[s] Filename: %s\n", filename);
 
-  Sequence_write(s, filename);
+  /* set auto_colormaps from context if needed */
+  if (s->auto_colormaps == -1) {
+    s->auto_colormaps = auto_colormaps;
+  }
+  /* set auto_images from context if needed */
+  if (s->auto_images == -1) {
+    s->auto_images = auto_images;
+  }
+
+  Sequence_write(s, filename, bare);
 
   g_free(filename);
 
@@ -138,8 +155,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
     if (oldp != NULL) {
       old = (Sequence_t *)oldp->data;
       Sequence_copy(s, old);
-    }
-    else {
+    } else {
       overwrite = 0;
     }
   }
