@@ -64,17 +64,21 @@ SequenceManager_move_selected_front(Sequence_t *seq)
   const Plugin_t *P = NULL;
 
   list = seq->layers;
-  if (g_list_length(list) <= 1)
+  if (g_list_length(list) <= 1) {
     return;
+  }
 
-  if ((where = Sequence_find(seq, plugins->selected)) == NULL)
+  if ((where = Sequence_find(seq, plugins->selected)) == NULL) {
     return;
+  }
 
   layer = (const Layer_t *)where->data;
   P = layer->plugin;
   if ((Plugin_t *)((const Layer_t *)list->data)->plugin == P)
     /* already at the beginning */
+  {
     return;
+  }
 
   prev = g_list_previous(where);
   list = g_list_remove(list, (gpointer)layer);
@@ -95,17 +99,21 @@ SequenceManager_move_selected_back(Sequence_t *seq)
   const Plugin_t *P = NULL;
 
   list = seq->layers;
-  if (g_list_length(list) <= 1)
+  if (g_list_length(list) <= 1) {
     return;
+  }
 
-  if ((where = Sequence_find(seq, plugins->selected)) == NULL)
+  if ((where = Sequence_find(seq, plugins->selected)) == NULL) {
     return;
+  }
 
   layer = (const Layer_t *)where->data;
   P = layer->plugin;
   if ((Plugin_t *)((const Layer_t *)g_list_last(list)->data) == P)
     /* already at the end */
+  {
     return;
+  }
 
   next = g_list_next(where);
   next = g_list_next(next);
@@ -120,10 +128,11 @@ SequenceManager_move_selected_back(Sequence_t *seq)
 void
 SequenceManager_toggle_lens(Sequence_t *seq)
 {
-  if (seq->lens == plugins->selected)
+  if (seq->lens == plugins->selected) {
     seq->lens = NULL;
-  else
+  } else {
     seq->lens = plugins->selected;
+  }
 
   Sequence_changed(seq);
 }
@@ -141,8 +150,9 @@ SequenceManager_select_previous_plugin(Sequence_t *seq)
       P = ((const Layer_t *)g_list_last(seq->layers)->data)->plugin;
     } else {
       hou = g_list_previous(hou);
-      if (hou == NULL)
-	hou = g_list_last(seq->layers);
+      if (hou == NULL) {
+        hou = g_list_last(seq->layers);
+      }
       P = ((const Layer_t *)hou->data)->plugin;
     }
     Plugins_select(plugins, P);
@@ -162,8 +172,9 @@ SequenceManager_select_next_plugin(Sequence_t *seq)
       P = ((const Layer_t *)g_list_first(seq->layers)->data)->plugin;
     } else {
       hou = g_list_next(hou);
-      if (hou == NULL)
-	hou = g_list_first(seq->layers);
+      if (hou == NULL) {
+        hou = g_list_first(seq->layers);
+      }
       P = ((const Layer_t*)hou->data)->plugin;
     }
     Plugins_select(plugins, P);
@@ -190,10 +201,11 @@ SequenceManager_prev_layer_mode(const Sequence_t *seq)
 
   if (ptr != NULL) {
     Layer_t *layer = (Layer_t *)ptr->data;
-    if (layer->mode == NONE)
+    if (layer->mode == NONE) {
       layer->mode = RANDOM;
-    else
+    } else {
       --layer->mode;
+    }
   }
 }
 
@@ -205,9 +217,10 @@ SequenceManager_next_layer_mode(const Sequence_t *seq)
 
   if (ptr != NULL) {
     Layer_t *layer = (Layer_t *)ptr->data;
-    if (layer->mode == RANDOM)
+    if (layer->mode == RANDOM) {
       layer->mode = NONE;
-    else
+    } else {
       ++layer->mode;
+    }
   }
 }
