@@ -48,7 +48,7 @@ void SequenceManager_default_layer_mode(const Sequence_t *);
 void SequenceManager_prev_layer_mode(const Sequence_t *);
 void SequenceManager_next_layer_mode(const Sequence_t *);
 
-int SequenceManager_event(SequenceManager_t *, const Event_t *);
+int SequenceManager_event(SequenceManager_t *, const Event_t *, const char, const char);
 
 int SequenceManager_is_transient(const SequenceManager_t *, const Sequence_t *);
 
