@@ -44,17 +44,19 @@ Sequences_new()
     // g_free(blah);
     while ((entry = readdir(dir)) != NULL) {
       if (strcmp(entry->d_name, "..")) {
-	Sequence_t *s = NULL;
+        Sequence_t *s = NULL;
 
-	s = Sequence_load(entry->d_name);
+        s = Sequence_load(entry->d_name);
 
-	if (s != NULL)
-	  sequences->seqs = g_list_insert_sorted(sequences->seqs, (gpointer)s, Sequence_sort_func);
+        if (s != NULL) {
+          sequences->seqs = g_list_insert_sorted(sequences->seqs, (gpointer)s, Sequence_sort_func);
+        }
       }
     }
 
-    if (closedir(dir) == -1)
+    if (closedir(dir) == -1) {
       xperror("closedir");
+    }
   }
 
   sequences->size = g_list_length(sequences->seqs);
@@ -69,8 +71,9 @@ Sequences_free()
 {
   GList *tmp;
 
-  if (sequences == NULL)
-	return;
+  if (sequences == NULL) {
+    return;
+  }
 
   tmp = sequences->seqs;
 
@@ -100,8 +103,9 @@ Sequences_find(const uint32_t id)
   while (tmp != NULL) {
     Sequence_t *s = (Sequence_t *)tmp->data;
 
-    if (s->id == id)
+    if (s->id == id) {
       return s;
+    }
 
     tmp = g_list_next(tmp);
   }
