@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -36,4 +36,8 @@ void Sequences_free();
 
 Sequence_t *Sequences_find(const uint32_t);
 
+void Sequences_set_dir(char *);
+const char *Sequences_get_dir();
+
+
 #endif /* __BINIOU_SEQUENCES_H */
