@@ -31,8 +31,9 @@ sighandle(int sig)
   case SIGHUP:
   case SIGINT:
     exit(1);
-    if (!biniou_stop())
+    if (!biniou_stop()) {
       exit(0);
+    }
     break;
 
   default:
@@ -45,10 +46,13 @@ sighandle(int sig)
 void
 register_signals(void)
 {
-  if (signal(SIGTERM, sighandle) == SIG_ERR)
+  if (signal(SIGTERM, sighandle) == SIG_ERR) {
     printf("[!] can't catch SIGTERM signal\n");
-  if (signal(SIGHUP, sighandle) == SIG_ERR)
+  }
+  if (signal(SIGHUP, sighandle) == SIG_ERR) {
     printf("[!] can't catch SIGHUP signal\n");
-  if (signal(SIGINT, sighandle) == SIG_ERR)
+  }
+  if (signal(SIGINT, sighandle) == SIG_ERR) {
     printf("[!] can't catch SIGINT signal\n");
+  }
 }
