@@ -34,8 +34,9 @@ Spline_new(const uint8_t span, const int64_t nb_cpoints)
   s->nb_spoints = (s->nb_cpoints - 1) * s->span + 1;
   s->dt = 1.0 / (double)s->span;
 
-  for (dd = 0; dd < 8; dd++)
+  for (dd = 0; dd < 8; dd++) {
     s->space[dd] = xcalloc(nb_cpoints, sizeof(double));
+  }
 
   s->cpoints = xcalloc(s->nb_cpoints, sizeof(Point3d_t));
   s->spoints = xcalloc(s->nb_spoints, sizeof(Point3d_t));
@@ -52,8 +53,9 @@ Spline_delete(Spline_t *s)
   xfree(s->cpoints);
   xfree(s->spoints);
 
-  for (dd = 0; dd < 8; dd++)
+  for (dd = 0; dd < 8; dd++) {
     xfree(s->space[dd]);
+  }
 
   xfree(s);
 }
@@ -71,8 +73,9 @@ Spline_compute(const Spline_t *s)
   uint8_t k;
   Point3d_t *v;
 
-  if (s->nb_cpoints < 2)
+  if (s->nb_cpoints < 2) {
     return;
+  }
 
   h0 = s->space[0];
   h1 = s->space[1];
@@ -87,8 +90,9 @@ Spline_compute(const Spline_t *s)
 
     /* Trigonal system */
 
-    for (i = 0; i < s->nb_cpoints; i++)
+    for (i = 0; i < s->nb_cpoints; i++) {
       d[i] = s->cpoints[i].coords[k];
+    }
 
     for (i = 0, imax = s->nb_cpoints - 2; i < imax; i++) {
       h3[i] = 3 * (d[i + 2] - 2 * d[i + 1] + d[i]);
@@ -108,11 +112,13 @@ Spline_compute(const Spline_t *s)
     }
     b[s->nb_cpoints - 3] = h1[s->nb_cpoints - 3];
 
-    for (i = s->nb_cpoints - 4; i >= 0; i--)
+    for (i = s->nb_cpoints - 4; i >= 0; i--) {
       b[i] = h1[i] - h0[i] * b[i + 1];
+    }
 
-    for (i = s->nb_cpoints - 2; i >= 1; i--)
+    for (i = s->nb_cpoints - 2; i >= 1; i--) {
       b[i] = b[i - 1];
+    }
 
     b[0] = b[s->nb_cpoints - 1] = 0;
     hi_a = a + s->nb_cpoints - 1;
@@ -133,19 +139,20 @@ Spline_compute(const Spline_t *s)
       int64_t lcount = 0;
 #endif
       for ( ; a < hi_a; a++, b++, c++, d++)
-	for (t = 0; t < 1 - 1e-7; t += s->dt) {
-	  // for (t = 0; t < 1.0 - s->dt; t += s->dt) {
-	  // printf("spoints= %ld, lcount= %ld\n", s->nb_spoints, lcount);
-	  (*v++).coords[k] = ((*a * t + *b) * t + *c) * t + *d;
+        for (t = 0; t < 1 - 1e-7; t += s->dt) {
+          // for (t = 0; t < 1.0 - s->dt; t += s->dt) {
+          // printf("spoints= %ld, lcount= %ld\n", s->nb_spoints, lcount);
+          (*v++).coords[k] = ((*a * t + *b) * t + *c) * t + *d;
 #ifdef DEBUG
-	  lcount++;
+          lcount++;
 #endif
-	}
+        }
       (*v++).coords[k] = *d;
 #ifdef DEBUG
       lcount++;
-      if (lcount > s->nb_spoints)
-	xerror("spline fatal: %d points, wanted to set %d\n", s->nb_spoints, lcount);
+      if (lcount > s->nb_spoints) {
+        xerror("spline fatal: %d points, wanted to set %d\n", s->nb_spoints, lcount);
+      }
     }
 #endif
   }
