@@ -41,7 +41,7 @@ Translation_build(Translation_t *t)
 
 
 Translation_t *
-Translation_new(Map_t(*f)(const u_short, const u_short), void (*init)())
+Translation_new(Map_t (*f)(const short, const short), void (*init)())
 {
   Translation_t *t = NULL;
 
@@ -75,14 +75,11 @@ Translation_idle(const Translation_t *t, const Context_t *ctx)
   M_wPoint_t *p = t->point;
   u_short i, j;
 
-  /* printf("Translation_idle\n"); */
-
   for (j = 0; j < HEIGHT; j++)
     for (i = 0; i < WIDTH; i++) {
       set_pixel_nc(dst, i, j,
-		   get_pixel_nc(src,
-				(u_short)p[j*WIDTH+i].x,
-				(u_short)p[j*WIDTH+i].y));
+                   get_pixel_nc(src, (u_short)p[j * WIDTH + i].x,
+                                     (u_short)p[j * WIDTH + i].y));
     }
 }
 
@@ -95,20 +92,23 @@ Translation_fade(Translation_t *t, const Context_t *ctx)
   M_wPoint_t *p = t->point;
   u_short i, j;
 
-  /* printf("Translation_fade\n"); */
-
   for (j = 0; j < HEIGHT; j++)
     for (i = 0; i < WIDTH; i++) {
-      p[j*WIDTH+i].x += p[j*WIDTH+i].dx;
-      p[j*WIDTH+i].y += p[j*WIDTH+i].dy;
-      /* FIXME using get_pixel_nc here causes a segfault when compiled
-	 with --disable-sanity-checks */
+      p[j * WIDTH + i].x += p[j * WIDTH + i].dx;
+      p[j * WIDTH + i].y += p[j * WIDTH + i].dy;
+
       set_pixel_nc(dst, i, j, get_pixel_nc(src,
-					   (u_short)p[j*WIDTH+i].x,
-					   (u_short)p[j*WIDTH+i].y));
+                        (u_short)(p[j * WIDTH + i].x + WIDTH ) % WIDTH,
+                        (u_short)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT));
     }
 
-  --t->fading;
+  /* save coordinages cropped to screen size */
+  if (--t->fading == 0)
+    for (j = 0; j < HEIGHT; j++)
+      for (i = 0; i < WIDTH; i++) {
+        p[j * WIDTH + i].x = (u_short)(p[j * WIDTH + i].x + WIDTH) % WIDTH;
+        p[j * WIDTH + i].y = (u_short)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT;
+      }
 }
 
 
@@ -119,21 +119,24 @@ Translation_compute(Translation_t *t)
 
   assert(t != NULL);
   for (k = 0; (k < BATCH_LINES) && !Translation_batch_done(t); k++)
-    if (Translation_batch_line(t))
+    if (Translation_batch_line(t)) {
       return;
+    }
 }
 
 
 int
 Translation_run(Translation_t *t, const Context_t *ctx)
 {
-  if (!Translation_batch_done(t))
+  if (!Translation_batch_done(t)) {
     Translation_compute(t);
+  }
 
-  if (t->fading)
+  if (t->fading) {
     Translation_fade(t, ctx);
-  else
+  } else {
     Translation_idle(t, ctx);
+  }
 
   return t->fading;
 }
@@ -161,21 +164,21 @@ Translation_batch_init(Translation_t *t)
 u_char
 Translation_batch_line(Translation_t *t)
 {
-  u_short i;
   M_wPoint_t *wp = &t->point[t->line * WIDTH];
 
-  for (i = 0; i < WIDTH; i++) {
+  for (u_short i = 0; i < WIDTH; i++) {
     Map_t m = t->f(wp->x, wp->y);
-    wp->dx = (float)((float)m.map_x - (float)wp->x) / FADE_STEPS;
-    wp->dy = (float)((float)m.map_y - (float)wp->y) / FADE_STEPS;
+    wp->dx  = (float)((float)m.map_x - (float)wp->x) / FADE_STEPS;
+    wp->dy  = (float)((float)m.map_y - (float)wp->y) / FADE_STEPS;
     wp++;
   }
 
   if (++t->line == HEIGHT) {
     Translation_init_fade(t);
     return 1;
-  } else
+  } else {
     return 0;
+  }
 }
 
 
