@@ -33,7 +33,7 @@
 
 /* -- Map -- */
 typedef struct Map_s {
-  u_short map_x, map_y;
+  short map_x, map_y;
 } Map_t;
 
 
@@ -46,7 +46,7 @@ typedef struct M_wPoint_s {
 
 /* -- Translation -- */
 typedef struct Translation_s {
-  Map_t      (*f)(const u_short, const u_short);
+  Map_t      (*f)(const short, const short);
   M_wPoint_t *point;
   int        line;
   u_char     fading;
@@ -54,7 +54,7 @@ typedef struct Translation_s {
 } Translation_t;
 
 
-Translation_t *Translation_new(Map_t (*)(const u_short, const u_short), void (*)());
+Translation_t *Translation_new(Map_t (*)(const short, const short), void (*)());
 void   Translation_delete(Translation_t *);
 
 int    Translation_run(Translation_t *, const Context_t *);
