@@ -50,8 +50,9 @@ xperror(const char *why)
 void
 okdone(const char *what)
 {
-  if (libbiniou_verbose)
+  if (libbiniou_verbose) {
     printf("[+] %s\n", what);
+  }
 }
 
 
@@ -60,8 +61,9 @@ xmalloc(const size_t size)
 {
   void *pouet = malloc(size);
 
-  if (NULL == pouet)
-    xerror("xmalloc: malloc failed\n");
+  if (NULL == pouet) {
+    xperror("malloc");
+  }
 
   return pouet;
 }
@@ -72,8 +74,9 @@ xcalloc(const size_t nmemb, const size_t size)
 {
   void *pouet = calloc(nmemb, size);
 
-  if (NULL == pouet)
-    xerror("xcalloc: calloc failed\n");
+  if (NULL == pouet) {
+    xperror("calloc");
+  }
 
   return pouet;
 }
@@ -84,8 +87,9 @@ xrealloc(void *ptr, size_t size)
 {
   void *pouet = realloc(ptr, size);
 
-  if (NULL == pouet)
-    xerror("xrealloc: realloc failed\n");
+  if (NULL == pouet) {
+    xperror("realloc");
+  }
 
   return pouet;
 }
@@ -98,8 +102,9 @@ xatol(const char *value)
 
   errno = 0;
   l = strtol(value, NULL, 10);
-  if (errno != 0)
+  if (errno != 0) {
     xperror("strtol");
+  }
 
   return l;
 }
@@ -111,8 +116,9 @@ rmkdir2(const char *dir)
   const mode_t omode = S_IRWXU|S_IRWXG|S_IRWXO;
 
   if (access(dir, R_OK) == -1) {
-    if (mkdir(dir, omode) == -1)
+    if (mkdir(dir, omode) == -1) {
       xperror("mkdir");
+    }
   }
 }
 
@@ -127,10 +133,11 @@ rmkdir(const char *p)
   assert(p != NULL);
   path = strdup(p);
 
-  if (path[0] == '/')
+  if (path[0] == '/') {
     slash = strchr(path+sizeof(char), '/');
-  else
+  } else {
     slash = strchr(path, '/');
+  }
 
   while (slash != NULL) {
     *slash = '\0';
@@ -194,33 +201,37 @@ parse_two_shorts(const char *str, const int delim, short *a, short *b)
   char *found = NULL;
   long a0, b0;
 
-  if ((NULL == a) && (NULL == b))
-    xerror("%s: no variable to set !\n", __FUNCTION__, a, b);
+  if ((NULL == a) && (NULL == b)) {
+    xerror("%s: No variable to set !\n", __FUNCTION__, a, b);
+  }
 
   dup = strdup(str);
-  if (NULL == dup)
-    xerror("strdup\n");
+  if (NULL == dup) {
+    xperror("strdup");
+  }
 
   found = strchr(str, delim);
-  if (NULL == found)
-    xerror("%s: did not find delimiter '%c' in \"%s\"\n", __FUNCTION__, delim, str);
-  *found = '\0';
-  found++;
+  if (NULL == found) {
+    xerror("%s: Did not find delimiter '%c' in \"%s\"\n", __FUNCTION__, delim, str);
+  }
+  *found++ = '\0';
 
   if (NULL != a) {
     a0 = xatol(dup);
-    if ((a0 >= SHRT_MIN) && (a0 <= SHRT_MAX))
+    if ((a0 >= SHRT_MIN) && (a0 <= SHRT_MAX)) {
       *a = a0;
-    else
+    } else {
       rc = -1;
+    }
   }
 
   if (NULL != b) {
     b0 = xatol(found);
-    if ((b0 >= SHRT_MIN) && (b0 <= SHRT_MAX))
+    if ((b0 >= SHRT_MIN) && (b0 <= SHRT_MAX)) {
       *b = b0;
-    else
+    } else {
       rc = -1;
+    }
   }
 
   xfree(dup);
@@ -235,8 +246,9 @@ check_command(const char *cmd)
 {
   if (cmd != NULL) {
     int res = system(cmd);
-    if (!res)
+    if (!res) {
       return 0;
+    }
   }
   return -1;
 }
