@@ -58,7 +58,7 @@ void ms_sleep(const u_long);
 int parse_two_shorts(const char *, const int, short *, short *);
 
 extern u_char       libbiniou_verbose;
-#define VERBOSE(X) if (libbiniou_verbose) X
+#define VERBOSE(X) if (libbiniou_verbose) { X; fflush(stdout); }
 
 int check_command(const char *);
 
