@@ -28,9 +28,9 @@ xioctl(int fd, int request, void *arg)
 {
   int r;
 
-  do
+  do {
     r = ioctl(fd, request, arg);
-  while ((-1 == r) && (EINTR == errno));
+  } while ((-1 == r) && (EINTR == errno));
 
   return r;
 }
@@ -39,7 +39,7 @@ xioctl(int fd, int request, void *arg)
 void
 init_read(unsigned int buffer_size, webcam_t *cam)
 {
-  cam->buffers = xmalloc(sizeof(buffer_t));
+  cam->buffers = xcalloc(1, sizeof(buffer_t));
   cam->buffers[0].length = buffer_size;
   cam->buffers[0].start = xmalloc(buffer_size);
 }
@@ -57,39 +57,43 @@ init_mmap(webcam_t *cam)
   req.memory              = V4L2_MEMORY_MMAP;
 
   if (-1 == xioctl(cam->fd, VIDIOC_REQBUFS, &req)) {
-    if (EINVAL == errno)
+    if (EINVAL == errno) {
       xerror("%s%d does not support memory mapping\n", video_base, cam->cam_no);
-    else
+    } else {
       xperror("VIDIOC_REQBUFS");
+    }
   }
 
-  if (req.count < 2)
+  if (req.count < 2) {
     xerror("Insufficient buffer memory on %s%d\n", video_base, cam->cam_no);
+  }
 
-  cam->buffers = xmalloc(req.count*sizeof(buffer_t));
+  cam->buffers = xcalloc(req.count, sizeof(buffer_t));
 
   for (cam->n_buffers = 0; cam->n_buffers < (int)req.count; ++cam->n_buffers) {
-   struct v4l2_buffer buf;
+    struct v4l2_buffer buf;
 
-   CLEAR(buf);
+    CLEAR(buf);
 
-   buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-   buf.memory      = V4L2_MEMORY_MMAP;
-   buf.index       = cam->n_buffers;
+    buf.type        = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+    buf.memory      = V4L2_MEMORY_MMAP;
+    buf.index       = cam->n_buffers;
 
-   if (-1 == xioctl(cam->fd, VIDIOC_QUERYBUF, &buf))
-     xperror("VIDIOC_QUERYBUF");
+    if (-1 == xioctl(cam->fd, VIDIOC_QUERYBUF, &buf)) {
+      xperror("VIDIOC_QUERYBUF");
+    }
 
-   cam->buffers[cam->n_buffers].length = buf.length;
-   cam->buffers[cam->n_buffers].start =
-     mmap(NULL /* start anywhere */,
-	  buf.length,
-	  PROT_READ | PROT_WRITE /* required */,
-	  MAP_SHARED /* recommended */,
-	  cam->fd, buf.m.offset);
+    cam->buffers[cam->n_buffers].length = buf.length;
+    cam->buffers[cam->n_buffers].start =
+      mmap(NULL /* start anywhere */,
+           buf.length,
+           PROT_READ | PROT_WRITE /* required */,
+           MAP_SHARED /* recommended */,
+           cam->fd, buf.m.offset);
 
-   if (MAP_FAILED == cam->buffers[cam->n_buffers].start)
-     xperror("mmap");
+    if (MAP_FAILED == cam->buffers[cam->n_buffers].start) {
+      xperror("mmap");
+    }
   }
 }
 
@@ -107,8 +111,9 @@ init_device(webcam_t *cam)
     if (EINVAL == errno) {
       fprintf(stderr, "[!] %s%d is no V4L2 device\n", video_base, cam->cam_no);
       return -1;
-    } else
+    } else {
       xperror("VIDIOC_QUERYCAP");
+    }
   }
 
   if (!(cap.capabilities & V4L2_CAP_VIDEO_CAPTURE)) {
@@ -148,12 +153,12 @@ init_device(webcam_t *cam)
     if (-1 == xioctl(cam->fd, VIDIOC_S_CROP, &crop)) {
       switch (errno) {
       case EINVAL:
-	/* Cropping not supported. */
-	break;
+        /* Cropping not supported. */
+        break;
 
       default:
-	/* Errors ignored. */
-	break;
+        /* Errors ignored. */
+        break;
       }
     }
   } else {
@@ -171,17 +176,20 @@ init_device(webcam_t *cam)
   fmt.fmt.pix.field       = V4L2_FIELD_INTERLACED;
 
   /* Note VIDIOC_S_FMT may change width and height. */
-  if (-1 == xioctl(cam->fd, VIDIOC_S_FMT, &fmt))
+  if (-1 == xioctl(cam->fd, VIDIOC_S_FMT, &fmt)) {
     return -1;
+  }
 
 #if 0
   /* Buggy driver paranoia. */
   min = fmt.fmt.pix.width * 2;
-  if (fmt.fmt.pix.bytesperline < min)
+  if (fmt.fmt.pix.bytesperline < min) {
     fmt.fmt.pix.bytesperline = min;
+  }
   min = fmt.fmt.pix.bytesperline * fmt.fmt.pix.height;
-  if (fmt.fmt.pix.sizeimage < min)
+  if (fmt.fmt.pix.sizeimage < min) {
     fmt.fmt.pix.sizeimage = min;
+  }
 #endif
 
   switch (cam->io) {
@@ -208,13 +216,16 @@ uninit_device(webcam_t *cam)
 
   switch (cam->io) {
   case IO_METHOD_READ:
-    free(cam->buffers[0].start);
+    xfree(cam->buffers[0].start);
     break;
 
   case IO_METHOD_MMAP:
     for (i = 0; i < cam->n_buffers; ++i)
-      if (-1 == munmap(cam->buffers[i].start, cam->buffers[i].length))
-	xperror("munmap");
+      if (-1 == munmap(cam->buffers[i].start, cam->buffers[i].length)) {
+        xperror("munmap");
+      }
     break;
   }
+
+  xfree(cam->buffers);
 }
