@@ -48,16 +48,19 @@ process_image(webcam_t *webcam, void *p)
   pthread_mutex_lock(&webcam->ctx->cam_mtx[webcam->cam_no]);
   dst = webcam->ctx->cam_save[webcam->cam_no][0];
 
-  if ((WIDTH == CAP_WIDTH) && (HEIGHT == CAP_HEIGHT))
+  if ((WIDTH == CAP_WIDTH) && (HEIGHT == CAP_HEIGHT)) {
     memcpy(dst->buffer, temp, BUFFSIZE*sizeof(Pixel_t));
-  else
+  } else {
     gray_scale(dst->buffer, CAP_WIDTH, CAP_HEIGHT, temp);
+  }
 
-  if (hflip)
+  if (hflip) {
     Buffer8_flip_h(dst);
+  }
 
-  if (vflip)
+  if (vflip) {
     Buffer8_flip_v(dst);
+  }
 
   save = Buffer8_clone(dst); /* TODO s/save/new_picture */
   Context_push_webcam(webcam->ctx, save, webcam->cam_no);
@@ -73,19 +76,19 @@ read_frame(webcam_t *cam)
   switch (cam->io) {
   case IO_METHOD_READ:
     if (-1 == read(cam->fd,
-		   cam->buffers[0].start,
-		   cam->buffers[0].length)) {
+                   cam->buffers[0].start,
+                   cam->buffers[0].length)) {
       switch (errno) {
       case EAGAIN:
-	return 0;
+        return 0;
 
       case EIO:
-	/* Could ignore EIO, see spec. */
+      /* Could ignore EIO, see spec. */
 
-	/* fall through */
+      /* fall through */
 
       default:
-	xperror("read");
+        xperror("read");
       }
     }
     process_image(cam, cam->buffers[0].start);
@@ -101,15 +104,15 @@ read_frame(webcam_t *cam)
     if (-1 == xioctl(cam->fd, VIDIOC_DQBUF, &buf)) {
       switch (errno) {
       case EAGAIN:
-	return 0;
+        return 0;
 
       case EIO:
-	/* Could ignore EIO, see spec. */
+      /* Could ignore EIO, see spec. */
 
-	/* fall through */
+      /* fall through */
 
       default:
-	xperror("VIDIOC_DQBUF");
+        xperror("VIDIOC_DQBUF");
       }
     }
 
@@ -118,8 +121,9 @@ read_frame(webcam_t *cam)
     // printf("index %d, process_image(%d) bytes\n", buf.index, (int)cam->buffers[buf.index].length);
     process_image(cam, cam->buffers[buf.index].start);
     // printf("process_image done cam #%d\n", cam->cam_no);
-    if (-1 == xioctl(cam->fd, VIDIOC_QBUF, &buf))
+    if (-1 == xioctl(cam->fd, VIDIOC_QBUF, &buf)) {
       xperror("VIDIOC_QBUF");
+    }
 
     break;
   }
@@ -127,43 +131,49 @@ read_frame(webcam_t *cam)
   return 1;
 }
 
+static int
+capture_frame(webcam_t *webcam)
+{
+  fd_set fds;
+  struct timeval tv;
+  int r;
+
+  FD_ZERO(&fds);
+  FD_SET(webcam->fd, &fds);
+
+  /* Timeout. */
+  tv.tv_sec = 30;
+  tv.tv_usec = 0;
+
+  r = select(webcam->fd + 1, &fds, NULL, NULL, &tv);
+  if (-1 == r) {
+    if (EINTR == errno) {
+      return 1;
+    }
+    xperror("select");
+  }
+  if (0 == r) {
+    xerror("select timeout\n");
+  }
+  return read_frame(webcam);
+}
+
+
 
 void *
 loop(void *args)
 {
   webcam_t *webcam = (webcam_t *)args;
 
+  capture_frame(webcam);
+  Buffer8_copy(webcam->ctx->cam_save[webcam->cam_no][0], webcam->ctx->cam_ref0[webcam->cam_no]);
+
   while (webcam->ctx->running) {
-    fd_set fds;
-    struct timeval tv;
-    int r;
-
-    FD_ZERO(&fds);
-    FD_SET(webcam->fd, &fds);
-
-    /* Timeout. */
-    tv.tv_sec = 30;
-    tv.tv_usec = 0;
-
-    r = select(webcam->fd + 1, &fds, NULL, NULL, &tv);
-
-    if (-1 == r) {
-      if (EINTR == errno)
-	continue;
-
-      xperror("select");
-    }
-
-    if (0 == r)
-      xerror("select timeout\n");
-
-    read_frame(webcam);
-
     if (!webcam->ctx->ref_taken[webcam->cam_no]) {
       Buffer8_copy(webcam->ctx->cam_save[webcam->cam_no][0], webcam->ctx->cam_ref[webcam->cam_no]);
       webcam->ctx->ref_taken[webcam->cam_no] = 1;
     }
+    capture_frame(webcam);
   }
-
   pthread_exit(NULL);
 }
