@@ -55,8 +55,9 @@ open_device(webcam_t *cam, const uint8_t try)
     VERBOSE(printf("[!] Cannot open '%s': %d, %s\n", dev_name, errno, strerror(errno)));
     g_free(dev_name);
     return -1;
-  } else
+  } else {
     VERBOSE(printf("[i] Successfully opened %s as a video device, fd= %d\n", dev_name, cam->fd));
+  }
 
   g_free(dev_name);
 
@@ -67,6 +68,7 @@ open_device(webcam_t *cam, const uint8_t try)
 void
 close_device(const webcam_t *cam)
 {
-  if (-1 == close(cam->fd))
+  if (-1 == close(cam->fd)) {
     xperror("close");
+  }
 }
