@@ -38,7 +38,8 @@ process_token(const char *tok)
     assert(NULL != *vv);
     webcams = xatol(*vv);
     VERBOSE(printf("[E] webcam: grabbing %d device%s\n", webcams, (webcams == 1) ? "" : "s"));
-  } if (!strcmp((const char *)*vv, "device")) {
+  }
+  if (!strcmp((const char *)*vv, "device")) {
     vv++;
     assert(NULL != *vv);
     VERBOSE(printf("[E] webcam: device set to %s\n", *vv));
@@ -63,8 +64,9 @@ process_options(const char *options)
 
   tokens = g_strsplit(options, ",", 0);
 
-  for (tok = tokens ; *tok != NULL; tok++)
+  for (tok = tokens ; *tok != NULL; tok++) {
     process_token(*tok);
+  }
 
   g_strfreev(tokens);
 }
@@ -77,6 +79,7 @@ parse_options()
 
   options = getenv("LEBINIOU_WEBCAM");
 
-  if (NULL != options)
+  if (NULL != options) {
     process_options(options);
+  }
 }
