@@ -41,14 +41,16 @@ start_capturing(webcam_t *cam)
       buf.memory = V4L2_MEMORY_MMAP;
       buf.index  = i;
 
-      if (-1 == xioctl(cam->fd, VIDIOC_QBUF, &buf))
-	xperror("VIDIOC_QBUF");
+      if (-1 == xioctl(cam->fd, VIDIOC_QBUF, &buf)) {
+        xperror("VIDIOC_QBUF");
+      }
     }
 
     type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 
-    if (-1 == xioctl(cam->fd, VIDIOC_STREAMON, &type))
+    if (-1 == xioctl(cam->fd, VIDIOC_STREAMON, &type)) {
       xperror("VIDIOC_STREAMON");
+    }
 
     break;
   }
@@ -68,8 +70,9 @@ stop_capturing(webcam_t *cam)
   case IO_METHOD_MMAP:
     type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 
-    if (-1 == xioctl(cam->fd, VIDIOC_STREAMOFF, &type))
+    if (-1 == xioctl(cam->fd, VIDIOC_STREAMOFF, &type)) {
       xperror("VIDIOC_STREAMOFF");
+    }
 
     break;
   }
